/*= Rohde&Schwarz AM300 Arbitrary Generator Include File ====================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/

#ifndef __RSSIAM_HEADER
#define __RSSIAM_HEADER

#include "rssitype.h"

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= Instrument Driver Specific Error/Warning Codes ==========================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_FILE_OPEN                (_VI_ERROR+0x3FFC0800L)
#define VI_ERROR_INSTR_FILE_WRITE               (_VI_ERROR+0x3FFC0801L)
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)
#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_WARNING_INSTR_OFFSET                           (0x3FFC0900L)
#define VI_ERROR_INSTR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define RSSIAM_ERROR_INSTRUMENT_ERROR           (VI_ERROR_INSTR_OFFSET + 0xF0L)
#define RSSIAM_ERROR_INVALID_CONFIGURATION      (VI_ERROR_INSTR_OFFSET + 0xF1L)
#define RSSIAM_ERROR_INSTRUMENT_OPTION          (VI_ERROR_INSTR_OFFSET + 0xF2L)
#define RSSIAM_ERROR_INSTRUMENT_NSUP_MODEL      (VI_ERROR_INSTR_OFFSET + 0xF3L)
#define RSSIAM_ERROR_REG_NAME_NOT_FOUND         (VI_ERROR_INSTR_OFFSET + 0xF4L)
#define RSSIAM_ERROR_INVALID_VALUE              (VI_ERROR_INSTR_OFFSET + 0xF5L)
#define RSSIAM_ERROR_RNG_TAB_NOT_AVAIL          (VI_ERROR_INSTR_OFFSET + 0xF6L)
#define RSSIAM_ERROR_NULL_POINTER_VALUE         (VI_ERROR_INSTR_OFFSET + 0xF7L)
#define RSSIAM_ERROR_QUEUE_OVERFLOW             (VI_ERROR_INSTR_OFFSET + 0xF8L)
#define RSSIAM_ERROR_DATA_NOT_AVAILABLE         (VI_ERROR_INSTR_OFFSET + 0xF9L)
#define RSSIAM_ERROR_DATA_CORRUPTED             (VI_ERROR_INSTR_OFFSET + 0xFAL)
#define RSSIAM_ERROR_SETTINGS_CONFLICT          (VI_ERROR_INSTR_OFFSET + 0xFBL)
#define RSSIAM_ERROR_RESERVED                   (VI_ERROR_INSTR_OFFSET + 0xFCL)
#define RSSIAM_ERROR_OVER_LIMIT                 (VI_ERROR_INSTR_OFFSET + 0xFDL)

/*****************************************************************************/
/*= INSTRUMENT CONSTANTS ====================================================*/
/*****************************************************************************/

/* --- Output Channel ------------------------------------------------------ */

#define RSSIAM_CH1                              1 /* CH1 (Channel 1) */
#define RSSIAM_CH2                              2 /* CH2 (Channel 2) */

/* --- Channel Coupling ---------------------------------------------------- */

#define RSSIAM_CHANNEL_COUPLING_OFF             0x0 /* Coupling Off */
#define RSSIAM_CHANNEL_COUPLING_FREQ            0x1 /* Frequency */
#define RSSIAM_CHANNEL_COUPLING_AMPT            0x2 /* Amplitude */
#define RSSIAM_CHANNEL_COUPLING_OUTPUT          0x4 /* Output */
#define RSSIAM_CHANNEL_COUPLING_PHASE           0x8 /* Phase */

/* --- Function Shape ------------------------------------------------------ */

#define RSSIAM_OUTPUT_FUNC_SIN                  0 /* Sinusoid */
#define RSSIAM_OUTPUT_FUNC_SQU                  1 /* Square Low Jitter */
#define RSSIAM_OUTPUT_FUNC_TRI                  2 /* Triangle */
#define RSSIAM_OUTPUT_FUNC_RAMP                 3 /* Ramp (variable symmetry) */
#define RSSIAM_OUTPUT_FUNC_NOIS                 4 /* Noise */
#define RSSIAM_OUTPUT_FUNC_DC                   5 /* DC */
#define RSSIAM_OUTPUT_FUNC_USER                 6 /* User */
#define RSSIAM_OUTPUT_FUNC_SQUARE               7 /* Square */
#define RSSIAM_OUTPUT_FUNC_REXP                 8 /* Reverse Exponential */
#define RSSIAM_OUTPUT_FUNC_FEXP                 9 /* Forward Exponential */
#define RSSIAM_OUTPUT_FUNC_PULSE                10 /* Pulse */

/* --- Range --------------------------------------------------------------- */

#define RSSIAM_CURRENT_RANGE                    0 /* Current */
#define RSSIAM_MIN_RANGE                        1 /* Minimum */
#define RSSIAM_MAX_RANGE                        2 /* Maximum */

/* --- Voltage Unit -------------------------------------------------------- */

#define RSSIAM_OUTPUT_VOLT_UNIT_VPP             0 /* VPP */
#define RSSIAM_OUTPUT_VOLT_UNIT_VRMS            1 /* VRMS */
#define RSSIAM_OUTPUT_VOLT_UNIT_DBM             2 /* DBM */
#define RSSIAM_OUTPUT_VOLT_UNIT_DEF             3 /* Default */

/* --- Output Load --------------------------------------------------------- */

#define RSSIAM_OUTPUT_LOAD_50                   0 /* 50 ohms */
#define RSSIAM_OUTPUT_LOAD_USER                 1 /* User */

/* --- Output Sync --------------------------------------------------------- */

#define RSSIAM_OUTPUT_SYNC_OFF                  0 /* Off */
#define RSSIAM_OUTPUT_SYNC_ON                   1 /* On */

/* --- Output Summary ------------------------------------------------------ */

#define RSSIAM_OUTPUT_SUM_OFF                   0 /* Off */
#define RSSIAM_OUTPUT_SUM_ON                    1 /* On */

/* --- Output Setup -------------------------------------------------------- */

#define RSSIAM_OUTPUT_SETUP_OFF                 0 /* Off */
#define RSSIAM_OUTPUT_SETUP_ON                  1 /* On */

/* --- Output Filter ------------------------------------------------------- */

#define RSSIAM_OUTPUT_FILTER_OFF                0 /* Off */
#define RSSIAM_OUTPUT_FILTER_ON                 1 /* On */
#define RSSIAM_OUTPUT_FILTER_AUTO               2 /* Auto */

/* --- Filter Auto --------------------------------------------------------- */

#define RSSIAM_OUTPUT_FILTER_AUTO_OFF           0 /* Off */
#define RSSIAM_OUTPUT_FILTER_AUTO_ON            1 /* On */

/* --- Output Filter Type -------------------------------------------------- */

#define RSSIAM_OUTPUT_FILTER_TYPE_CAUER         0 /* Cauer 35 MHz */
#define RSSIAM_OUTPUT_FILTER_TYPE_BESSEL10      1 /* Bessel 37 MHz */
#define RSSIAM_OUTPUT_FILTER_TYPE_BESSEL75      2 /* Bessel 75 MHz */

/* --- Output External Filter ---------------------------------------------- */

#define RSSIAM_OUTPUT_EXT_FILTER_OFF            0 /* Off */
#define RSSIAM_OUTPUT_EXT_FILTER_ON             1 /* On */

/* --- Pulse Polarity ------------------------------------------------------ */

#define RSSIAM_PULSE_POLARITY_NORMAL            0 /* Normal */
#define RSSIAM_PULSE_POLARITY_INVERTED          1 /* Inverted */

/* --- Sync Type ----------------------------------------------------------- */

#define RSSIAM_SYNC_TYPE_COMP                   0 /* COMP */
#define RSSIAM_SYNC_TYPE_CARRY                  1 /* CARRY */
#define RSSIAM_SYNC_TYPE_TRIG                   2 /* TRIG */
#define RSSIAM_SYNC_TYPE_MOD                    3 /* MOD */
#define RSSIAM_SYNC_TYPE_MFRQ                   4 /* MFRQ */
#define RSSIAM_SYNC_TYPE_MWFM                   5 /* MWFM */

/* --- Sync Polarity ------------------------------------------------------- */

#define RSSIAM_SYNC_POLARITY_NORMAL             0 /* Normal */
#define RSSIAM_SYNC_POLARITY_INVERTED           1 /* Inverted */

/* --- AM Func ------------------------------------------------------------- */

#define RSSIAM_AMP_INT_FUNC_SIN                 0 /* Sinusoid */
#define RSSIAM_AMP_INT_FUNC_SQU                 1 /* Square */
#define RSSIAM_AMP_INT_FUNC_TRI                 2 /* Triangle */
#define RSSIAM_AMP_INT_FUNC_URAMP               3 /* Ramp (Up) */
#define RSSIAM_AMP_INT_FUNC_DRAMP               4 /* Ramp (Down) */
#define RSSIAM_AMP_INT_FUNC_USER                5 /* User */
#define RSSIAM_AMP_INT_FUNC_REXP                8 /* Reverse Exponential */
#define RSSIAM_AMP_INT_FUNC_FEXP                9 /* Forward Exponential */

/* --- AM State ------------------------------------------------------------ */

#define RSSIAM_AMP_STAT_OFF                     0 /* Off */
#define RSSIAM_AMP_STAT_ON                      1 /* On */

/* --- FM Func ------------------------------------------------------------- */

#define RSSIAM_FREQ_INT_FUNC_SIN                0 /* Sinusoid */
#define RSSIAM_FREQ_INT_FUNC_SQU                1 /* Square */
#define RSSIAM_FREQ_INT_FUNC_TRI                2 /* Triangle */
#define RSSIAM_FREQ_INT_FUNC_URAMP              3 /* Ramp (Up) */
#define RSSIAM_FREQ_INT_FUNC_DRAMP              4 /* Ramp (Down) */
#define RSSIAM_FREQ_INT_FUNC_USER               5 /* User */
#define RSSIAM_FREQ_INT_FUNC_REXP               8 /* Reverse Exponential */
#define RSSIAM_FREQ_INT_FUNC_FEXP               9 /* Forward Exponential */

/* --- FM State ------------------------------------------------------------ */

#define RSSIAM_FREQ_STAT_OFF                    0 /* Off */
#define RSSIAM_FREQ_STAT_ON                     1 /* On */

/* --- PM Func ------------------------------------------------------------- */

#define RSSIAM_PHASE_INT_FUNC_SIN               0 /* Sinusoid */
#define RSSIAM_PHASE_INT_FUNC_SQU               1 /* Square */
#define RSSIAM_PHASE_INT_FUNC_TRI               2 /* Triangle */
#define RSSIAM_PHASE_INT_FUNC_URAMP             3 /* Ramp (Up) */
#define RSSIAM_PHASE_INT_FUNC_DRAMP             4 /* Ramp (Down) */
#define RSSIAM_PHASE_INT_FUNC_USER              5 /* User */
#define RSSIAM_PHASE_INT_FUNC_REXP              8 /* Reverse Exponential */
#define RSSIAM_PHASE_INT_FUNC_FEXP              9 /* Forward Exponential */

/* --- PM State ------------------------------------------------------------ */

#define RSSIAM_PHASE_STAT_OFF                   0 /* Off */
#define RSSIAM_PHASE_STAT_ON                    1 /* On */

/* --- BM Source ----------------------------------------------------------- */

#define RSSIAM_BM_SOUR_TRIG                     0 /* Triggered */
#define RSSIAM_BM_SOUR_INT                      1 /* Int Gated */
#define RSSIAM_BM_SOUR_EXT                      2 /* Ext Gated */

/* --- BM State ------------------------------------------------------------ */

#define RSSIAM_BM_STAT_OFF                      0 /* Off */
#define RSSIAM_BM_STAT_ON                       1 /* On */

/* --- FSK Source ---------------------------------------------------------- */

#define RSSIAM_FSK_SOUR_INT                     0 /* Internal */
#define RSSIAM_FSK_SOUR_EXT                     1 /* External */

/* --- FSK State ----------------------------------------------------------- */

#define RSSIAM_FSK_STAT_OFF                     0 /* Off */
#define RSSIAM_FSK_STAT_ON                      1 /* On */

/* --- PSK Source ---------------------------------------------------------- */

#define RSSIAM_PSK_SOUR_INT                     0 /* Internal */
#define RSSIAM_PSK_SOUR_EXT                     1 /* External */

/* --- PSK State ----------------------------------------------------------- */

#define RSSIAM_PSK_STAT_OFF                     0 /* Off */
#define RSSIAM_PSK_STAT_ON                      1 /* On */

/* --- Frequency Mode ------------------------------------------------------ */

#define RSSIAM_FREQUENCY_MODE_CW                0 /* CW */
#define RSSIAM_FREQUENCY_MODE_FIXED             1 /* FIXED */
#define RSSIAM_FREQUENCY_MODE_SWEEP             2 /* SWEEP */

/* --- Arb Rate Mode ------------------------------------------------------- */

#define RSSIAM_ARB_RATE_MODE_NORMAL             0 /* Normal */
#define RSSIAM_ARB_RATE_MODE_ACCURATE           1 /* Sample Accurate */

/* --- Arb Direction ------------------------------------------------------- */

#define RSSIAM_SWEEP_DIRECTION_UP               0 /* Up */
#define RSSIAM_SWEEP_DIRECTION_DOWN             1 /* Down */

/* --- Sweep Spacing ------------------------------------------------------- */

#define RSSIAM_SWEEP_SPAC_LIN                   0 /* Linear */
#define RSSIAM_SWEEP_SPAC_LOG                   1 /* Logarithmic */

/* --- Sweep State --------------------------------------------------------- */

#define RSSIAM_SWEEP_STAT_OFF                   0 /* Off */
#define RSSIAM_SWEEP_STAT_ON                    1 /* On */

/* --- Marker State -------------------------------------------------------- */

#define RSSIAM_MARKER_STAT_OFF                  0 /* Off */
#define RSSIAM_MARKER_STAT_ON                   1 /* On */

/* --- Trigger Source ------------------------------------------------------ */

#define RSSIAM_TRIGGER_SOUR_IMM                 0 /* Immediate */
#define RSSIAM_TRIGGER_SOUR_EXT                 1 /* External */
#define RSSIAM_TRIGGER_SOUR_BUS                 2 /* Bus */
#define RSSIAM_TRIGGER_SOUR_SYS                 3 /* System */

/* --- Trigger Slope ------------------------------------------------------- */

#define RSSIAM_TRIGGER_SLOPE_POS                0 /* Positive */
#define RSSIAM_TRIGGER_SLOPE_NEG                1 /* Negative */

/* --- Gate Function ------------------------------------------------------- */

#define RSSIAM_GATE_SAMPLE_HOLD                 0 /* Sample & Hold */
#define RSSIAM_GATE_BLOCK_END                   1 /* Block End */
#define RSSIAM_GATE_BURST                       2 /* Burst */

/* --- Rosc Source --------------------------------------------------------- */

#define RSSIAM_ROSC_TCXO                        0 /* TCXO */
#define RSSIAM_ROSC_OCXO                        1 /* OCXO */
#define RSSIAM_ROSC_EXT                         2 /* External */

/* --- Rosc State ---------------------------------------------------------- */

#define RSSIAM_ROSC_STAT_OFF                    0 /* Off */
#define RSSIAM_ROSC_STAT_ON                     1 /* On */

/* --- Rosc Frequency ------------------------------------------------------ */

#define RSSIAM_ROSC_FREQ_2MHZ                   0 /* 2 MHz */
#define RSSIAM_ROSC_FREQ_5MHZ                   1 /* 5 MHz */
#define RSSIAM_ROSC_FREQ_10MHZ                  2 /* 10 MHz */

/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC rssiam_init (ViRsrc resourceName, ViBoolean IDQuery,
                               ViBoolean resetDevice, ViPSession instrSession);
ViStatus _VI_FUNC rssiam_appl (ViSession instrSession, ViInt16 function,
                               ViReal64 frequency, ViReal64 amplitude,
                               ViReal64 offset);
ViStatus _VI_FUNC rssiam_appl_Q (ViSession instrSession,
                                 ViChar _VI_FAR queryResult[]);
ViStatus _VI_FUNC rssiam_outpChannel (ViSession instrSession,
                                      ViInt16 activeChannel);
ViStatus _VI_FUNC rssiam_outpChannel_Q (ViSession instrSession,
                                        ViPInt16 activeChannel);
ViStatus _VI_FUNC rssiam_outpChannelCoupl (ViSession instrSession,
                                           ViInt16 channelCoupling);
ViStatus _VI_FUNC rssiam_outpChannelCoupl_Q (ViSession instrSession,
                                             ViPInt16 channelCoupling);
ViStatus _VI_FUNC rssiam_funcShap (ViSession instrSession,
                                   ViInt16 functionShape);
ViStatus _VI_FUNC rssiam_funcShap_Q (ViSession instrSession,
                                     ViPInt16 functionShape);
ViStatus _VI_FUNC rssiam_freq (ViSession instrSession, ViReal64 frequency);
ViStatus _VI_FUNC rssiam_freq_Q (ViSession instrSession, ViInt16 range,
                                 ViPReal64 frequency);
ViStatus _VI_FUNC rssiam_volt (ViSession instrSession, ViReal64 voltage);
ViStatus _VI_FUNC rssiam_volt_Q (ViSession instrSession, ViInt16 range,
                                 ViPReal64 voltage);
ViStatus _VI_FUNC rssiam_voltOffs (ViSession instrSession,
                                   ViReal64 voltageOffset);
ViStatus _VI_FUNC rssiam_voltOffs_Q (ViSession instrSession, ViInt16 range,
                                     ViPReal64 voltageOffset);
ViStatus _VI_FUNC rssiam_voltHigh (ViSession instrSession,
                                   ViReal64 voltageHigh);
ViStatus _VI_FUNC rssiam_voltHigh_Q (ViSession instrSession, ViInt16 range,
                                     ViPReal64 voltageHigh);
ViStatus _VI_FUNC rssiam_voltLow (ViSession instrSession, ViReal64 voltageLow);
ViStatus _VI_FUNC rssiam_voltLow_Q (ViSession instrSession, ViInt16 range,
                                    ViPReal64 voltageLow);
ViStatus _VI_FUNC rssiam_voltUnit (ViSession instrSession, ViInt16 voltageUnit);
ViStatus _VI_FUNC rssiam_voltUnit_Q (ViSession instrSession,
                                     ViPInt16 voltageUnit);
ViStatus _VI_FUNC rssiam_pulsDcyc (ViSession instrSession, ViReal64 dutyCycle);
ViStatus _VI_FUNC rssiam_pulsDcyc_Q (ViSession instrSession, ViInt16 range,
                                     ViPReal64 dutyCycle);
ViStatus _VI_FUNC rssiam_rampSymm (ViSession instrSession,
                                   ViReal64 rampSymmetry);
ViStatus _VI_FUNC rssiam_rampSymm_Q (ViSession instrSession, ViInt16 range,
                                     ViPReal64 rampSymmetry);
ViStatus _VI_FUNC rssiam_outpLoad (ViSession instrSession, ViInt16 outputLoad);
ViStatus _VI_FUNC rssiam_outpLoadUser (ViSession instrSession,
                                       ViReal64 outputLoad);
ViStatus _VI_FUNC rssiam_outpLoad_Q (ViSession instrSession, ViInt16 range,
                                     ViPReal64 outputLoad);
ViStatus _VI_FUNC rssiam_outpSync (ViSession instrSession, ViInt16 outputSync);
ViStatus _VI_FUNC rssiam_outpSync_Q (ViSession instrSession,
                                     ViPInt16 outputSync);
ViStatus _VI_FUNC rssiam_outpSetup (ViSession instrSession,
                                    ViInt16 outputSetup);
ViStatus _VI_FUNC rssiam_outpSetup_Q (ViSession instrSession,
                                      ViPInt16 outputSetup);
ViStatus _VI_FUNC rssiam_outpStartPhase (ViSession instrSession,
                                         ViReal64 startPhase);
ViStatus _VI_FUNC rssiam_outpStartPhase_Q (ViSession instrSession,
                                           ViPReal64 startPhase);
ViStatus _VI_FUNC rssiam_outpFilter (ViSession instrSession,
                                     ViInt16 outputFilter);
ViStatus _VI_FUNC rssiam_outpFilter_Q (ViSession instrSession,
                                       ViPInt16 outputFilter);
ViStatus _VI_FUNC rssiam_outpFilterType (ViSession instrSession,
                                         ViInt16 outputFilterType);
ViStatus _VI_FUNC rssiam_outpFilterType_Q (ViSession instrSession,
                                           ViPInt16 outputFilterType);
ViStatus _VI_FUNC rssiam_extFilter (ViSession instrSession,
                                    ViInt16 externalFilter);
ViStatus _VI_FUNC rssiam_extFilter_Q (ViSession instrSession,
                                      ViPInt16 externalFilter);
ViStatus _VI_FUNC rssiam_outpAddition (ViSession instrSession,
                                       ViInt16 outputAddition);
ViStatus _VI_FUNC rssiam_outpAdditon_Q (ViSession instrSession,
                                        ViPInt16 outputSummary);
ViStatus _VI_FUNC rssiam_pulsePeriod (ViSession instrSession,
                                      ViReal64 pulsePeriod);
ViStatus _VI_FUNC rssiam_pulsePeriod_Q (ViSession instrSession, ViInt16 range,
                                        ViPReal64 pulsePeriod);
ViStatus _VI_FUNC rssiam_pulseWidth (ViSession instrSession,
                                     ViReal64 pulseWidth);
ViStatus _VI_FUNC rssiam_pulseWidth_Q (ViSession instrSession, ViInt16 range,
                                       ViPReal64 pulseWidth);
ViStatus _VI_FUNC rssiam_pulsePolarity (ViSession instrSession,
                                        ViInt16 pulsePolarity);
ViStatus _VI_FUNC rssiam_pulsePolarity_Q (ViSession instrSession,
                                          ViPInt16 pulsePolarity);
ViStatus _VI_FUNC rssiam_mPoints (ViSession instrSession,
                                  ViInt32 modulationPoints);
ViStatus _VI_FUNC rssiam_mPoints_Q (ViSession instrSession, ViInt16 range,
                                    ViPInt32 modulationPoints);
ViStatus _VI_FUNC rssiam_amDept (ViSession instrSession,
                                 ViReal64 amplitudeDepth);
ViStatus _VI_FUNC rssiam_amDept_Q (ViSession instrSession, ViInt16 range,
                                   ViPReal64 amplitudeDepth);
ViStatus _VI_FUNC rssiam_amIntFunc (ViSession instrSession,
                                    ViInt16 AMIntFunction);
ViStatus _VI_FUNC rssiam_amIntFunc_Q (ViSession instrSession,
                                      ViPInt16 AMIntFunction);
ViStatus _VI_FUNC rssiam_amIntFreq (ViSession instrSession,
                                    ViReal64 AMFrequency);
ViStatus _VI_FUNC rssiam_amIntFreq_Q (ViSession instrSession, ViInt16 range,
                                      ViPReal64 AMFrequency);
ViStatus _VI_FUNC rssiam_amState (ViSession instrSession, ViInt16 AMState);
ViStatus _VI_FUNC rssiam_amState_Q (ViSession instrSession, ViPInt16 AMState);
ViStatus _VI_FUNC rssiam_fmDev (ViSession instrSession, ViReal64 FMDeviation);
ViStatus _VI_FUNC rssiam_fmDev_Q (ViSession instrSession, ViInt16 range,
                                  ViPReal64 FMDeviation);
ViStatus _VI_FUNC rssiam_fmIntFunc (ViSession instrSession,
                                    ViInt16 FMIntFunction);
ViStatus _VI_FUNC rssiam_fmIntFunc_Q (ViSession instrSession,
                                      ViPInt16 FMIntFunction);
ViStatus _VI_FUNC rssiam_fmIntFreq (ViSession instrSession,
                                    ViReal64 FMFrequency);
ViStatus _VI_FUNC rssiam_fmIntFreq_Q (ViSession instrSession, ViInt16 range,
                                      ViPReal64 FMFrequency);
ViStatus _VI_FUNC rssiam_fmStat (ViSession instrSession, ViInt16 FMState);
ViStatus _VI_FUNC rssiam_fmStat_Q (ViSession instrSession, ViPInt16 FMState);
ViStatus _VI_FUNC rssiam_pmDev (ViSession instrSession, ViReal64 PMDeviation);
ViStatus _VI_FUNC rssiam_pmDev_Q (ViSession instrSession, ViInt16 range,
                                  ViPReal64 PMDeviation);
ViStatus _VI_FUNC rssiam_pmIntFunc (ViSession instrSession,
                                    ViInt16 PMIntFunction);
ViStatus _VI_FUNC rssiam_pmIntFunc_Q (ViSession instrSession,
                                      ViPInt16 PMIntFunction);
ViStatus _VI_FUNC rssiam_pmIntFreq (ViSession instrSession,
                                    ViReal64 PMFrequency);
ViStatus _VI_FUNC rssiam_pmIntFreq_Q (ViSession instrSession, ViInt16 range,
                                      ViPReal64 PMFrequency);
ViStatus _VI_FUNC rssiam_pmStat (ViSession instrSession, ViInt16 PMState);
ViStatus _VI_FUNC rssiam_pmStat_Q (ViSession instrSession, ViPInt16 PMState);
ViStatus _VI_FUNC rssiam_fskFreq (ViSession instrSession,
                                  ViReal64 FSKFrequency);
ViStatus _VI_FUNC rssiam_fskFreq_Q (ViSession instrSession, ViInt16 range,
                                    ViPReal64 FSKFrequency);
ViStatus _VI_FUNC rssiam_fskIntRate (ViSession instrSession,
                                     ViReal64 FSKIntRate);
ViStatus _VI_FUNC rssiam_fskIntRate_Q (ViSession instrSession, ViInt16 range,
                                       ViPReal64 FSKIntRate);
ViStatus _VI_FUNC rssiam_fskSour (ViSession instrSession, ViInt16 FSKSource);
ViStatus _VI_FUNC rssiam_fskSour_Q (ViSession instrSession, ViPInt16 FSKSource);
ViStatus _VI_FUNC rssiam_fskStat (ViSession instrSession, ViInt16 FSKState);
ViStatus _VI_FUNC rssiam_fskStat_Q (ViSession instrSession, ViPInt16 FSKState);
ViStatus _VI_FUNC rssiam_pskPhase (ViSession instrSession, ViReal64 PSKPhase);
ViStatus _VI_FUNC rssiam_pskPhase_Q (ViSession instrSession, ViInt16 range,
                                     ViPReal64 PSKPhase);
ViStatus _VI_FUNC rssiam_pskIntRate (ViSession instrSession,
                                     ViReal64 PSKIntRate);
ViStatus _VI_FUNC rssiam_pskIntRate_Q (ViSession instrSession, ViInt16 range,
                                       ViPReal64 PSKIntRate);
ViStatus _VI_FUNC rssiam_pskSour (ViSession instrSession, ViInt16 PSKSource);
ViStatus _VI_FUNC rssiam_pskSour_Q (ViSession instrSession, ViPInt16 PSKSource);
ViStatus _VI_FUNC rssiam_pskStat (ViSession instrSession, ViInt16 PSKState);
ViStatus _VI_FUNC rssiam_pskStat_Q (ViSession instrSession, ViPInt16 PSKState);
ViStatus _VI_FUNC rssiam_userVolatile (ViSession instrSession,
                                       ViInt32 no_ofPoints,
                                       ViReal64 _VI_FAR dataArray[]);
ViStatus _VI_FUNC rssiam_userDacVolatile (ViSession instrSession,
                                          ViInt32 no_ofPoints,
                                          ViInt16 _VI_FAR dataArray[]);
ViStatus _VI_FUNC rssiam_fmUserVolatile (ViSession instrSession,
                                         ViInt32 no_ofSamples,
                                         ViReal64 _VI_FAR dataArray[]);
ViStatus _VI_FUNC rssiam_fmUserDacVolatile (ViSession instrSession,
                                            ViInt32 no_ofSamples,
                                            ViUInt32 _VI_FAR dataArray[]);
ViStatus _VI_FUNC rssiam_amUserVolatile (ViSession instrSession,
                                         ViInt32 no_ofPoints,
                                         ViReal64 _VI_FAR dataArrayCH1[],
                                         ViReal64 _VI_FAR dataArrayCH2[]);
ViStatus _VI_FUNC rssiam_amUserDacVolatile (ViSession instrSession,
                                            ViInt32 no_ofPoints,
                                            ViInt16 _VI_FAR dataArrayCH1[],
                                            ViInt16 _VI_FAR dataArrayCH2[]);
ViStatus _VI_FUNC rssiam_pmUserVolatile (ViSession instrSession,
                                         ViInt32 no_ofPoints,
                                         ViReal64 _VI_FAR dataArrayCH1[],
                                         ViReal64 _VI_FAR dataArrayCH2[]);
ViStatus _VI_FUNC rssiam_pmUserDacVolatile (ViSession instrSession,
                                            ViInt32 no_ofPoints,
                                            ViUInt16 _VI_FAR dataArrayCH1[],
                                            ViUInt16 _VI_FAR dataArrayCH2[]);
ViStatus _VI_FUNC rssiam_dataArbPoin (ViSession instrSession,
                                      ViInt32 dataPoints);
ViStatus _VI_FUNC rssiam_dataArbPoin_Q (ViSession instrSession,
                                        ViPInt32 dataPoints);
ViStatus _VI_FUNC rssiam_dataArbStart (ViSession instrSession,
                                       ViInt32 dataStart);
ViStatus _VI_FUNC rssiam_dataArbStart_Q (ViSession instrSession,
                                         ViPInt32 dataStart);
ViStatus _VI_FUNC rssiam_dataArbStop (ViSession instrSession, ViInt32 dataStop);
ViStatus _VI_FUNC rssiam_dataArbStop_Q (ViSession instrSession,
                                        ViPInt32 dataStop);
ViStatus _VI_FUNC rssiam_dataArbRate (ViSession instrSession,
                                      ViReal64 dataSampleRate);
ViStatus _VI_FUNC rssiam_dataArbRate_Q (ViSession instrSession,
                                        ViPReal64 dataSampleRate);
ViStatus _VI_FUNC rssiam_dataArbRateMode (ViSession instrSession,
                                          ViInt16 dataSampleRateMode);
ViStatus _VI_FUNC rssiam_dataArbRateMode_Q (ViSession instrSession,
                                            ViPInt16 dataSampleRateMode);
ViStatus _VI_FUNC rssiam_dataVolatile (ViSession instrSession,
                                       ViInt32 no_ofPoints,
                                       ViReal64 _VI_FAR dataArray[]);
ViStatus _VI_FUNC rssiam_dataDacVolatile (ViSession instrSession,
                                          ViInt32 no_ofPoints,
                                          ViInt16 _VI_FAR dataArray[]);
ViStatus _VI_FUNC rssiam_freqStar (ViSession instrSession,
                                   ViReal64 frequencyStart);
ViStatus _VI_FUNC rssiam_freqStar_Q (ViSession instrSession, ViInt16 range,
                                     ViPReal64 frequencyStart);
ViStatus _VI_FUNC rssiam_freqStop (ViSession instrSession,
                                   ViReal64 frequencyStop);
ViStatus _VI_FUNC rssiam_freqStop_Q (ViSession instrSession, ViInt16 range,
                                     ViPReal64 frequencyStop);
ViStatus _VI_FUNC rssiam_freqCenter (ViSession instrSession,
                                     ViReal64 frequencyCenter);
ViStatus _VI_FUNC rssiam_freqCenter_Q (ViSession instrSession, ViInt16 range,
                                       ViPReal64 frequencyCenter);
ViStatus _VI_FUNC rssiam_freqSpan (ViSession instrSession,
                                   ViReal64 frequencySpan);
ViStatus _VI_FUNC rssiam_freqSpan_Q (ViSession instrSession, ViInt16 range,
                                     ViPReal64 frequencySpan);
ViStatus _VI_FUNC rssiam_sweDirection (ViSession instrSession,
                                       ViInt16 sweepDirection);
ViStatus _VI_FUNC rssiam_sweDirection_Q (ViSession instrSession,
                                         ViPInt16 sweepDirection);
ViStatus _VI_FUNC rssiam_swePoin (ViSession instrSession, ViInt32 sweepPoints);
ViStatus _VI_FUNC rssiam_swePoin_Q (ViSession instrSession,
                                    ViPInt32 dataPoints);
ViStatus _VI_FUNC rssiam_sweSpac (ViSession instrSession, ViInt16 sweepSpacing);
ViStatus _VI_FUNC rssiam_sweSpac_Q (ViSession instrSession,
                                    ViPInt16 sweepSpacing);
ViStatus _VI_FUNC rssiam_sweTime (ViSession instrSession, ViReal64 sweepTime);
ViStatus _VI_FUNC rssiam_sweTime_Q (ViSession instrSession, ViInt16 range,
                                    ViPReal64 sweepTime);
ViStatus _VI_FUNC rssiam_sweStat (ViSession instrSession, ViInt16 sweepState);
ViStatus _VI_FUNC rssiam_sweStat_Q (ViSession instrSession,
                                    ViPInt16 sweepState);
ViStatus _VI_FUNC rssiam_mkrFreq (ViSession instrSession,
                                  ViReal64 markerFrequency);
ViStatus _VI_FUNC rssiam_mkrFreq_Q (ViSession instrSession,
                                    ViPReal64 markerFrequency);
ViStatus _VI_FUNC rssiam_mkrStat (ViSession instrSession, ViInt16 markerState);
ViStatus _VI_FUNC rssiam_mkrStat_Q (ViSession instrSession,
                                    ViPInt16 markerState);
ViStatus _VI_FUNC rssiam_trigSour (ViSession instrSession,
                                   ViInt16 triggerSource);
ViStatus _VI_FUNC rssiam_trigSour_Q (ViSession instrSession,
                                     ViPInt16 triggerSource);
ViStatus _VI_FUNC rssiam_trigPolarity (ViSession instrSession,
                                       ViInt16 triggerPolarity);
ViStatus _VI_FUNC rssiam_trigPolarity_Q (ViSession instrSession,
                                         ViPInt16 triggerPolarity);
ViStatus _VI_FUNC rssiam_trigDelay (ViSession instrSession,
                                    ViReal64 triggerDelay);
ViStatus _VI_FUNC rssiam_trigDelay_Q (ViSession instrSession,
                                      ViPReal64 triggerDelay);
ViStatus _VI_FUNC rssiam_trigFrequency (ViSession instrSession,
                                        ViReal64 triggerFrequency);
ViStatus _VI_FUNC rssiam_trigFrequency_Q (ViSession instrSession,
                                          ViPReal64 triggerFrequency);
ViStatus _VI_FUNC rssiam_trigPeriod (ViSession instrSession,
                                     ViReal64 triggerPeriod);
ViStatus _VI_FUNC rssiam_trigPeriod_Q (ViSession instrSession,
                                       ViPReal64 triggerPeriod);
ViStatus _VI_FUNC rssiam_bmNcyc (ViSession instrSession, ViInt32 no_ofCycles);
ViStatus _VI_FUNC rssiam_bmNcyc_Q (ViSession instrSession, ViInt16 range,
                                   ViPInt32 no_ofCycles);
ViStatus _VI_FUNC rssiam_bmIntRate (ViSession instrSession, ViReal64 BMIntRate);
ViStatus _VI_FUNC rssiam_bmIntRate_Q (ViSession instrSession, ViInt16 range,
                                      ViPReal64 BMIntRate);
ViStatus _VI_FUNC rssiam_bmSour (ViSession instrSession, ViInt16 BMSource);
ViStatus _VI_FUNC rssiam_bmSour_Q (ViSession instrSession, ViPInt16 BMSource);
ViStatus _VI_FUNC rssiam_bmStat (ViSession instrSession, ViInt16 BMState);
ViStatus _VI_FUNC rssiam_bmStat_Q (ViSession instrSession, ViPInt16 BMState);
ViStatus _VI_FUNC rssiam_syncType (ViSession instrSession, ViInt16 syncType);
ViStatus _VI_FUNC rssiam_syncType_Q (ViSession instrSession, ViPInt16 syncType);
ViStatus _VI_FUNC rssiam_syncPolarity (ViSession instrSession,
                                       ViInt16 syncPolarity);
ViStatus _VI_FUNC rssiam_syncPolarity_Q (ViSession instrSession,
                                         ViPInt16 syncPolarity);
ViStatus _VI_FUNC rssiam_gateFunction (ViSession instrSession,
                                       ViInt16 gateFunction);
ViStatus _VI_FUNC rssiam_gateFunction_Q (ViSession instrSession,
                                         ViPInt16 gateFunction);
ViStatus _VI_FUNC rssiam_gateLength (ViSession instrSession,
                                     ViReal64 gateLength);
ViStatus _VI_FUNC rssiam_gateLength_Q (ViSession instrSession,
                                       ViPReal64 gateLength);
ViStatus _VI_FUNC rssiam_gateSource (ViSession instrSession,
                                     ViInt16 gateSource);
ViStatus _VI_FUNC rssiam_gateSource_Q (ViSession instrSession,
                                       ViPInt16 gateSource);
ViStatus _VI_FUNC rssiam_gatePolarity (ViSession instrSession,
                                       ViInt16 gatePolarity);
ViStatus _VI_FUNC rssiam_gatePolarity_Q (ViSession instrSession,
                                         ViPInt16 gatePolarity);
ViStatus _VI_FUNC rssiam_sendTrigger (ViSession instrSession);
ViStatus _VI_FUNC rssiam_abortTrigger (ViSession instrSession);
ViStatus _VI_FUNC rssiam_timeOut (ViSession instrSession, ViInt32 timeout);
ViStatus _VI_FUNC rssiam_timeOut_Q (ViSession instrSession, ViPInt32 timeout);
ViStatus _VI_FUNC rssiam_roscSour (ViSession instrSession, ViInt16 roscSource);
ViStatus _VI_FUNC rssiam_roscSour_Q (ViSession instrSession,
                                     ViPInt16 roscSource);
ViStatus _VI_FUNC rssiam_roscStat (ViSession instrSession, ViInt16 roscState);
ViStatus _VI_FUNC rssiam_roscStat_Q (ViSession instrSession,
                                     ViPInt16 roscState);
ViStatus _VI_FUNC rssiam_roscFreq (ViSession instrSession,
                                   ViInt32 refFrequency);
ViStatus _VI_FUNC rssiam_roscFreq_Q (ViSession instrSession,
                                     ViPInt32 refFrequency);
ViStatus _VI_FUNC rssiam_flushErrorQueue (ViSession instrSession);
ViStatus _VI_FUNC rssiam_errorCheckState (ViSession instrSession,
                                          ViBoolean stateChecking);
ViStatus _VI_FUNC rssiam_reset (ViSession instrSession);
ViStatus _VI_FUNC rssiam_self_test (ViSession instrSession,
                                    ViPInt16 selfTestResult,
                                    ViChar _VI_FAR selfTestMessage[]);
ViStatus _VI_FUNC rssiam_error_query (ViSession instrSession,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[]);
ViStatus _VI_FUNC rssiam_error_message (ViSession instrSession,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR message[]);
ViStatus _VI_FUNC rssiam_revision_query (ViSession instrSession,
                                         ViChar _VI_FAR instrumentDriverRevision[],
                                         ViChar _VI_FAR firmwareRevision[]);
ViStatus _VI_FUNC rssiam_trigSlope (ViSession instrSession,
                                    ViInt16 triggerSlope);
ViStatus _VI_FUNC rssiam_trigSlope_Q (ViSession instrSession,
                                      ViPInt16 triggerSlope);
ViStatus _VI_FUNC rssiam_outpSum (ViSession instrSession,
                                  ViInt16 outputSummary);
ViStatus _VI_FUNC rssiam_outpSum_Q (ViSession instrSession,
                                    ViPInt16 outputSummary);
ViStatus _VI_FUNC rssiam_gateTime (ViSession instrSession, ViReal64 gateTime);
ViStatus _VI_FUNC rssiam_gateTime_Q (ViSession instrSession,
                                     ViPReal64 gateTime);
ViStatus _VI_FUNC rssiam_close (ViSession instrSession);


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
