/*= R&S AM300 Arbitrary Generator ===========================================*/
/* LabWindows/CVI 6.0 VXIpnp Instrument Driver
/* Original Release: November 2003
/* By: Martin Koutny
/*
/* Should you have any technical questions please contact the hotline of
/* Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center
/*
/* e-mail: CustomerSupport@rsd.rohde-schwarz.com
/*
/* Modification History:
/*
/*  Rev 1.8.1, 09/2008 by Martin Krcmar
/*      - Windows Vista support added in installer
/*
/*  Rev 1.8, 04/2006 by Martin Koutny
/*      - Removed not supported parameter RSSIAM_ROSC_OCXO:
/*          Reference Oscillator Source Setup (rssiam_roscSour)
/*          Reference Oscillator Source Query (rssiam_roscSour_Q)
/*      - Updated functions for new unit: Vpp ,Vrms, dBm (for Sinewave only):
/*          Output Voltage Setup (rssiam_volt)
/*          Output Voltage Query (rssiam_volt_Q)
/*          Output Voltage Unit Setup (rssiam_voltUnit)
/*          Output Voltage Unit Query (rssiam_voltUnit_Q)
/*      - New function Output Load User Setup (rssiam_outpLoadUser)
/*      - Updated functions Output Load Setup (rssiam_outpLoad) and Output Load Query (rssiam_outpLoad_Q)
/*      - Added manual trigger source (RSSIAM_TRIGGER_SOUR_BUS (2) - Manual), updated functions are:
/*          Trigger Source Setup (rssiam_trigSour)
/*          Trigger Source Query (rssiam_trigSour_Q)
/*          Send Trigger (rssiam_sendTrigger)
/*      - Reordered structure of FP file. New group "Trigger Subsystem Settings"
/*          bundles all related functions in one group.
/*      - New trigger subsystem functions:
/*          Trigger Polarity Setup (rssiam_trigPolarity) replacement of
/*              Trigger Slope Setup (rssiam_trigSlope)
/*          Trigger Polarity Query (rssiam_trigPolarity_Q) replacement of
/*              Trigger Slope Query (rssiam_trigSlope_Q)
/*          Trigger Frequency Setup (rssiam_trigFrequency)
/*          Trigger Frequency Query (rssiam_trigFrequency_Q)
/*          Trigger Period Setup (rssiam_trigPeriod)
/*          Trigger Period Query (rssiam_trigPeriod_Q)
/*      - New output functions:
/*              Output Addition Setup (rssiam_outpAddition)
/*              Output Addition Query (rssiam_outpAdditon_Q)
/*          are as replacement of
/*              Output Summary Setup (rssiam_outpSum)
/*              Output Summary Query (rssiam_outpSum_Q)
/*      - New sweep functions:
/*          Sweep Freq Center Setup (rssiam_freqCenter)
/*          Sweep Freq Center Query (rssiam_freqCenter_Q)
/*          Sweep Freq Span Setup (rssiam_freqSpan)
/*          Sweep Freq Span Query (rssiam_freqSpan_Q)
/*      - Group of functions Marker Settings renamed to the Frequency Marker Settings
/*      - New gate functions:
/*          Gate Source Setup (rssiam_gateSource)
/*          Gate Source Query (rssiam_gateSource_Q)
/*          Gate Polarity Setup (rssiam_gatePolarity)
/*          Gate Polarity Query (rssiam_gatePolarity_Q)
/*              Gate Length Setup (rssiam_gateLength)
/*              Gate Length Query (rssiam_gateLength_Q)
/*          are as replacement of
/*              Gate Time Setup (rssiam_gateTime)
/*              Gate Time Query (rssiam_gateTime_Q)
/*
/*  Rev 1.7, 11/2005 by Martin Koutny
/*      - Updated (fixed) functions:
/*          FM User Modulation Volatile Setup (rssiam_fmUserVolatile)
/*          FM User Modulation Dac Volatile Setup (rssiam_fmUserDacVolatile)
/*          PM User Modulation Volatile Setup (rssiam_pmUserVolatile)
/*          Phase Mod Dev Setup (rssiam_pmDev)
/*          PM User Modulation Dac Volatile Setup (rssiam_pmUserDacVolatile)
/*
/*  Rev 1.6, 09/2005 by Martin Koutny
/*      - Updated functions (descriptions, parameter ranges):
/*          Data Arb Volatile Setup (rssiam_dataVolatile)
/*          Data Arb Dac Volatile Setup (rssiam_dataDacVolatile)
/*          User Modulation Volatile Setup (rssiam_userVolatile)
/*          User Modulation Dac Volatile Setup (rssiam_userDacVolatile)
/*      - New functions:
/*          FM User Modulation Volatile Setup (rssiam_fmUserVolatile)
/*          FM User Modulation Dac Volatile Setup (rssiam_fmUserDacVolatile)
/*          AM User Modulation Volatile Setup (rssiam_amUserVolatile)
/*          AM User Modulation Dac Volatile Setup (rssiam_amUserDacVolatile)
/*          PM User Modulation Volatile Setup (rssiam_pmUserVolatile)
/*          PM User Modulation Dac Volatile Setup (rssiam_pmUserDacVolatile)
/*
/*  Rev 1.5, 08/2005 by Martin Koutny
/*      - New functions:
/*          User Modulation Volatile Setup (rssiam_userVolatile)
/*          User Modulation Dac Volatile Setup (rssiam_userDacVolatile)
/*          Reference Oscillator Frequency Setup (rssiam_roscFreq)
/*          Reference Oscillator Frequency Query (rssiam_roscFreq_Q)
/*      - Modified functions (description):
/*          Burst Mod Sour Setup (rssiam_bmSour)
/*          Burst Mod Sour Query (rssiam_bmSour_Q)
/*          Burst Mod Stat Setup (rssiam_bmStat)
/*          Burst Mod Stat Query (rssiam_bmStat_Q)
/*          Gate Function Setup (rssiam_gateFunction) (new value)
/*          Gate Function Query (rssiam_gateFunction_Q) (new value)
/*
/*  Rev 1.4.1, 04/2005 by Martin Koutny
/*      - Function shape parameters are renamed (Square to Square Low Jitter,
/*        Square (variable duty cycle) to Square), descriptions improved:
/*          Apply Instrument Setup (rssiam_appl)
/*          Apply Instrument Query (rssiam_appl_Q)
/*          Output Function Shape Setup (rssiam_funcShap)
/*          Output Function Shape Query (rssiam_funcShap_Q)
/*      - Warning messages from device are suppressed when the function
/*        Output Channel Coupling Setup (rssiam_outpChannelCoupl) is executed.
/*
/*  Rev 1.4, 02/2005 by Martin Koutny
/*      - Output Channel Coupling Setup (rssiam_outpChannelCoupl):
/*          Fixed side effects of coupled/uncoupled mode. Transition
/*          from coupled to uncoupled mode (and vice versa) preserves
/*          (restores) device (channel based) settings (depends on coupling
/*          mode, of course).
/*      - Output Load Setup (rssiam_outpLoad)
/*          Description changed. This function used for compatibility purpose only.
/*
/*  Rev 1.3, 12/2004 by Martin Koutny
/*      - Fixed default instrument setup routine when reset is omitted
/*      - Changed descriptions:
/*          Trigger Source Setup (rssiam_trigSour)
/*          Send Trigger (rssiam_sendTrigger)
/*          Output Voltage High Setup (rssiam_voltHigh)
/*          Output Voltage High Query (rssiam_voltHigh_Q)
/*          Output Voltage Low Setup (rssiam_voltLow)
/*          Output Voltage Low Query (rssiam_voltLow_Q)
/*      - Changed default values:
/*          Output Voltage High Setup (rssiam_voltHigh)
/*          Output Voltage Low Setup (rssiam_voltLow)
/*      - Error handling & status checking improved:
/*          State Checking (rssiam_errorCheckState) changed
/*          Non exported function Check Status (rssiam_checkStatus) changed
/*
/*  Rev 1.2, 04/2004 by Martin Koutny
/*      - Update of Arbitrary Waveform Setting functions
/*
/*  Rev 1.1, 03/2004 by Martin Koutny
/*      - device identification and logical names management added
/*      - hot plug & unplug support added
/*
/*  Rev 1.0.1, 01/2004 by Martin Koutny
/*      - Driver rebuild (broken type library in dll)
/*
/*  Rev 1.0.2, 02/2004 by Martin Koutny
/*      - Driver is adopted to instrument module firmware 3.63
/*
/* Note:
/*
/*  This instrument driver is deriver from Agilent ag33250a instr driver.
/*
/*===========================================================================*/
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <math.h>
#include <float.h>
#include <SiControl.h>
#include "rssiam.h"

/* Instrument driver revision */

#define RSSIAM_REVISION                         "Rev 1.8.1, 09/2008, CVI 8.0"

/* Constants & Macros */

#define BUFFER_SIZE                             4096L   /* I/O buffer size */
#define RSSIAM_DEFAULT_TIMEOUT                  15000   /* Timeout value in msec */
#define MAX_ERROR_QUEUE_LENGTH                  512     /* Maximum number of queued errors */
#define NUMERIC_PRECISION                       1e-12   /* Precision of compare operations */

/* Debuging mode */

#define ADD_ERROR_INFO                          1       /* 1 = append additional error information to the error message
                                                           0 = skipped */
#define PLL_FAILED_ROSC_INFO                    0       /* 1 = show error message when PLL fails for RegId 0x2060
                                                           0 = skip it */

/* Device States */

#define RSSIAM_IDLE                             0       /* Device is up and waiting for commands. */
#define RSSIAM_BUSY                             1       /* Device is working. */

/* Applicable Product IDs */

#define RSSIAM_PID_A300                         0x0005  /* Arbitrary Generator */
#define RSSIAM_PID_PS_OLD                       0x0009  /* Power Supply (old) */
#define RSSIAM_PID_PS                           0x0010  /* Power Supply */

/* Applicable Vendor ID */

#define RSSIAM_VID_ROHDE_SCHWARZ                0x0AAD  /* Rohde&Schwarz */

/* Data type identifiers used in the data structures */

#define DBL                                     0       /* double (8bytes) */
#define FLT                                     1       /* float (4bytes) */
#define I32                                     2       /* long (4bytes) */
#define U32                                     3       /* unsigned long (4bytes) */
#define I16                                     4       /* short (2bytes) */
#define U16                                     5       /* unsigned short (2bytes) */
#define STRING                                  6       /* string */
#define STRUCT                                  7       /* Structures must be handled each case one by one */
#define DBL_ARRAY                               8       /* double array */
#define U16_ARRAY                               9       /* unsigned short (2bytes) array */

/* Events */

#define RSSIAM_OSE_INTERNAL_ERROR               0x6010
#define RSSIAM_DEVICE_ERROR                     0x6011
#define RSSIAM_EXECUTION_ERROR                  0x6012
#define RSSIAM_DEVICE_SPECIFIC_ERROR            0x6013
#define RSSIAM_CONTROL_TRANSFER_HANDSHAKE       0x1000  /* 0x67FF or 0x1000 - old version */
#define RSSIAM_BAUGRUPPEN_DATA_BLOCK_ERROR      0x6F02

/*= Macros ==================================================================*/

#define CHECKERR(fCal) if (rssiam_status = (fCal), rssiam_status < VI_SUCCESS) \
    return rssiam_status; else

#define GOCHECKERR(fCal) if (rssiam_status = (fCal), rssiam_status < VI_SUCCESS) \
                            goto ERROR; else

#define CHECKERR_CU(fCal) if (rssiam_status = (fCal), rssiam_status < VI_SUCCESS) \
    return rssiam_initCleanUp (instrSession, rssiam_status); else

#define DBL2FLT(dblVal, fltVal) \
    fltVal = FLT_EPSILON * ceil (dblVal / FLT_EPSILON);

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE/DATA STRUCTURES =======================*/
/*****************************************************************************/

#pragma pack(1) /* Set maximum alignment to 1byte */

/* TSStringValPair is used in the rssiam_error_message function */
typedef struct
{
   ViStatus                     stringVal;
   ViString                     stringName;
}  TSStringValPair;

/* TSStringErrorPair is used for error queue handling */
typedef struct
{
   ViStatus                     stringVal;
   ViChar                       stringName[256];
}  TSStringErrorPair;

/* Define range table data type */
typedef union
{
    ViReal64                    dbl; /* Must be always as first item! */
    ViReal32                    flt;
    ViInt32                     i32;
    ViUInt32                    u32;
    ViInt16                     i16;
    ViUInt16                    u16;
/*  ViConstString               string; */
} TUValue;

/*
    Defines discrete elements of range table
     - parameter: parameter id
     - value: discrete value attached to parameter
     - opt: optional string value, set NULL for last item
*/
typedef struct
{
    ViUInt32                    parameter;
    TUValue                     value;
    ViConstString               opt;
} TSDiscreteValue;

/*
    Defines elements of range table
     - min: minimum value
     - def: default value
     - max: maximum value
     - discreteValues: pointer to list of discrete values (if any applicable)
*/
typedef struct
{
    TUValue                     min;
    TUValue                     def;
    TUValue                     max;
    TSDiscreteValue*            discreteValues;
} TSRangeTableEntry;

/*
    Defines elements of auto range device capabilities sources
     - minCap: Value of device capability identifier for minimum
     - maxCap: Value of device capability identifier for maximum
*/

typedef struct
{
    ViConstString               minCap;
    ViConstString               maxCap;
} TSAutoRangeDeviceCap;

/*
    Defines element of register set table.
     - RegId: Value of register identifier
     - Name: Name
     - Size: Size of the data structure
     - Structure: Definition of the data structure (data type)
     - AutoRangeCap: Pointer to auto range capability sources (min & max values)
     - RangeTable: Pointer to range table, associated to instrument register
     - Channels[]: Recognized channels (bit mask used) for device config 0 and 1
*/
typedef struct
{
    ViInt16                     RegId;
    ViConstString               Name;
    ViInt16                     Size;
    ViUInt16                    Structure;
    TSAutoRangeDeviceCap*       AutoRangeCap;
    TSRangeTableEntry*          RangeTable;
    ViUInt32                    Channels[2];
} TSRegisterSetEntry;

/*
    Defines element of device capabilities table
     - CapsId: Value of device capability identifier
     - Name: Name
     - Size: Size of the data structure
     - Structure: Definition of the data structure (data type)
     - Dependency: Name on which this element depends
*/
typedef struct
{
    ViInt16                     CapsId;
    ViConstString               Name;
    ViInt16                     Size;
    ViUInt16                    Structure;
    ViConstString               Dependency;
} TSDeviceCapsEntry;

/*
    Defines element of command set table
    - CmdId: Value of command identifier
    - Name: Name
    - Channels[]: Recognized channels (bit mask used) for device config 0 and 1
*/
typedef struct
{
    ViInt16                     CmdId;
    ViConstString               Name;
    ViUInt32                    Channels[2];
} TSCommandSetEntry;

/* --- Data structures of the Apply commands ------------------------------- */
/*                                                                           */
/* Apply commands provides straightforward possibility to program the        */
/* arbitrary generator over the DSI. You can select different parameters from*/
/* the function group in one command. Data structures of these commands are  */
/* shown below.                                                              */
/*                                                                           */
/* Note: Enumerations are allocated as unsigned integer (2 bytes on device,  */
/*       4 bytes on PC!). Replace all enums by unsigned short data type.     */
/*                                                                           */
/* ------------------------------------------------------------------------- */

typedef enum
{
  UP, DOWN
} eDIRECTION;

typedef enum
{
  CAUER, BESSEL10, BESSEL75
} eFILTER_TYPE;

typedef enum
{
  SINUSOID, TRIANGLE, URAMP, DRAMP, REXP,
  FEXP, NOISE, SQUARE, PULSE, DC, USER
} eFUNCTION;

typedef enum
{
  SH, BLKEND
} eGATE_FUNCTION;

typedef enum
{
  F_OFF, F_ON, F_AUTO
} eOUTFILT_STATE;

typedef enum
{
  NORMAL, INVERTED
} ePOLARITY;

typedef enum
{
  INT1, INT2, EXT1
} eRSOURCE;

typedef enum
{
  TRGED, INTGAT, EXTGAT
} eBSOURCE;

typedef enum
{
  INTERNAL, EXTERNAL
} eSOURCE;

typedef enum
{
  NORM, FIX, VAR
} eSRATE_MODE;

typedef enum
{
  OFF, ON
} eSTATE;

typedef enum
{
  LINEAR, LOGARITHMIC
} eSWEEP_SPACING;

typedef enum
{
  COMP, CARRY, TRIG, MOD, MFRQ, MWFM
} eSYNC_TYPE;

typedef enum
{
  POSITIVE, NEGATIVE
} eTRIGGER_SLOPE;

typedef enum
{
  BUS, EXT, IMM, SYST
} eTRIGGER_SOURCE;

typedef struct
{
  double                            period;     /* pulse period */
  double                            width;      /* pulse width */
  /* ePOLARITY */ unsigned short    polarity;   /* pulse polarity */
} ST_PULSE, *P_ST_PULSE;

typedef struct
{
  unsigned long                     points;     /* the number of generated points */
  unsigned long                     start;      /* arbitrary start address */
  unsigned long                     stop;       /* arbitrary stop address */
  double                            rate;       /* arbitrary sample rate */
  /* eSRATE_MODE */ unsigned short  rate_mode;  /* sample rate mode */
} ST_USER, *P_ST_USER;

typedef union
{
  float         symmetry;               /* RAMP */
  float         duty_cycle;             /* SQUARE with variable duty cycle */
  ST_PULSE      pulse_prmtr;            /* PULSE */
  float         volt_dc;                /* DC */
  ST_USER       user_prmtr;             /* USER */
} ST_F_PRMTR;

typedef union
{
  float         depth;                  /* AM depth */
  double        fm_deviation;           /* FM peak deviation */
  double        pm_deviation;           /* PM deviation */
} ST_M_PRMTR;

/* The CARRIER structure - defines the control setting for non-modulated or carrier waveform;
   channel recognized */

typedef struct
{
  double                            frequency;          /* frequency in channel or common frequency */
  double                            phase;              /* phase in channel */
  float                             amplitude;          /* amplitude in channel */
  float                             offset;             /* offset in channel */
  /* eFUNCTION */ unsigned short    function;           /* function shape in channel */
  ST_F_PRMTR                        function_prmtr;     /* parameter(s) of the function shape */
} ST_CARRIER, *P_ST_CARRIER;

/* The MODULATION structure - defines the control setting for the AM, FM or PM modulation;
   channel recognized */

typedef struct
{
  unsigned short                    type;       /* AM=1, FM=2, PM=3 */
  unsigned short                    points;     /* modulation points */
  double                            frequency;  /* modulating frequency */
  /* eFUNCTION */ unsigned short    shape;      /* modulating function */
  ST_M_PRMTR                        prmtr;      /* depth or deviation */
  /* eSTATE */ unsigned short       state;      /* modulation state */
} ST_MODULATION, *P_ST_MODULATION;

/* The SWEEP structure - defines the control setting for the sweep */

typedef struct
{
  double                                startf;     /* start frequency */
  double                                stopf;      /* stop frequency */
  float                                 time;       /* sweep time */
  /* eDIRECTION */ unsigned short       direction;  /* sweep direction */
  /* eSWEEP_SPACING */ unsigned short   spacing;    /* sweep spacing */
  unsigned short                        points;     /* sweep points */
  /* eSTATE */ unsigned short           state;      /* sweep state */
} ST_SWEEP, *P_ST_SWEEP;

/* The DEVICE_CFG structure - defines the control setting for the global configuration of the module */

typedef struct
{
  unsigned short                        device_cfg;         /* 0 - common frequency */
                                                            /* 1 - two independent frequencies, channels */

  double                                frequency_1;        /* frequency in channel I or common frequency */
  double                                phase_1;            /* phase in channel I */
  float                                 volt_1_amplitude;   /* amplitude in channel I */
  float                                 volt_1_offset;      /* offset in channel I */
  /* eFUNCTION */ unsigned short        func_1;               /* function in channel I */
  double                                frequency_2;        /* frequency in channel Q */
  double                                phase_2;            /* phase in channel Q */
  float                                 volt_2_amplitude;   /* amplitude in channel Q */
  float                                 volt_2_offset;      /* offset in channel Q */
  /* eFUNCTION */ unsigned short        func_2;                /* function in channel Q */

  float                                 symmetry_1;         /* symmetry in channel I */
  float                                 symmetry_2;         /* symmetry in channel Q */

  float                                 dcyc_1;             /* duty cycle in channel I */
  float                                 dcyc_2;             /* duty cycle in channel Q */

  double                                pulse_period;       /* pulse period */
  double                                pulse_width;        /* pulse width */
  /* ePOLARITY */ unsigned short        pulse_polarity_1;   /* pulse polarity in channel I */
  /* ePOLARITY */ unsigned short        pulse_polarity_2;   /* pulse polarity in channel Q */

  float                                 volt_1_dc;          /* DC voltage in channel I */
  float                                 volt_2_dc;          /* DC voltage in channel Q */

  unsigned long                         arb_data_points;    /* the number of generated points */
  unsigned long                         arb_1_data_start;   /* arbitrary start address in channel I */
  unsigned long                         arb_2_data_start;   /* arbitrary start address in channel Q */
  unsigned long                         arb_1_data_stop;    /* arbitrary stop address in channel I */
  unsigned long                         arb_2_data_stop;    /* arbitrary stop address in channel Q */
  double                                arb_data_rate;      /* arbitrary sample rate */
  /* eSRATE_MODE */ unsigned short      arb_data_rate_mode; /* sample rate mode */

  /* eSTATE */ unsigned short           filt_1_auto;        /* auto selection of the path filter type in channel I */
  /* eSTATE */ unsigned short           filt_1_external;    /* selection of the external filter in channel I */
  /* eFILTER_TYPE */ unsigned short     filt_1_type;        /* selection of the path filter type in channel I */
  /* eOUTFILT_STATE */ unsigned short   filt_1_out;         /* state of the output filter in channel I */
  /* eSTATE */ unsigned short           filt_2_auto;        /* auto selection of the path filter type in channel Q */
  /* eSTATE */ unsigned short           filt_2_external;    /* selection of the external filter in channel Q */
  /* eFILTER_TYPE */ unsigned short     filt_2_type;        /* selection of the path filter type in channel Q */
  /* eOUTFILT_STATE */ unsigned short   filt_2_out;         /* state of the output filter in channel Q */

  /* ePOLARITY */ unsigned short        sync_1_polarity;    /* polarity of the sync signal in channel I */
  /* eSYNC_TYPE */ unsigned short       sync_1_type;        /* type of the synchronization in channel I */
  /* eSTATE */ unsigned short           sync_1_state;       /* state of the SYNC I output */
  /* ePOLARITY */ unsigned short        sync_2_polarity;    /* polarity of the sync signal in channel Q */
  /* eSYNC_TYPE */ unsigned short       sync_2_type;        /* type of the synchronization in channel Q */
  /* eSTATE */ unsigned short           sync_2_state;       /* state of the SYNC Q output */

  double                                trig_delay;         /* trigger delay */
  double                                trig_gate;          /* time of gated trigger event  */
  /* eTRIGGER_SLOPE */ unsigned short   trig_slope;         /* trigger slope */
  /* eTRIGGER_SOURCE */ unsigned short  trig_source;        /* source of trigger */
  /* eGATE_FUNCTION */ unsigned short   gate_function;      /* gate function */

  /* eSTATE */ unsigned short           outp_1_state;       /* state of the signal output in channel I */
  /* eSTATE */ unsigned short           outp_2_state;       /* state of the signal output in channel Q */
  /* eSTATE */ unsigned short           output_sum;         /* selection of the I+Q mode */

  double                                rosc_ext_frequency; /* frequency of the external reference oscillator */
  /* eRSOURCE */ unsigned short         rosc_source;        /* source of the reference oscillator */
  /* eSTATE */ unsigned short           rosc_state;         /* state of the REF OSC output */

  double                                start_frequency;    /* start frequency */
  double                                stop_frequency;     /* stop frequency */
  float                                 sweep_time;         /* sweep time */
  /* eDIRECTION */ unsigned short       sweep_direction;    /* sweep direction */
  /* eSWEEP_SPACING */ unsigned short   sweep_spacing;      /* sweep spacing */
  unsigned short                        sweep_points;       /* sweep points */
  /* eSTATE */ unsigned short           sweep_state;        /* sweep state */

  /* eSTATE */ unsigned short           marker_state;       /* marker state */
  double                                marker_frequency;   /* marker frequency */

  unsigned short                        modulation_points;  /* modulation points */

  double                                am_frequency;       /* modulating frequency */
  /* eFUNCTION */ unsigned short        am_1_func;          /* modulating function in channel I */
  float                                 am_1_depth;         /* modulation depth in channel I */
  /* eSTATE */ unsigned short           am_1_state;         /* modulation state in channel I */
  /* eFUNCTION */ unsigned short        am_2_func;          /* modulating function in channel Q */
  float                                 am_2_depth;         /* modulation depth in channel Q */
  /* eSTATE */ unsigned short           am_2_state;         /* modulation state in channel Q */

  double                                fm_frequency;       /* modulating frequency */
  /* eFUNCTION */ unsigned short        fm_func;            /* modulating function */
  double                                fm_peak_deviation;  /* peak frequency deviation */
  /* eSTATE */ unsigned short           fm_state;           /* modulation state */

  double                                pm_frequency;       /* modulating frequency */
  /* eFUNCTION */ unsigned short        pm_1_func;          /* modulating function in channel I */
  double                                pm_1_deviation;     /* phase deviation in channel I */
  /* eSTATE */ unsigned short           pm_1_state;         /* modulation state in channel I */
  /* eFUNCTION */ unsigned short        pm_2_func;          /* modulating function in channel Q */
  double                                pm_2_deviation;     /* phase deviation in channel Q */
  /* eSTATE */ unsigned short           pm_2_state;         /* modulation state in channel Q */

  double                                bm_rate;            /* burst rate */
  unsigned short                        bm_count;           /* burst count */
  /* eBSOURCE */ unsigned short         bm_source;          /* burst source */
  /* eSTATE */ unsigned short           bm_state;           /* burst state */

  double                                fsk_frequency;      /* FSK hop frequency */
  double                                fsk_rate;           /* FSK rate */
  /* eSOURCE */ unsigned short          fsk_source;         /* FSK source */
  /* eSTATE */ unsigned short           fsk_state;          /* FSK state */

  double                                psk_rate;           /* PSK rate */
  /* eSOURCE */ unsigned short          psk_source;         /* PSK source */
  double                                psk_1_phase;        /* PSK hop phase in channel I */
  /* eSTATE */ unsigned short           psk_1_state;        /* PSK state in channel I */
  double                                psk_2_phase;        /* PSK hop phase in channel Q */
  /* eSTATE */ unsigned short           psk_2_state;        /* PSK state in channel Q */
} ST_DEVICE_CFG, *P_ST_DEVICE_CFG;

/* TSStatusDataRanges is used to track session dependent status/ranges/data */
typedef struct {
    ViInt32                     instrModel;
    ViInt32                     instrOption;
    ViBoolean                   errorChecking;
    ViChar                      instrDriverRevision[256];
    /* - */
    ST_CARRIER                  carrier;
    ST_MODULATION               modulation;
    ST_SWEEP                    sweep;
    ST_DEVICE_CFG               deviceCfg;
    /* - */
    ViInt16                     activeChannel;
    ViInt16                     channelCoupling;
    /* - */
    ViReal32                    voltageHigh[2];
    ViReal32                    voltageLow[2];
    /* - */
    ViReal64                    outputLoad[2];
    ViInt16                     outputVoltageUnit;
    /* - */
    ViUInt16                    errorCount;
    TSStringErrorPair           errorQueue[MAX_ERROR_QUEUE_LENGTH];
} TSStatusDataRanges, *pTSStatusDataRanges;

/*****************************************************************************/
/*= Global data =============================================================*/
/*****************************************************************************/

/*--- "CARRIER_FUNCTION" ----------------------------------------------------*/

static TSDiscreteValue          GSCarrierFunctionDiscVals[] =
{
    {RSSIAM_OUTPUT_FUNC_SIN,                0,  ""},  /* SINUSOID */
    {RSSIAM_OUTPUT_FUNC_SQU,                7,  ""},  /* SQUARE */
    {RSSIAM_OUTPUT_FUNC_TRI,                1,  ""},  /* TRIANGLE */
    {RSSIAM_OUTPUT_FUNC_RAMP,               2,  ""},  /* RAMP (variable symmetry) */
    {RSSIAM_OUTPUT_FUNC_NOIS,               6,  ""},  /* NOISE */
    {RSSIAM_OUTPUT_FUNC_DC,                 9,  ""},  /* DC */
    {RSSIAM_OUTPUT_FUNC_USER,               10, ""},  /* USER */
    {RSSIAM_OUTPUT_FUNC_SQUARE,             3,  ""},  /* SQUARE (variable duty cycle) */
    {RSSIAM_OUTPUT_FUNC_REXP,               4,  ""},  /* REXP */
    {RSSIAM_OUTPUT_FUNC_FEXP,               5,  ""},  /* FEXP */
    {RSSIAM_OUTPUT_FUNC_PULSE,              8,  ""},  /* PULSE */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSModOneSelRangeTable = {RSSIAM_OUTPUT_FUNC_SIN,
                                                         RSSIAM_OUTPUT_FUNC_SIN,
                                                         RSSIAM_OUTPUT_FUNC_PULSE,
                                                         GSCarrierFunctionDiscVals};

/*--- "RAMP_SYMMETRY" -------------------------------------------------------*/

static TSRangeTableEntry        GSRampSymmetryRangeTable = {0.0, 100.0, 100.0, NULL};

/*--- "DUTY_CYCLE" ----------------------------------------------------------*/

static TSRangeTableEntry        GSDutyCycleRangeTable = {0.0, 50.0, 100.0, NULL};

/*--- "PULSE_PERIOD" --------------------------------------------------------*/

static TSRangeTableEntry        GSPulsePeriodRangeTable = {20.0e-9, 0.001, 9999.0, NULL};

/*--- "PULSE_WIDTH" ---------------------------------------------------------*/

static TSRangeTableEntry        GSPulseWidthRangeTable = {10.0e-9, 0.0005, 9999.0, NULL};

/*--- "PULSE_POLARITY" ------------------------------------------------------*/

static TSDiscreteValue          GSPulsePolarityDiscVals[] =
{
    {RSSIAM_PULSE_POLARITY_NORMAL,          0,  ""},  /* Normal */
    {RSSIAM_PULSE_POLARITY_INVERTED,        1,  ""},  /* Inverted */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSPulsePolarityRangeTable = {RSSIAM_PULSE_POLARITY_NORMAL,
                                                             RSSIAM_PULSE_POLARITY_NORMAL,
                                                             RSSIAM_PULSE_POLARITY_INVERTED,
                                                             GSPulsePolarityDiscVals};

/*--- "CARRIER_FREQUENCY" ---------------------------------------------------*/

static TSRangeTableEntry        GSCarrierFrequencyRangeTable = {10.0e-6, 1000.0, 50.0e6, NULL};

    //
    // TODO: Frequency ranges of carrier waveform dependencies ...
    //

/*--- "START_PHASE" ---------------------------------------------------------*/

static TSRangeTableEntry        GSStartPhaseRangeTable = {-180.0, 0.0, 180.0, NULL};

/*--- "VOLTAGE_AMPLITUDE" ---------------------------------------------------*/

static TSRangeTableEntry        GSVoltageAmplitudeRangeTable = {0.001, 1.0, 10.0, NULL};

/*--- "VOLTAGE_OFFSET" ------------------------------------------------------*/

static TSRangeTableEntry        GSVoltageOffsetRangeTable = {-5.0, 0.0, 5.0, NULL};

/*--- "VOLTAGE_DC" ----------------------------------------------------------*/

static TSRangeTableEntry        GSVoltageDCRangeTable = {-5.0, 0.0, 5.0, NULL};

/*--- "FILTER_TYPE" ---------------------------------------------------------*/

static TSDiscreteValue          GSFilterTypeDiscVals[] =
{
    {RSSIAM_OUTPUT_FILTER_TYPE_CAUER ,      0, ""},  /* Cauer 35 MHz */
    {RSSIAM_OUTPUT_FILTER_TYPE_BESSEL10,    1, ""},  /* Bessel 37 MHz */
    {RSSIAM_OUTPUT_FILTER_TYPE_BESSEL75,    2, ""},  /* Bessel 75 MHz */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSFilterTypeRangeTable = {RSSIAM_OUTPUT_FILTER_TYPE_CAUER,
                                                          RSSIAM_OUTPUT_FILTER_TYPE_CAUER,
                                                          RSSIAM_OUTPUT_FILTER_TYPE_BESSEL75,
                                                          GSFilterTypeDiscVals};

/*--- "FILTER_EXTERNAL" -----------------------------------------------------*/

static TSDiscreteValue          GSFilterExternalDiscVals[] =
{
    {RSSIAM_OUTPUT_EXT_FILTER_OFF,          0, ""},  /* Off */
    {RSSIAM_OUTPUT_EXT_FILTER_ON,           1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSFilterExternalRangeTable = {RSSIAM_OUTPUT_EXT_FILTER_OFF,
                                                              RSSIAM_OUTPUT_EXT_FILTER_OFF,
                                                              RSSIAM_OUTPUT_EXT_FILTER_ON,
                                                              GSFilterExternalDiscVals};

/*--- "FILTER_AUTO" ---------------------------------------------------------*/

static TSDiscreteValue          GSFilterAutoDiscVals[] =
{
    {RSSIAM_OUTPUT_FILTER_AUTO_OFF,         0, ""},  /* Off */
    {RSSIAM_OUTPUT_FILTER_AUTO_ON,          1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSFilterAutoRangeTable = {RSSIAM_OUTPUT_FILTER_AUTO_OFF,
                                                          RSSIAM_OUTPUT_FILTER_AUTO_OFF,
                                                          RSSIAM_OUTPUT_FILTER_AUTO_ON,
                                                          GSFilterAutoDiscVals};

/*--- "OUTPUT_FILTER" -------------------------------------------------------*/

static TSDiscreteValue          GSOutputFilterDiscVals[] =
{
    {RSSIAM_OUTPUT_FILTER_OFF,              0, ""},  /* Off */
    {RSSIAM_OUTPUT_FILTER_ON,               1, ""},  /* On */
    {RSSIAM_OUTPUT_FILTER_AUTO,             2, ""},  /* Auto */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSOutputFilterRangeTable = {RSSIAM_OUTPUT_FILTER_OFF,
                                                            RSSIAM_OUTPUT_FILTER_OFF,
                                                            RSSIAM_OUTPUT_FILTER_AUTO,
                                                            GSOutputFilterDiscVals};

/*--- "OUTPUT_STATE" --------------------------------------------------------*/

static TSDiscreteValue          GSOutputStateDiscVals[] =
{
    {RSSIAM_OUTPUT_SETUP_OFF,               0, ""},  /* Off */
    {RSSIAM_OUTPUT_SETUP_ON,                1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSOutputStateRangeTable = {RSSIAM_OUTPUT_SETUP_OFF,
                                                           RSSIAM_OUTPUT_SETUP_OFF,
                                                           RSSIAM_OUTPUT_SETUP_ON,
                                                           GSOutputStateDiscVals};

/*--- "OUTPUT_SUM" ----------------------------------------------------------*/

static TSDiscreteValue          GSOutputSumDiscVals[] =
{
    {RSSIAM_OUTPUT_SUM_OFF,                 0, ""},  /* Off */
    {RSSIAM_OUTPUT_SUM_ON,                  1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSOutputSumRangeTable = {RSSIAM_OUTPUT_SUM_OFF,
                                                         RSSIAM_OUTPUT_SUM_OFF,
                                                         RSSIAM_OUTPUT_SUM_ON,
                                                         GSOutputSumDiscVals};

/*--- "SYNC_POLARITY" -------------------------------------------------------*/

static TSDiscreteValue          GSSyncPolarityDiscVals[] =
{
    {RSSIAM_SYNC_POLARITY_NORMAL,           0, ""},  /* Normal */
    {RSSIAM_SYNC_POLARITY_INVERTED,         1, ""},  /* Inverted */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSSyncPolarityRangeTable = {RSSIAM_SYNC_POLARITY_NORMAL,
                                                            RSSIAM_SYNC_POLARITY_NORMAL,
                                                            RSSIAM_SYNC_POLARITY_INVERTED,
                                                            GSSyncPolarityDiscVals};

/*--- "SYNC_TYPE" -----------------------------------------------------------*/

static TSDiscreteValue          GSSyncTypeDiscVals[] =
{
    {RSSIAM_SYNC_TYPE_COMP,                 0, ""},  /* COMP */
    {RSSIAM_SYNC_TYPE_CARRY,                1, ""},  /* CARRY */
    {RSSIAM_SYNC_TYPE_TRIG,                 2, ""},  /* TRIG */
    {RSSIAM_SYNC_TYPE_MOD,                  3, ""},  /* MOD */
    {RSSIAM_SYNC_TYPE_MFRQ,                 4, ""},  /* MFRQ */
    {RSSIAM_SYNC_TYPE_MWFM,                 5, ""},  /* MWFM */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSSyncTypeRangeTable = {RSSIAM_SYNC_TYPE_COMP,
                                                        RSSIAM_SYNC_TYPE_COMP,
                                                        RSSIAM_SYNC_TYPE_MWFM,
                                                        GSSyncTypeDiscVals};

/*--- "SYNC_STATE" ----------------------------------------------------------*/

static TSDiscreteValue          GSSyncStateDiscVals[] =
{
    {RSSIAM_OUTPUT_SYNC_OFF,                0, ""},  /* Off */
    {RSSIAM_OUTPUT_SYNC_ON,                 1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSSyncStateRangeTable = {RSSIAM_OUTPUT_SYNC_OFF,
                                                         RSSIAM_OUTPUT_SYNC_OFF,
                                                         RSSIAM_OUTPUT_SYNC_ON,
                                                         GSSyncStateDiscVals};

/*--- "ARB_DATA_DAC_LOAD" ---------------------------------------------------*/

static TSRangeTableEntry        GSArbDataDACLoadRangeTable = {0, 0, 0, NULL};

/*--- "ARB_DATA_POINTS" -----------------------------------------------------*/

static TSRangeTableEntry        GSArbDataPointsRangeTable = {16, 16, 262144, NULL};

/*--- "ARB_DATA_START" ------------------------------------------------------*/

static TSRangeTableEntry        GSArbDataStartRangeTable = {0, 0, 262143, NULL};

/*--- "ARB_DATA_STOP" -------------------------------------------------------*/

static TSRangeTableEntry        GSArbDataStopRangeTable = {0, 262143, 262143, NULL};

/*--- "ARB_DATA_SAMPLE_RATE" ------------------------------------------------*/

static TSRangeTableEntry        GSArbDataSampleRateRangeTable = {10.0e-9, 10.0e-9, 1.0e5, NULL};

/*--- "ARB_DATA_RATE_MODE" --------------------------------------------------*/

static TSDiscreteValue          GSArbDataRateModeDiscVals[] =
{
    {RSSIAM_ARB_RATE_MODE_NORMAL,           0, ""},  /* Normal */
    {RSSIAM_ARB_RATE_MODE_ACCURATE,         1, ""},  /* Sample Accurate */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSArbDataRateModeRangeTable = {RSSIAM_ARB_RATE_MODE_NORMAL,
                                                               RSSIAM_ARB_RATE_MODE_NORMAL,
                                                               RSSIAM_ARB_RATE_MODE_ACCURATE,
                                                               GSArbDataRateModeDiscVals};

/*--- "AM_FUNCTION" ---------------------------------------------------------*/

static TSDiscreteValue          GSAMFunctionDiscVals[] =
{
    {RSSIAM_AMP_INT_FUNC_SIN,               0,  ""},  /* Sinusoid */
    {RSSIAM_AMP_INT_FUNC_SQU,               7,  ""},  /* Square */
    {RSSIAM_AMP_INT_FUNC_TRI,               1,  ""},  /* Triangle */
    {RSSIAM_AMP_INT_FUNC_URAMP,             2,  ""},  /* Ramp (Up) */
    {RSSIAM_AMP_INT_FUNC_DRAMP,             3,  ""},  /* Ramp (Down) */
    {RSSIAM_AMP_INT_FUNC_USER,              10, ""},  /* User */
    {RSSIAM_AMP_INT_FUNC_REXP,              4,  ""},  /* Reverse Exponential */
    {RSSIAM_AMP_INT_FUNC_FEXP,              5,  ""},  /* Forward Exponential */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSAMFunctionRangeTable = {RSSIAM_AMP_INT_FUNC_SIN,
                                                          RSSIAM_AMP_INT_FUNC_SIN,
                                                          RSSIAM_AMP_INT_FUNC_FEXP,
                                                          GSAMFunctionDiscVals};

/*--- "AM_FREQUENCY" --------------------------------------------------------*/

static TSRangeTableEntry        GSAMFrequencyRangeTable = {10.0e-3, 1000.0, 100.0e3, NULL};

/*--- "AM_DEPTH" ------------------------------------------------------------*/

static TSRangeTableEntry        GSAMDepthRangeTable = {0.0, 100.0, 100.0, NULL};

/*--- "AM_STATE" ------------------------------------------------------------*/

static TSDiscreteValue          GSAMStateDiscVals[] =
{
    {RSSIAM_AMP_STAT_OFF,                   0, ""},  /* Off */
    {RSSIAM_AMP_STAT_ON,                    1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSAMStateRangeTable = {RSSIAM_AMP_STAT_OFF,
                                                       RSSIAM_AMP_STAT_OFF,
                                                       RSSIAM_AMP_STAT_ON,
                                                       GSAMStateDiscVals};

/*--- "FM_FUNCTION" ---------------------------------------------------------*/

static TSDiscreteValue          GSFMFunctionDiscVals[] =
{
    {RSSIAM_FREQ_INT_FUNC_SIN,              0,  ""},  /* Sinusoid */
    {RSSIAM_FREQ_INT_FUNC_SQU,              7,  ""},  /* Square */
    {RSSIAM_FREQ_INT_FUNC_TRI,              1,  ""},  /* Triangle */
    {RSSIAM_FREQ_INT_FUNC_URAMP,            2,  ""},  /* Ramp (Up) */
    {RSSIAM_FREQ_INT_FUNC_DRAMP,            3,  ""},  /* Ramp (Down) */
    {RSSIAM_FREQ_INT_FUNC_USER,             10, ""},  /* User */
    {RSSIAM_FREQ_INT_FUNC_REXP,             4,  ""},  /* Reverse Exponential */
    {RSSIAM_FREQ_INT_FUNC_FEXP,             5,  ""},  /* Forward Exponential */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSFMFunctionRangeTable = {RSSIAM_FREQ_INT_FUNC_SIN,
                                                          RSSIAM_FREQ_INT_FUNC_SIN,
                                                          RSSIAM_FREQ_INT_FUNC_FEXP,
                                                          GSFMFunctionDiscVals};

/*--- "FM_FREQUENCY" --------------------------------------------------------*/

static TSRangeTableEntry        GSFMFrequencyRangeTable = {10.0e-3, 1000.0, 100.0e3, NULL};

/*--- "FM_PEAK_DEVIATION" ---------------------------------------------------*/

static TSRangeTableEntry        GSFMPeakDeviationRangeTable = {10.0e-3, 999.9, 100.0e3, NULL};

/*--- "FM_STATE" ------------------------------------------------------------*/

static TSDiscreteValue          GSFMStateDiscVals[] =
{
    {RSSIAM_FREQ_STAT_OFF,                  0, ""},  /* Off */
    {RSSIAM_FREQ_STAT_ON,                   1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSFMStateRangeTable = {RSSIAM_FREQ_STAT_OFF,
                                                       RSSIAM_FREQ_STAT_OFF,
                                                       RSSIAM_FREQ_STAT_ON,
                                                       GSFMStateDiscVals};

/*--- "PM_FUNCTION" ---------------------------------------------------------*/

static TSDiscreteValue          GSPMFunctionDiscVals[] =
{
    {RSSIAM_PHASE_INT_FUNC_SIN,             0,  ""},  /* Sinusoid */
    {RSSIAM_PHASE_INT_FUNC_SQU,             7,  ""},  /* Square */
    {RSSIAM_PHASE_INT_FUNC_TRI,             1,  ""},  /* Triangle */
    {RSSIAM_PHASE_INT_FUNC_URAMP,           2,  ""},  /* Ramp (Up) */
    {RSSIAM_PHASE_INT_FUNC_DRAMP,           3,  ""},  /* Ramp (Down) */
    {RSSIAM_PHASE_INT_FUNC_USER,            10, ""},  /* User */
    {RSSIAM_PHASE_INT_FUNC_REXP,            4,  ""},  /* Reverse Exponential */
    {RSSIAM_PHASE_INT_FUNC_FEXP,            5,  ""},  /* Forward Exponential */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSPMFunctionRangeTable = {RSSIAM_PHASE_INT_FUNC_SIN,
                                                          RSSIAM_PHASE_INT_FUNC_SIN,
                                                          RSSIAM_PHASE_INT_FUNC_FEXP,
                                                          GSPMFunctionDiscVals};

/*--- "PM_FREQUENCY" --------------------------------------------------------*/

static TSRangeTableEntry        GSPMFrequencyRangeTable = {10.0e-3, 1000.0, 100.0e3, NULL};

/*--- "PM_DEVIATION" --------------------------------------------------------*/

static TSRangeTableEntry        GSPMDeviationRangeTable = {-180.0, 180.0, 180.0, NULL};

/*--- "PM_STATE" ------------------------------------------------------------*/

static TSDiscreteValue          GSPMStateDiscVals[] =
{
    {RSSIAM_PHASE_STAT_OFF,                 0, ""},  /* Off */
    {RSSIAM_PHASE_STAT_ON,                  1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSPMStateRangeTable = {RSSIAM_PHASE_STAT_OFF,
                                                       RSSIAM_PHASE_STAT_OFF,
                                                       RSSIAM_PHASE_STAT_ON,
                                                       GSPMStateDiscVals};

/*--- "BM_RATE" -------------------------------------------------------------*/

static TSRangeTableEntry        GSBMRateRangeTable = {500.0e-9, 0.001, 9999.0, NULL};

/*--- "BM_COUNT" ------------------------------------------------------------*/

static TSRangeTableEntry        GSBMCountRangeTable = {1, 1, 65535, NULL};

/*--- "BM_SOURCE" -----------------------------------------------------------*/

static TSDiscreteValue          GSBMSourceDiscVals[] =
{
    {RSSIAM_BM_SOUR_TRIG,                   0, ""},  /* Triggered */
    {RSSIAM_BM_SOUR_INT,                    1, ""},  /* Int Gated */
    {RSSIAM_BM_SOUR_EXT,                    2, ""},  /* Ext Gated */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSBMSourceRangeTable = {RSSIAM_BM_SOUR_TRIG,
                                                        RSSIAM_BM_SOUR_TRIG,
                                                        RSSIAM_BM_SOUR_EXT,
                                                        GSBMSourceDiscVals};

/*--- "BM_STATE" ------------------------------------------------------------*/

static TSDiscreteValue          GSBMStateDiscVals[] =
{
    {RSSIAM_BM_STAT_OFF,                    0, ""},  /* Off */
    {RSSIAM_BM_STAT_ON,                     1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSBMStateRangeTable = {RSSIAM_BM_STAT_OFF,
                                                       RSSIAM_BM_STAT_OFF,
                                                       RSSIAM_BM_STAT_ON,
                                                       GSBMStateDiscVals};

/*--- "FSK_FREQUENCY" -------------------------------------------------------*/

static TSRangeTableEntry        GSFSKFrequencyRangeTable = {10.0e-6, 10.0e3, 50.0e6, NULL};

/*--- "FSK_RATE" ------------------------------------------------------------*/

static TSRangeTableEntry        GSFSKRateRangeTable = {500.0e-9, 0.001, 9999.0, NULL};

/*--- "FSK_SOURCE" ----------------------------------------------------------*/

static TSDiscreteValue          GSFSKSourceDiscVals[] =
{
    {RSSIAM_FSK_SOUR_INT,                   0, ""},  /* Internal */
    {RSSIAM_FSK_SOUR_EXT,                   1, ""},  /* External */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSFSKSourceRangeTable = {RSSIAM_FSK_SOUR_INT,
                                                         RSSIAM_FSK_SOUR_INT,
                                                         RSSIAM_FSK_SOUR_EXT,
                                                         GSFSKSourceDiscVals};

/*--- "FSK_STATE" -----------------------------------------------------------*/

static TSDiscreteValue          GSFSKStateDiscVals[] =
{
    {RSSIAM_FSK_STAT_OFF,                   0, ""},  /* Off */
    {RSSIAM_FSK_STAT_ON,                    1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSFSKStateRangeTable = {RSSIAM_FSK_STAT_OFF,
                                                        RSSIAM_FSK_STAT_OFF,
                                                        RSSIAM_FSK_STAT_ON,
                                                        GSFSKStateDiscVals};

/*--- "PSK_PHASE" -----------------------------------------------------------*/

static TSRangeTableEntry        GSPSKPhaseRangeTable = {0.0, 180.0, 360.0, NULL};

/*--- "PSK_RATE" ------------------------------------------------------------*/

static TSRangeTableEntry        GSPSKRateRangeTable = {500.0e-9, 0.001, 9999.0, NULL};

/*--- "PSK_SOURCE" ----------------------------------------------------------*/

static TSDiscreteValue          GSPSKSourceDiscVals[] =
{
    {RSSIAM_PSK_SOUR_INT,                   0, ""},  /* Internal */
    {RSSIAM_PSK_SOUR_EXT,                   1, ""},  /* External */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSPSKSourceRangeTable = {RSSIAM_PSK_SOUR_INT,
                                                         RSSIAM_PSK_SOUR_INT,
                                                         RSSIAM_PSK_SOUR_EXT,
                                                         GSPSKSourceDiscVals};

/*--- "PSK_STATE" -----------------------------------------------------------*/

static TSDiscreteValue          GSPSKStateDiscVals[] =
{
    {RSSIAM_PSK_STAT_OFF,                   0, ""},  /* Off */
    {RSSIAM_PSK_STAT_ON,                    1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSPSKStateRangeTable = {RSSIAM_PSK_STAT_OFF,
                                                        RSSIAM_PSK_STAT_OFF,
                                                        RSSIAM_PSK_STAT_ON,
                                                        GSPSKStateDiscVals};

/*--- "FREQUENCY_MODE" ------------------------------------------------------*/

static TSDiscreteValue          GSFrequencyModeDiscVals[] =
{
    {RSSIAM_FREQUENCY_MODE_CW,              0, ""},  /* CW */
    {RSSIAM_FREQUENCY_MODE_FIXED,           1, ""},  /* FIXED */
    {RSSIAM_FREQUENCY_MODE_SWEEP,           2, ""},  /* SWEEP */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSFrequencyModeRangeTable = {RSSIAM_FREQUENCY_MODE_CW,
                                                             RSSIAM_FREQUENCY_MODE_CW,
                                                             RSSIAM_FREQUENCY_MODE_SWEEP,
                                                             GSFrequencyModeDiscVals};

/*--- "START_FREQUENCY" -----------------------------------------------------*/

static TSRangeTableEntry        GSStartFrequencyRangeTable = {0.1, 1.0, 50.0e6, NULL};

/*--- "STOP_FREQUENCY" ------------------------------------------------------*/

static TSRangeTableEntry        GSStopFrequencyRangeTable = {0.1, 250.0e3, 50.0e6, NULL};

/*--- "SWEEP_TIME" ----------------------------------------------------------*/

static TSRangeTableEntry        GSSweepTimeRangeTable = {0.001, 0.001, 999.0, NULL};

/*--- "SWEEP_DIRECTION" -----------------------------------------------------*/

static TSDiscreteValue          GSSweepDirectionDiscVals[] =
{
    {RSSIAM_SWEEP_DIRECTION_UP,             0, ""},  /* Up */
    {RSSIAM_SWEEP_DIRECTION_DOWN,           1, ""},  /* Down */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSSweepDirectionRangeTable = {RSSIAM_SWEEP_DIRECTION_UP,
                                                              RSSIAM_SWEEP_DIRECTION_UP,
                                                              RSSIAM_SWEEP_DIRECTION_DOWN,
                                                              GSSweepDirectionDiscVals};

/*--- "SWEEP_SPACING" -------------------------------------------------------*/

static TSDiscreteValue          GSSweepSpacingDiscVals[] =
{
    {RSSIAM_SWEEP_SPAC_LIN,                 0, ""},  /* Linear */
    {RSSIAM_SWEEP_SPAC_LOG,                 1, ""},  /* Logarithmic */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSSweepSpacingRangeTable = {RSSIAM_SWEEP_SPAC_LIN,
                                                            RSSIAM_SWEEP_SPAC_LIN,
                                                            RSSIAM_SWEEP_SPAC_LOG,
                                                            GSSweepSpacingDiscVals};

/*--- "SWEEP_POINTS" --------------------------------------------------------*/

static TSRangeTableEntry        GSSweepPointsRangeTable = {1, 1024, 4096, NULL};

/*--- "MARKER_FREQUENCY" ----------------------------------------------------*/

static TSRangeTableEntry        GSMarkerFrequencyRangeTable = {0.1, 1.0, 50.0e6, NULL};

/*--- "MARKER_STATE" --------------------------------------------------------*/

static TSDiscreteValue          GSMarkerStateDiscVals[] =
{
    {RSSIAM_MARKER_STAT_OFF,                0, ""},  /* Off */
    {RSSIAM_MARKER_STAT_ON,                 1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSMarkerStateRangeTable = {RSSIAM_MARKER_STAT_OFF,
                                                           RSSIAM_MARKER_STAT_OFF,
                                                           RSSIAM_MARKER_STAT_ON,
                                                           GSMarkerStateDiscVals};

/*--- "ROSC_SOURCE" ---------------------------------------------------------*/

static TSDiscreteValue          GSRoscSourceDiscVals[] =
{
    {RSSIAM_ROSC_TCXO,                      0, ""},  /* TCXO */
//    {RSSIAM_ROSC_OCXO,                      1, ""},  /* OCXO */
    {RSSIAM_ROSC_EXT,                       2, ""},  /* External */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSRoscSourceRangeTable = {RSSIAM_ROSC_TCXO,
                                                          RSSIAM_ROSC_TCXO,
                                                          RSSIAM_ROSC_EXT,
                                                          GSRoscSourceDiscVals};

/*--- "ROSC_STATE" ----------------------------------------------------------*/

static TSDiscreteValue          GSRoscStateDiscVals[] =
{
    {RSSIAM_ROSC_STAT_OFF,                  0, ""},  /* Off */
    {RSSIAM_ROSC_STAT_ON,                   1, ""},  /* On */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSRoscStateRangeTable = {RSSIAM_ROSC_STAT_OFF,
                                                         RSSIAM_ROSC_STAT_OFF,
                                                         RSSIAM_ROSC_STAT_ON,
                                                         GSRoscStateDiscVals};

/*--- "TRIGGER_DELAY" -------------------------------------------------------*/

static TSRangeTableEntry        GSTriggerDelayRangeTable = {0.0, 0.0, 9999.0, NULL};

/*--- "TRIGGER_SLOPE" -------------------------------------------------------*/

static TSDiscreteValue          GSTriggerSlopeDiscVals[] =
{
    {RSSIAM_TRIGGER_SLOPE_POS,              0, ""},  /* Positive */
    {RSSIAM_TRIGGER_SLOPE_NEG,              1, ""},  /* Negative */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSTriggerSlopeRangeTable = {RSSIAM_TRIGGER_SLOPE_POS,
                                                            RSSIAM_TRIGGER_SLOPE_POS,
                                                            RSSIAM_TRIGGER_SLOPE_NEG,
                                                            GSTriggerSlopeDiscVals};

/*--- "TRIGGER_SOURCE" ------------------------------------------------------*/

static TSDiscreteValue          GSTriggerSourceDiscVals[] =
{
    {RSSIAM_TRIGGER_SOUR_IMM,               2, ""},  /* Immediate */
    {RSSIAM_TRIGGER_SOUR_EXT,               1, ""},  /* External */
    {RSSIAM_TRIGGER_SOUR_BUS,               0, ""},  /* Bus */
    {RSSIAM_TRIGGER_SOUR_SYS,               3, ""},  /* System */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSTriggerSourceRangeTable = {RSSIAM_TRIGGER_SOUR_IMM,
                                                             RSSIAM_TRIGGER_SOUR_IMM,
                                                             RSSIAM_TRIGGER_SOUR_SYS,
                                                             GSTriggerSourceDiscVals};

/*--- "GATE_INTERNAL_TIME" --------------------------------------------------*/

static TSRangeTableEntry        GSGateTimeRangeTable = {0.0, 100.0e-9, 9999.0, NULL};

/*--- "GATE_FUNCTION" -------------------------------------------------------*/

static TSDiscreteValue          GSGateFunctionDiscVals[] =
{
    {RSSIAM_GATE_SAMPLE_HOLD,               0, ""},  /* Sample & Hold */
    {RSSIAM_GATE_BLOCK_END,                 1, ""},  /* Block End */
    {0, 0, NULL}
};
static TSRangeTableEntry        GSGateFunctionRangeTable = {RSSIAM_GATE_SAMPLE_HOLD,
                                                            RSSIAM_GATE_SAMPLE_HOLD,
                                                            RSSIAM_GATE_BLOCK_END,
                                                            GSGateFunctionDiscVals};

/*--- "MODULATION_POINTS" ---------------------------------------------------*/

static TSRangeTableEntry        GSModulationPointsTable = {2, 64, 65535, NULL};

/*--- "APPLY_DEVICE_CONFIGURATION" ------------------------------------------*/

static TSRangeTableEntry     GSApplyDeviceConfigRangeTable = {0, 0, 0, NULL};

/*--- "APPLY_FUNCTION" ------------------------------------------------------*/

static TSRangeTableEntry     GSApplyFunctionRangeTable = {0, 0, 0, NULL};

/*--- "APPLY_MODULATION" ----------------------------------------------------*/

static TSRangeTableEntry     GSApplyModulationRangeTable = {0, 0, 0, NULL};

/*--- "APPLY_SWEEP" ---------------------------------------------------------*/

static TSRangeTableEntry     GSApplySweepRangeTable = {0, 0, 0, NULL};

/*--- "DEVICE_CONFIG" -------------------------------------------------------*/

 static TSRangeTableEntry     GSDeviceConfigRangeTable = {0, 0, 1, NULL};

/*--- Register Set ----------------------------------------------------------*/

static TSRegisterSetEntry GSRegisterSetTable[] =
{
    /* RegId, Name, Size, Structure, AutoRangeCap, RangeTable, Channels */

    {0x2000, "CARRIER_FUNCTION",            2,                      U16,        NULL, &GSModOneSelRangeTable,           {0x3, 0x3}},
    {0x2041, "RAMP_SYMMETRY",               4,                      FLT,        NULL, &GSRampSymmetryRangeTable,        {0x3, 0x3}},
    {0x2063, "DUTY_CYCLE",                  4,                      FLT,        NULL, &GSDutyCycleRangeTable,           {0x3, 0x3}},
    {0x2001, "PULSE_PERIOD",                8,                      DBL,        NULL, &GSPulsePeriodRangeTable,         {0x0, 0x0}},
    {0x2002, "PULSE_WIDTH",                 8,                      DBL,        NULL, &GSPulseWidthRangeTable,          {0x0, 0x3}},
    {0x2003, "PULSE_POLARITY",              2,                      U16,        NULL, &GSPulsePolarityRangeTable,       {0x3, 0x3}},
    {0x2005, "CARRIER_FREQUENCY",           8,                      DBL,        NULL, &GSCarrierFrequencyRangeTable,    {0x0, 0x3}},
    {0x2006, "START_PHASE",                 8,                      DBL,        NULL, &GSStartPhaseRangeTable,          {0x3, 0x3}},
    {0x2007, "VOLTAGE_AMPLITUDE",           4,                      FLT,        NULL, &GSVoltageAmplitudeRangeTable,    {0x3, 0x3}},
    {0x2008, "VOLTAGE_OFFSET",              4,                      FLT,        NULL, &GSVoltageOffsetRangeTable,       {0x3, 0x3}},
    {0x202F, "VOLTAGE_DC",                  4,                      FLT,        NULL, &GSVoltageDCRangeTable,           {0x3, 0x3}},
    {0x2009, "FILTER_TYPE",                 2,                      U16,        NULL, &GSFilterTypeRangeTable,          {0x3, 0x3}},
    {0x2042, "FILTER_EXTERNAL",             2,                      U16,        NULL, &GSFilterExternalRangeTable,      {0x3, 0x3}},
    {0x2043, "FILTER_AUTO",                 2,                      U16,        NULL, &GSFilterAutoRangeTable,          {0x3, 0x3}},
    {0x2056, "OUTPUT_FILTER",               2,                      U16,        NULL, &GSOutputFilterRangeTable,        {0x3, 0x3}},
    {0x2044, "OUTPUT_STATE",                2,                      U16,        NULL, &GSOutputStateRangeTable,         {0x3, 0x3}},
    {0x200A, "OUTPUT_SUM",                  2,                      U16,        NULL, &GSOutputSumRangeTable,           {0x0, 0x0}},
    {0x200B, "SYNC_POLARITY",               2,                      U16,        NULL, &GSSyncPolarityRangeTable,        {0x3, 0x3}},
    {0x2054, "SYNC_TYPE",                   2,                      U16,        NULL, &GSSyncTypeRangeTable,            {0x3, 0x3}},
    {0x2045, "SYNC_STATE",                  2,                      U16,        NULL, &GSSyncStateRangeTable,           {0x3, 0x3}},
    {0x2052, "ARB_DATA_DAC_LOAD",           2,                      U16_ARRAY,  NULL, &GSArbDataDACLoadRangeTable,      {0x3, 0x3}},
    {0x200C, "ARB_DATA_POINTS",             4,                      U32,        NULL, &GSArbDataPointsRangeTable,       {0x0, 0x0}},
    {0x200D, "ARB_DATA_START",              4,                      U32,        NULL, &GSArbDataStartRangeTable,        {0x3, 0x3}},
    {0x200E, "ARB_DATA_STOP",               4,                      U32,        NULL, &GSArbDataStopRangeTable,         {0x3, 0x3}},
    {0x200F, "ARB_DATA_SAMPLE_RATE",        8,                      DBL,        NULL, &GSArbDataSampleRateRangeTable,   {0x0, 0x0}},
    {0x2053, "ARB_DATA_RATE_MODE",          2,                      U16,        NULL, &GSArbDataRateModeRangeTable,     {0x0, 0x0}},
    {0x2012, "AM_FUNCTION",                 2,                      U16,        NULL, &GSAMFunctionRangeTable,          {0x3, 0x3}},
    {0x2013, "AM_FREQUENCY",                8,                      DBL,        NULL, &GSAMFrequencyRangeTable,         {0x0, 0x0}},
    {0x2014, "AM_DEPTH",                    4,                      FLT,        NULL, &GSAMDepthRangeTable,             {0x3, 0x3}},
    {0x2046, "AM_STATE",                    2,                      U16,        NULL, &GSAMStateRangeTable,             {0x3, 0x3}},
    {0x2015, "FM_FUNCTION",                 2,                      U16,        NULL, &GSFMFunctionRangeTable,          {0x0, 0x0}},
    {0x2016, "FM_FREQUENCY",                8,                      DBL,        NULL, &GSFMFrequencyRangeTable,         {0x0, 0x0}},
    {0x2017, "FM_PEAK_DEVIATION",           8,                      DBL,        NULL, &GSFMPeakDeviationRangeTable,     {0x0, 0x0}},
    {0x2047, "FM_STATE",                    2,                      U16,        NULL, &GSFMStateRangeTable,             {0x0, 0x0}},
    {0x2018, "PM_FUNCTION",                 2,                      U16,        NULL, &GSPMFunctionRangeTable,          {0x3, 0x3}},
    {0x2019, "PM_FREQUENCY",                8,                      DBL,        NULL, &GSPMFrequencyRangeTable,         {0x0, 0x0}},
    {0x201A, "PM_DEVIATION",                8,                      DBL,        NULL, &GSPMDeviationRangeTable,         {0x3, 0x3}},
    {0x2048, "PM_STATE",                    2,                      U16,        NULL, &GSPMStateRangeTable,             {0x3, 0x3}},
    {0x201B, "BM_RATE",                     8,                      DBL,        NULL, &GSBMRateRangeTable,              {0x0, 0x0}},
    {0x201C, "BM_COUNT",                    2,                      U16,        NULL, &GSBMCountRangeTable,             {0x0, 0x3}},
    {0x201D, "BM_SOURCE",                   2,                      U16,        NULL, &GSBMSourceRangeTable,            {0x0, 0x0}},
    {0x2049, "BM_STATE",                    2,                      U16,        NULL, &GSBMStateRangeTable,             {0x0, 0x0}},
    {0x201E, "FSK_FREQUENCY",               8,                      DBL,        NULL, &GSFSKFrequencyRangeTable,        {0x0, 0x0}},
    {0x201F, "FSK_RATE",                    8,                      DBL,        NULL, &GSFSKRateRangeTable,             {0x0, 0x0}},
    {0x2020, "FSK_SOURCE",                  2,                      U16,        NULL, &GSFSKSourceRangeTable,           {0x0, 0x0}},
    {0x2050, "FSK_STATE",                   2,                      U16,        NULL, &GSFSKStateRangeTable,            {0x0, 0x0}},
    {0x2021, "PSK_PHASE",                   8,                      DBL,        NULL, &GSPSKPhaseRangeTable,            {0x3, 0x3}},
    {0x2022, "PSK_RATE",                    8,                      DBL,        NULL, &GSPSKRateRangeTable,             {0x0, 0x0}},
    {0x2023, "PSK_SOURCE",                  2,                      U16,        NULL, &GSPSKSourceRangeTable,           {0x0, 0x0}},
    {0x2051, "PSK_STATE",                   2,                      U16,        NULL, &GSPSKStateRangeTable,            {0x3, 0x3}},
    {0x2024, "FREQUENCY_MODE",              2,                      U16,        NULL, &GSFrequencyModeRangeTable,       {0x0, 0x0}},
    {0x2025, "START_FREQUENCY",             8,                      DBL,        NULL, &GSStartFrequencyRangeTable,      {0x0, 0x0}},
    {0x2026, "STOP_FREQUENCY",              8,                      DBL,        NULL, &GSStopFrequencyRangeTable,       {0x0, 0x0}},
    {0x2027, "SWEEP_TIME",                  4,                      FLT,        NULL, &GSSweepTimeRangeTable,           {0x0, 0x0}},
    {0x2028, "SWEEP_DIRECTION",             2,                      U16,        NULL, &GSSweepDirectionRangeTable,      {0x0, 0x0}},
    {0x2029, "SWEEP_SPACING",               2,                      U16,        NULL, &GSSweepSpacingRangeTable,        {0x0, 0x0}},
    {0x202A, "SWEEP_POINTS",                2,                      U16,        NULL, &GSSweepPointsRangeTable,         {0x0, 0x0}},
    {0x202C, "MARKER_FREQUENCY",            8,                      DBL,        NULL, &GSMarkerFrequencyRangeTable,     {0x0, 0x0}},
    {0x202D, "MARKER_STATE",                2,                      U16,        NULL, &GSMarkerStateRangeTable,         {0x0, 0x0}},
    {0x2060, "ROSC_SOURCE",                 2,                      U16,        NULL, &GSRoscSourceRangeTable,          {0x0, 0x0}},
    {0x2062, "ROSC_STATE",                  2,                      U16,        NULL, &GSRoscStateRangeTable,           {0x0, 0x0}},
    {0x2030, "TRIGGER_DELAY",               8,                      DBL,        NULL, &GSTriggerDelayRangeTable,        {0x0, 0x3}},
    {0x2032, "TRIGGER_SLOPE",               2,                      U16,        NULL, &GSTriggerSlopeRangeTable,        {0x0, 0x0}},
    {0x2033, "TRIGGER_SOURCE",              2,                      U16,        NULL, &GSTriggerSourceRangeTable,       {0x0, 0x0}},
    {0x2034, "GATE_INTERNAL_TIME",          8,                      DBL,        NULL, &GSGateTimeRangeTable,            {0x0, 0x0}},
    {0x2035, "GATE_FUNCTION",               2,                      U16,        NULL, &GSGateFunctionRangeTable,        {0x0, 0x0}},
    {0x2040, "MODULATION_POINTS",           2,                      U16,        NULL, &GSModulationPointsTable,         {0x0, 0x0}},
    /* - */
    {0x2801, "APPLY_DEVICE_CONFIGURATION",  sizeof (ST_DEVICE_CFG), STRUCT,     NULL, &GSApplyDeviceConfigRangeTable,   {0x0, 0x0}},
    {0x2810, "APPLY_FUNCTION",              sizeof (ST_CARRIER),    STRUCT,     NULL, &GSApplyFunctionRangeTable,       {0x3, 0x3}},
    {0x2811, "APPLY_MODULATION",            sizeof (ST_MODULATION), STRUCT,     NULL, &GSApplyModulationRangeTable,     {0x3, 0x3}},
    {0x2812, "APPLY_SWEEP",                 sizeof (ST_SWEEP),      STRUCT,     NULL, &GSApplySweepRangeTable,          {0x0, 0x0}},
    /* - */
    {0x2F00, "DEVICE_CONFIG",               2,                      U16,        NULL, &GSDeviceConfigRangeTable,        {0x0, 0x0}},

    /* Last element */
    {0, NULL, 0, 0, 0, 0}
};

/*--- Device Capabilities ---------------------------------------------------*/

static TSDeviceCapsEntry GSDeviceCapsTable[] =
{
    /* CapsId, Name, Size, Structure, Dependency */

    /* Not applied ... */

    /* Last element */
    {0, NULL, 0, 0}
};

/*--- Command Set -----------------------------------------------------------*/

static TSCommandSetEntry GSCommandSetTable[] =
{
    /* CmdId, Name, Channels */

    {0x3000, "OUTPUT_ON",       {0x3, 0x3}},
    {0x3001, "OUTPUT_OFF",      {0x3, 0x3}},
    {0x3002, "OUTPUT_SUM_ON",   {0x0, 0x0}},
    {0x3003, "OUTPUT_SUM_OFF",  {0x0, 0x0}},
    {0x3004, "SYNC_ON",         {0x3, 0x3}},
    {0x3005, "SYNC_OFF",        {0x3, 0x3}},
    {0x3006, "FILTER_EXT_ON",   {0x3, 0x3}},
    {0x3007, "FILTER_EXT_OFF",  {0x3, 0x3}},
    {0x3020, "FILTER_AUTO_ON",  {0x3, 0x3}},
    {0x3021, "FILTER_AUTO_OFF", {0x3, 0x3}},
    {0x3008, "AM_ON",           {0x3, 0x3}},
    {0x3009, "AM_OFF",          {0x3, 0x3}},
    {0x300A, "FM_ON",           {0x0, 0x0}},
    {0x300B, "FM_OFF",          {0x0, 0x0}},
    {0x300C, "PM_ON",           {0x3, 0x3}},
    {0x300D, "PM_OFF",          {0x3, 0x3}},
    {0x300E, "BM_ON",           {0x0, 0x0}},
    {0x300F, "BM_OFF",          {0x0, 0x0}},
    {0x3010, "FSK_ON",          {0x0, 0x0}},
    {0x3011, "FSK_OFF",         {0x0, 0x0}},
    {0x3012, "PSK_ON",          {0x3, 0x3}},
    {0x3013, "PSK_OFF",         {0x3, 0x3}},
    {0x3014, "SWEEP_ON",        {0x0, 0x0}},
    {0x3015, "SWEEP_OFF",       {0x0, 0x0}},
    {0x3016, "ABORT",           {0x0, 0x0}},
    {0x3017, "TRIGGER",         {0x0, 0x0}},
    {0x3022, "MARKER_ON",       {0x0, 0x0}},
    {0x3023, "MARKER_OFF",      {0x0, 0x0}},
    {0x3024, "ROSC_ON",         {0x0, 0x0}},
    {0x3025, "ROSC_OFF",        {0x0, 0x0}},
    {0x3FFF, "RESET",           {0x0, 0x0}},
    /* Last element */
    {0, NULL, 0}
};

/*--- Device-specific Errors Table ------------------------------------------*/

static TSStringValPair GSDeviceSpecificErrorsTable[] =
{
    {-330, "selftest fail"},
    {-360, "communication fail"},
    { 200, "over temperature"},
    { 300, "over voltage"},
    { 401, "self-test fail"},
    { 402, "PLL fail"},
    /* Last element */
    {0, NULL}
};

/*--- Execution Errors Table ------------------------------------------------*/

static TSStringValPair GSExecutionErrorsTable[] =
{
    {-211, "trigger ignored"},
    {-221, "settings conflict"},
    {-222, "out of range"},
    {-223, "too much data"},
    {-224, "illegal parameter"},
    /* Last element */
    {0, NULL}
};

/*--- Error Codes of Baugruppen Data Block Table ----------------------------*/

static TSStringValPair GSBaugruppenDataBlockErrorsTable[] =
{
    {0x0000, "no error"},
    {0x0001, "invalid BlockId"},
    {0x0002, "invalid size"},
    {0x0003, "corrupt checksum or data"},
    {0x0004, "unknown BlockId"},
    /* Last element */
    {0, NULL}
};

/*--- Device Errors Table ---------------------------------------------------*/

static TSStringValPair GSDeviceErrorsTable[] =
{

    /* Error Codes of GDI Core */

    {0xA010, "unexpected type of signal received"},
    {0xA020, "incoming bulk buffer is corrupt"},
    {0xA030, "unknown control request"},
    {0xA040, "corrupt control batch"},

    /* Error codes that can be used in app-defined GDI handlers */

    {0x8010, "an unimplemented feature was accessed"},
    {0x8020, "unknown GDI identifier"},
    {0x8025, "invalid channel index"},
    {0x8030, "identifier and size do not correspond"},
    {0x8040, "invalid buffer content"},

    /* USB Driver Error Codes */

    {0xC010, "(USB error) unknown signal"},
    {0xC011, "(USB error) EP0 unknown transfer type"},
    {0xC012, "(USB error) control signal up is not free"},
    {0xC013, "(USB error) signal USB setup request reserved"},
    {0xC014, "(USB error) EP0 mishmash transfer type"},
    {0xC015, "(USB error) EP0 unknown transfer direction"},
    {0xC016, "(USB error) EP0 unknown transfer request"},
    {0xC017, "(USB error) signal USB setup unknown direction"},
    {0xC018, "(USB error) buffer down signal pipe 0 is null"},
    {0xC019, "(USB error) buffer up signal pipe 0 is null"},
    {0xC01A, "(USB warning) EP0 different data size"},
    {0xC01B, "(USB error) buffer up signal pipe x is null"},
    {0xC01C, "(USB error) send signal buffer up to control default"},
    {0xC01D, "(USB error) buffer up unknown EP type"},

    /* OnBufferUp, OnBufferDown */

    {0xC020, "(USB error) signal buffer up control transfer request standard"},
    {0xC021, "(USB error) signal buffer up control transfer request type default"},
    {0xC022, "(USB error) signal buffer up control transfer bad EP"},
    {0xC023, "(USB error) signal buffer up transfer type default"},

    {0xC024, "(USB error) signal buffer down control transfer request standard"},
    {0xC025, "(USB error) signal buffer down control transfer request type default"},
    {0xC026, "(USB error) signal buffer down control transfer bad EP"},
    {0xC027, "(USB error) signal buffer down Transfer type default"},

    /* Last element */
    {0, NULL}
};

/*****************************************************************************/
/*= UTILITY ROUTINE DECLARATIONS (Non-Exportable Functions) =================*/
/*****************************************************************************/
ViBoolean rssiam_invalidViBooleanRange (ViBoolean val);
ViBoolean rssiam_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rssiam_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max);
ViBoolean rssiam_invalidViString (ViString val, ViUInt32 maxLength);
ViStatus rssiam_initCleanUp (ViPSession openInstrSession, ViStatus currentStatus);
void rssiam_delay (ViReal64 numberOfSeconds);
void rssiam_SWAP_32(unsigned char *data, long points);
ViReal64 rssiam_unit2vpp (ViReal64 value, ViInt32 unit);
ViReal64 rssiam_vpp2unit (ViReal64 value, ViInt32 unit);

/*****************************************************************************/
/*------ INSERT INSTRUMENT-DEPENDENT UTILITY ROUTINE DECLARATIONS HERE ------*/
/*****************************************************************************/
ViStatus rssiam_defaultInstrSetup (ViSession openInstrSession);
ViStatus rssiam_waitForDeviceState (ViSession instrSession, ViInt32 deviceState);
ViStatus rssiam_checkStatus (ViSession instrSession, ViInt16 checkEvent, ViPBoolean checkEnventFound);
ViStatus rssiam_setRegister (ViSession instrSession, ViString registerSetName, void *value);
ViStatus rssiam_getRegister (ViSession instrSession, ViString registerSetName, void *value, ViInt16 range);
ViStatus rssiam_getDeviceCaps (ViSession instrSession, ViConstString capsName, void *value);
ViStatus rssiam_sendCmd (ViSession instrSession, ViString cmdSetName);
ViStatus rssiam_getIndexFromName (ViString Name, ViPInt32 index);
ViStatus rssiam_checkRange (ViInt32 index, void* min, void* value, void* max);
ViReal64 rssiam_uLoad (ViReal64 uSource, ViReal64 rLoad);
ViReal64 rssiam_uSource (ViReal64 uLoad, ViReal64 rLoad);

/*****************************************************************************/
/*====== USER-CALLABLE FUNCTIONS (Exportable Functions) =====================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC rssiam_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrSession)
{
    ViStatus rssiam_status  = VI_SUCCESS;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rssiam_invalidViBooleanRange (IDQuery))
        return VI_ERROR_PARAMETER2;
    if (rssiam_invalidViBooleanRange (resetDevice))
        return VI_ERROR_PARAMETER3;

    /*- Initialize SiControl library and open instrument session(s) ---------*/
    if((rssiam_status = SiLibInit ()) != SI_ERROR_LIB_ALREADY_INITIALIZED)
        {
        CHECKERR (SiUpdateDeviceList());
        }

    /* Check device list if requested device is present in the system */
    {
    unsigned int    idx                 = 0,
                    deviceCount         = 0,
                    VendorId            = 0x0,
                    VID                 = 0x0,
                    ProductId           = 0x0,
                    PID                 = 0x0;
    unsigned long   SerialNumber        = 0,
                    ModelSerialNumber   = 0,
                    MSN                 = 0;
    char            dupResourceName[256];
    ViBoolean       ResourceNameMatched = VI_FALSE;

        /* Parse resource string "USB::Vendor_IDentifier::Product_IDentifier::Serial_Number" */
        if ((sscanf (resourceName, "USB::%x::%x::%u", &VID, &PID, &MSN)) != 3)
            {
            /* If resource string does not fit, try to pass it as alias */
            strcpy (dupResourceName, resourceName);
            }
        else
            {
            deviceCount = SiGetDeviceCount();

            for (idx = 0; idx < deviceCount; idx++)
                {
                CHECKERR (SiGetDeviceInfo(idx, &VendorId, &ProductId, &SerialNumber, &ModelSerialNumber));
                if ((VendorId == VID) && (ProductId == PID) && (ModelSerialNumber == MSN))
                    {
                    ResourceNameMatched = VI_TRUE;
                    break;
                    }
                }

            if (ResourceNameMatched == VI_FALSE)
                return SI_ERROR_RSRC_NFOUND;

            /* Create duplicate resource name with module serial number */
            sprintf (dupResourceName, "USB::0x%x::0x%x::%u", VID, PID, SerialNumber);
            }

        if ((rssiam_status = SiOpenDevice(dupResourceName, instrSession)) < 0)
            {
            SiCloseDevice (*instrSession);
            return rssiam_status;
            }
    }

    /*- Configure SiControl session parameters ------------------------------*/
    CHECKERR_CU (SiSetAttribute (*instrSession, SI_ATTR_TMO_VALUE, RSSIAM_DEFAULT_TIMEOUT));
    CHECKERR_CU (SiSetAttribute (*instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE_ID,
        RSSIAM_CONTROL_TRANSFER_HANDSHAKE));

    /*- Identification Query ------------------------------------------------*/
    if (IDQuery)
        {
        unsigned int VID = 0x0,
                     PID = 0x0;

        CHECKERR_CU (SiGetAttribute (*instrSession, SI_ATTR_VENDOR_ID, &VID));
        CHECKERR_CU (SiGetAttribute (*instrSession, SI_ATTR_PRODUCT_ID, &PID));

        if ((VID != RSSIAM_VID_ROHDE_SCHWARZ) || (PID != RSSIAM_PID_A300))
            return rssiam_initCleanUp (instrSession, VI_ERROR_FAIL_ID_QUERY);
        }

    /*- Reset instrument ----------------------------------------------------*/
    if (resetDevice)
        rssiam_status = rssiam_reset (*instrSession);
    else  /*- Send Default Instrument Setup ---------------------------------*/
        rssiam_status = rssiam_defaultInstrSetup (*instrSession);

    /* CHECKERR_CU (rssiam_status); ... in case of error is lost instrSession */

    return rssiam_status;
}

/*****************************************************************************
 * Function: Apply Instrument Setup
 * Purpose:  The Apply function provides the most straightforward method to
 *           program the function generator over the remote interface. You can
 *           select the function, frequency, amplitude, and offset all in one
 *           function.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_appl(
    ViSession   instrSession,
    ViInt16     function,
    ViReal64    frequency,
    ViReal64    amplitude,
    ViReal64    offset
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    CHECKERR (rssiam_funcShap (instrSession, function));
    CHECKERR (rssiam_freq (instrSession, frequency));
    CHECKERR (rssiam_volt (instrSession, amplitude));
    CHECKERR (rssiam_voltOffs (instrSession, offset));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Apply Instrument Query
 * Purpose:  Returns the parameters such as function, frequency, amplitude,
 *           and offset of the arbitrary generator.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_appl_Q(
    ViSession   instrSession,
    ViChar      _VI_FAR queryResult[]
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt16     function        = 0;
    ViInt16     idx             = 0;
    ViReal64    frequency       = 0.0;
    ViReal64    amplitude       = 0.0;
    ViReal64    offset          = 0.0;

    static TSStringValPair functionShapeArray[] =
        {
            {RSSIAM_OUTPUT_FUNC_SIN,    "Sinusoid"},
            {RSSIAM_OUTPUT_FUNC_SQU,    "Square Low Jitter"},
            {RSSIAM_OUTPUT_FUNC_TRI,    "Triangle"},
            {RSSIAM_OUTPUT_FUNC_RAMP,   "Ramp (variable symmetry)"},
            {RSSIAM_OUTPUT_FUNC_NOIS,   "Noise"},
            {RSSIAM_OUTPUT_FUNC_DC,     "DC"},
            {RSSIAM_OUTPUT_FUNC_USER,   "User"},
            {RSSIAM_OUTPUT_FUNC_SQUARE, "Square"},
            {RSSIAM_OUTPUT_FUNC_REXP,   "Reverse Exponential"},
            {RSSIAM_OUTPUT_FUNC_FEXP,   "Forward Exponential"},
            {RSSIAM_OUTPUT_FUNC_PULSE,  "Pulse"},
            {VI_NULL, VI_NULL}
        };

    if (!queryResult)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_funcShap_Q (instrSession, &function));
    CHECKERR (rssiam_freq_Q (instrSession, RSSIAM_CURRENT_RANGE, &frequency));
    CHECKERR (rssiam_volt_Q (instrSession, RSSIAM_CURRENT_RANGE, &amplitude));
    CHECKERR (rssiam_voltOffs_Q (instrSession, RSSIAM_CURRENT_RANGE, &offset));

    for (idx = 0; functionShapeArray[idx].stringName; idx++)
        {
        if (functionShapeArray[idx].stringVal == function)
            {
            sprintf (queryResult, "Waveform shape is %s, frequency is %3.3Le Hz,"
                " amplitude is %3.3f V and DC offset is %3.3f V",
                functionShapeArray[idx].stringName, frequency, amplitude, offset);
            return VI_SUCCESS;
            }
        }

    sprintf (queryResult, "Waveform shape is unknown, frequency is %3.3Le Hz,"
        " amplitude is %3.3f V and DC offset is %3.3f V",
        functionShapeArray[idx].stringName, frequency, amplitude, offset);

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Channel Setup
 * Purpose:  This function selects active channel for which are the settings
 *           applied.
 *
 *           Note:
 *
 *           Channel based operations are noted in the descriptions
 *           (applicable channels are listed).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpChannel(
    ViSession   instrSession,
    ViInt16     activeChannel
)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges     instrPtr        = {0};

    if ((activeChannel != RSSIAM_CH1) && (activeChannel != RSSIAM_CH2))
        return RSSIAM_ERROR_INVALID_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    instrPtr -> activeChannel = activeChannel;

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Channel Query
 * Purpose:  This function returns currently active channel for which are the
 *           settings applied.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpChannel_Q(
    ViSession   instrSession,
    ViPInt16    activeChannel
)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges     instrPtr        = {0};

    if (!activeChannel)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    *activeChannel = instrPtr -> activeChannel;

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Channel Coupling Setup
 * Purpose:  Select output channel(s) coupling.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpChannelCoupl(
    ViSession   instrSession,
    ViInt16     channelCoupling
)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges instrPtr        = {0};
    ViUInt16            deviceConfig    = 0,
                        oldDeviceConfig = 0;

    if (channelCoupling < 0)
        return RSSIAM_ERROR_INVALID_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    /*
        Device config = 0 ... with common frequency,
        Device config = 1 ... two independent frequencies
    */

    deviceConfig = (channelCoupling == RSSIAM_CHANNEL_COUPLING_OFF) ? 1 : 0;

    instrPtr -> channelCoupling = channelCoupling;

    CHECKERR (rssiam_getRegister (instrSession, "DEVICE_CONFIG", &oldDeviceConfig, RSSIAM_CURRENT_RANGE));
    
    /* Coupling mode is changed */
    if (deviceConfig != oldDeviceConfig)
        {
        CHECKERR (rssiam_getRegister (instrSession, "APPLY_DEVICE_CONFIGURATION", &instrPtr -> deviceCfg, RSSIAM_CURRENT_RANGE));

        instrPtr -> deviceCfg.device_cfg = deviceConfig;

        CHECKERR (rssiam_setRegister (instrSession, "APPLY_DEVICE_CONFIGURATION", &instrPtr -> deviceCfg));
#if 1
        /* Flush SiControl event queue (workaround to suppress messages from device) */
        CHECKERR (SiFlushEventQueue (instrSession));
#else
        CHECKERR (rssiam_checkStatus (instrSession, NULL, NULL));
#endif
        }

    if (channelCoupling & RSSIAM_CHANNEL_COUPLING_AMPT)
        {
        ViReal64    volt        = 0.0,
                    voltOffset  = 0.0,
                    voltLow     = 0.0,
                    voltHigh    = 0.0;

        CHECKERR (rssiam_voltLow_Q (instrSession, RSSIAM_CURRENT_RANGE, &voltLow));
        CHECKERR (rssiam_voltHigh_Q (instrSession, RSSIAM_CURRENT_RANGE, &voltHigh));

        CHECKERR (rssiam_volt_Q (instrSession, RSSIAM_CURRENT_RANGE, &volt));
        CHECKERR (rssiam_voltOffs_Q (instrSession, RSSIAM_CURRENT_RANGE, &voltOffset));

        volt = ((voltOffset + volt/2) < voltLow) ? voltLow : volt;
        volt = ((voltOffset + volt/2) > voltHigh) ? voltHigh : volt;

        voltOffset = ((voltOffset + volt/2) < voltLow) ? (voltLow + volt/2) : voltOffset;
        voltOffset = ((voltOffset + volt/2) > voltHigh) ? (voltHigh - volt/2) : voltOffset;

        CHECKERR (rssiam_volt (instrSession, volt));
        CHECKERR (rssiam_voltOffs (instrSession, voltOffset));
        }

    if (channelCoupling & RSSIAM_CHANNEL_COUPLING_OUTPUT)
        {
        ViInt16 state = VI_FALSE;

        CHECKERR (rssiam_outpSetup_Q (instrSession, &state));
        CHECKERR (rssiam_outpSetup (instrSession, state));
        }

    if (channelCoupling & RSSIAM_CHANNEL_COUPLING_PHASE)
        {
        ViReal64 phase = 0.0;

        CHECKERR (rssiam_outpStartPhase_Q (instrSession, &phase));
        CHECKERR (rssiam_outpStartPhase (instrSession, phase));
        }

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Channel Coupling Query
 * Purpose:  Returns output channel(s) coupling.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpChannelCoupl_Q(
    ViSession   instrSession,
    ViPInt16    channelCoupling
)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    ViUInt16                deviceConfig    = 0;
    pTSStatusDataRanges     instrPtr        = {0};

    if (!channelCoupling)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_getRegister (instrSession, "DEVICE_CONFIG", &deviceConfig, RSSIAM_CURRENT_RANGE));

    /*
        Device config = 0 ... with common frequency,
        Device config = 1 ... two independent frequencies
    */

    *channelCoupling = (deviceConfig == 1) ? RSSIAM_CHANNEL_COUPLING_OFF : instrPtr -> channelCoupling;

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Function Shape Setup
 * Purpose:  Selects the function and outputs the selected waveform shape. The
 *           selected waveform is output using the previously selected
 *           frequency, amplitude, and offset settings.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_funcShap(
    ViSession   instrSession,
    ViInt16     functionShape
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    functionShape_data  = functionShape;

    CHECKERR (rssiam_setRegister (instrSession, "CARRIER_FUNCTION", &functionShape_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Function Shape Query
 * Purpose:  Returns a numeric value indicating the current waveform shape.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_funcShap_Q(
    ViSession   instrSession,
    ViPInt16    functionShape
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    functionShape_data  = 0;

    if (!functionShape)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "CARRIER_FUNCTION", &functionShape_data, RSSIAM_CURRENT_RANGE));

    *functionShape = functionShape_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Frequency Setup
 * Purpose:  Sets the carrier frequency of the output signal (Hz).
 *
 *           Applicable channels:
 *
 *             CH1, CH2 if device config selects two independent frequencies
 *
 *           Note:
 *
 *           If device config selects common frequency (see function Output
 *           Channel Coupling (rssiam_outpChannelCoupl())), channel does not
 *           apply.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freq(
    ViSession   instrSession,
    ViReal64    frequency
)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    ViReal64                frequency_data  = frequency;

    CHECKERR (rssiam_setRegister (instrSession, "CARRIER_FREQUENCY", &frequency_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Frequency Query
 * Purpose:  Returns the carrier frequency setting of the output signal (Hz).
 *
 *           Applicable channels:
 *
 *             CH1, CH2 if device config selects two independent frequencies
 *
 *           Note:
 *
 *           If device config selects common frequency (see function Output
 *           Channel Coupling (rssiam_outpChannelCoupl())), channel does not
 *           apply.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freq_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   frequency
)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    ViReal64                frequency_data  = 0.0;

    if (!frequency)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "CARRIER_FREQUENCY", &frequency_data, range));

    *frequency = frequency_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage Setup
 * Purpose:  Sets the output amplitude for currently active function.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_volt(
    ViSession   instrSession,
    ViReal64    voltage
)
{
    ViStatus            rssiam_status       = VI_SUCCESS;
    ViReal32            voltage_data        = 0.0;
    ViUInt16            functionShape_data  = 0;
    pTSStatusDataRanges instrPtr            = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    CHECKERR (rssiam_getRegister (instrSession, "CARRIER_FUNCTION", &functionShape_data,
        RSSIAM_CURRENT_RANGE));

    /* Other unit than Vpp are allowed only for sinewave */
    if ((functionShape_data != RSSIAM_OUTPUT_FUNC_SIN) &&
        (instrPtr -> outputVoltageUnit != RSSIAM_OUTPUT_VOLT_UNIT_VPP) &&
        (instrPtr -> outputVoltageUnit != RSSIAM_OUTPUT_VOLT_UNIT_DEF))
        return RSSIAM_ERROR_SETTINGS_CONFLICT;

    DBL2FLT (rssiam_uSource (voltage, instrPtr -> outputLoad[instrPtr -> activeChannel - 1]), voltage_data);
    DBL2FLT (rssiam_unit2vpp (voltage_data, instrPtr -> outputVoltageUnit), voltage_data);  
        
    if (functionShape_data == RSSIAM_OUTPUT_FUNC_DC)
        {
        if (instrPtr -> channelCoupling & RSSIAM_CHANNEL_COUPLING_AMPT)
            {
            ViInt16 activeChannelOld    = instrPtr -> activeChannel;
            ViInt16 channel             = 1;

            for (channel = 1; channel <= 2; channel++)
                {
                instrPtr -> activeChannel = channel;

                if ((rssiam_status = rssiam_setRegister (instrSession, "VOLTAGE_DC",
                    &voltage_data)) < VI_SUCCESS)
                    {
                    instrPtr -> activeChannel = activeChannelOld;
                    return rssiam_status;
                    }
                }
            instrPtr -> activeChannel = activeChannelOld;
            }
        else
            {
            CHECKERR (rssiam_setRegister (instrSession, "VOLTAGE_DC", &voltage_data));
            }
        }
    else
        {
        ViReal32                voltageOffset   = 0.0;
        ViUInt16                idx             = 0; /* Channel index */

        if (instrPtr -> channelCoupling & RSSIAM_CHANNEL_COUPLING_AMPT)
            {
            ViInt16 activeChannelOld    = instrPtr -> activeChannel;
            ViInt16 channel             = 1;

            for (channel = 1; channel <= 2; channel++)
                {
                instrPtr -> activeChannel = channel;

                if ((rssiam_status = rssiam_getRegister (instrSession, "VOLTAGE_OFFSET",
                    &voltageOffset, RSSIAM_CURRENT_RANGE)) < VI_SUCCESS)
                    {
                    instrPtr -> activeChannel = activeChannelOld;
                    return rssiam_status;
                    }

                idx = instrPtr -> activeChannel - 1;

                if (((voltageOffset + voltage_data/2.0) > instrPtr -> voltageHigh[idx]) ||
                    ((voltageOffset + voltage_data/2.0) < instrPtr -> voltageLow[idx]))
                    {
                    instrPtr -> activeChannel = activeChannelOld;
                    return RSSIAM_ERROR_OVER_LIMIT;
                    }

                if ((rssiam_status = rssiam_setRegister (instrSession, "VOLTAGE_AMPLITUDE",
                    &voltage_data)) < VI_SUCCESS)
                    {
                    instrPtr -> activeChannel = activeChannelOld;
                    return rssiam_status;
                    }
                }
            instrPtr -> activeChannel = activeChannelOld;
            }
        else
            {
            CHECKERR (rssiam_getRegister (instrSession, "VOLTAGE_OFFSET", &voltageOffset,
                RSSIAM_CURRENT_RANGE));

            idx = instrPtr -> activeChannel - 1;

            if (((voltageOffset + voltage_data/2.0) > instrPtr -> voltageHigh[idx]) ||
                ((voltageOffset + voltage_data/2.0) < instrPtr -> voltageLow[idx]))
                return RSSIAM_ERROR_OVER_LIMIT;

            CHECKERR (rssiam_setRegister (instrSession, "VOLTAGE_AMPLITUDE", &voltage_data));
            }
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage Query
 * Purpose:  Returns the output amplitude for the currently selected function.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_volt_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   voltage
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal32    voltage_data        = 0.0;
    ViUInt16    functionShape_data  = 0;
    pTSStatusDataRanges instrPtr            = {0};

    if (!voltage)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_getRegister (instrSession, "CARRIER_FUNCTION", &functionShape_data,
        RSSIAM_CURRENT_RANGE));

    /* Other unit than Vpp are allowed only for sinewave */
    if ((functionShape_data != RSSIAM_OUTPUT_FUNC_SIN) &&
        (instrPtr -> outputVoltageUnit != RSSIAM_OUTPUT_VOLT_UNIT_VPP) &&
        (instrPtr -> outputVoltageUnit != RSSIAM_OUTPUT_VOLT_UNIT_DEF))
        return RSSIAM_ERROR_SETTINGS_CONFLICT;

    if (functionShape_data == RSSIAM_OUTPUT_FUNC_DC)
        {
        CHECKERR (rssiam_getRegister (instrSession, "VOLTAGE_DC", &voltage_data, range));
        }
    else
        {
        CHECKERR (rssiam_getRegister (instrSession, "VOLTAGE_AMPLITUDE", &voltage_data, range));
        }

    /* Apply output load and unit conversion */
    *voltage = rssiam_vpp2unit (rssiam_uLoad (voltage_data,
        instrPtr -> outputLoad[instrPtr -> activeChannel - 1]),
        instrPtr -> outputVoltageUnit);

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage Offset Setup
 * Purpose:  Sets the DC offset voltage for currently active function.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_voltOffs(
    ViSession   instrSession,
    ViReal64    voltageOffset
)
{
    ViStatus                rssiam_status       = VI_SUCCESS;
    ViReal32                voltageOffset_data  = 0.0;
    ViReal32                voltage             = 0.0;
    ViUInt16                idx                 = 0; /* Channel index */
    pTSStatusDataRanges     instrPtr            = {0};

    DBL2FLT (voltageOffset, voltageOffset_data);
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr -> channelCoupling & RSSIAM_CHANNEL_COUPLING_AMPT)
        {
        ViInt16 activeChannelOld    = instrPtr -> activeChannel;
        ViInt16 channel             = 1;

        for (channel = 1; channel <= 2; channel++)
            {
            instrPtr -> activeChannel = channel;

            if ((rssiam_status = rssiam_getRegister (instrSession, "VOLTAGE_AMPLITUDE",
                &voltage, RSSIAM_CURRENT_RANGE)) < VI_SUCCESS)
                {
                instrPtr -> activeChannel = activeChannelOld;
                return rssiam_status;
                }

            idx = instrPtr -> activeChannel - 1;

            if (((voltageOffset + voltage/2) > instrPtr -> voltageHigh[idx]) ||
                ((voltageOffset + voltage/2) < instrPtr -> voltageLow[idx]))
                {
                instrPtr -> activeChannel = activeChannelOld;
                return RSSIAM_ERROR_OVER_LIMIT;
                }

            if ((rssiam_status = rssiam_setRegister (instrSession, "VOLTAGE_OFFSET",
                &voltageOffset_data)) < VI_SUCCESS)
                {
                instrPtr -> activeChannel = activeChannelOld;
                return rssiam_status;
                }
            }
        instrPtr -> activeChannel = activeChannelOld;
        }
    else
        {
        CHECKERR (rssiam_getRegister (instrSession, "VOLTAGE_AMPLITUDE", &voltage,
            RSSIAM_CURRENT_RANGE));

        idx = instrPtr -> activeChannel - 1;

        if (((voltageOffset + voltage/2) > instrPtr -> voltageHigh[idx]) ||
            ((voltageOffset + voltage/2) < instrPtr -> voltageLow[idx]))
            return RSSIAM_ERROR_OVER_LIMIT;

        CHECKERR (rssiam_setRegister (instrSession, "VOLTAGE_OFFSET", &voltageOffset_data));
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage Offset Query
 * Purpose:  Returns the DC offset voltage in volts for the currently selected
 *           function.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_voltOffs_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   voltageOffset
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal32    voltageOffset_data  = 0.0;

    if (!voltageOffset)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "VOLTAGE_OFFSET", &voltageOffset_data, range));

    *voltageOffset = voltageOffset_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage High Setup
 * Purpose:  Sets the high voltage level (related to offset). For all
 *           functions, the default high level is +500 mV.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_voltHigh(
    ViSession   instrSession,
    ViReal64    voltageHigh
)
{
    ViStatus                rssiam_status       = VI_SUCCESS;
    ViReal32                voltageHigh_data    = 0.0;
    ViReal32                voltage             = 0.0;
    ViReal32                voltageOffset       = 0.0;
    ViReal32                voltageHighOld      = 0.0;
    ViUInt16                idx                 = 0;
    pTSStatusDataRanges     instrPtr            = {0};

    DBL2FLT (voltageHigh, voltageHigh_data);

    if (rssiam_invalidViReal64Range (voltageHigh_data, -5.0, 5.0))
        return RSSIAM_ERROR_INVALID_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    CHECKERR (rssiam_getRegister (instrSession, "VOLTAGE_AMPLITUDE", &voltage, RSSIAM_CURRENT_RANGE));
    CHECKERR (rssiam_getRegister (instrSession, "VOLTAGE_OFFSET", &voltageOffset, RSSIAM_CURRENT_RANGE));

    idx = instrPtr -> activeChannel - 1;

    voltageHighOld = instrPtr -> voltageHigh[idx];

    instrPtr -> voltageHigh[idx] = (voltageHigh_data < instrPtr -> voltageLow[idx]) ?
        instrPtr -> voltageLow[idx] : voltageHigh_data;

    if (((voltageOffset + voltage/2) > instrPtr -> voltageHigh[idx]) ||
        ((voltageOffset + voltage/2) < instrPtr -> voltageLow[idx]))
        {
        instrPtr -> voltageHigh[idx] = voltageHighOld;
        return RSSIAM_ERROR_SETTINGS_CONFLICT;
        }

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage High Query
 * Purpose:  Returns the high voltage level (related to offset) in DC volts
 *           for the currently selected function.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_voltHigh_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   voltageHigh
)
{
    ViStatus    rssiam_status = VI_SUCCESS;
    pTSStatusDataRanges     instrPtr        = {0};

    if (!voltageHigh)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    switch (range)
        {
        case RSSIAM_MIN_RANGE:
            *voltageHigh = -5.0; /* valid min range is hardcoded here */
            break;
        case RSSIAM_MAX_RANGE:
            *voltageHigh = 5.0; /* valid max range is hardcoded here */
            break;
        default:
            *voltageHigh = instrPtr -> voltageHigh[instrPtr -> activeChannel - 1];
            break;
        }

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage Low Setup
 * Purpose:  Sets the low voltage level (related to offset). For all
 *           functions, the default low level is -500 mV.
 *
 *           You can set the levels to any valid positive or negative value,
 *           but note that the high level must always be greater than the low
 *           level. If you specify a low level that is greater than the high
 *           level, this function will automatically set the low level equal to
 *           the high level.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_voltLow(
    ViSession   instrSession,
    ViReal64    voltageLow
)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    ViReal32                voltageLow_data = 0.0;
    ViReal32                voltage         = 0.0;
    ViReal32                voltageOffset   = 0.0;
    ViReal32                voltageLowOld   = 0.0;
    ViUInt16                idx             = 0;
    pTSStatusDataRanges     instrPtr        = {0};

    DBL2FLT (voltageLow, voltageLow_data);

    if (rssiam_invalidViReal64Range (voltageLow_data, -5.0, 5.0))
        return RSSIAM_ERROR_INVALID_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_getRegister (instrSession, "VOLTAGE_AMPLITUDE", &voltage, RSSIAM_CURRENT_RANGE));
    CHECKERR (rssiam_getRegister (instrSession, "VOLTAGE_OFFSET", &voltageOffset, RSSIAM_CURRENT_RANGE));

    idx = instrPtr -> activeChannel - 1;

    voltageLowOld = instrPtr -> voltageLow[idx];

    instrPtr -> voltageLow[idx] = (voltageLow_data > instrPtr -> voltageHigh[idx]) ?
        instrPtr -> voltageHigh[idx] : voltageLow_data;

    if (((voltageOffset + voltage/2) > instrPtr -> voltageHigh[idx]) ||
        ((voltageOffset + voltage/2) < instrPtr -> voltageLow[idx]))
        {
        instrPtr -> voltageLow[idx] = voltageLowOld;
        return RSSIAM_ERROR_SETTINGS_CONFLICT;
        }

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage Low Query
 * Purpose:  Returns the low voltage level (related to offset) in DC volts for
 *           the currently selected function.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_voltLow_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   voltageLow
)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges     instrPtr        = {0};

    if (!voltageLow)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    switch (range)
        {
        case RSSIAM_MIN_RANGE:
            *voltageLow = -5.0; /* valid min range is hardcoded here */
            break;
        case RSSIAM_MAX_RANGE:
            *voltageLow = 5.0; /* valid max range is hardcoded here */
            break;
        default:
            *voltageLow = instrPtr -> voltageLow[instrPtr -> activeChannel - 1];
            break;
        }

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage Unit Setup
 * Purpose:  Selects the output units for amplitude only.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_voltUnit(
    ViSession   instrSession,
    ViInt16     voltageUnit
)
{
    ViStatus                rssiam_status       = VI_SUCCESS;
    pTSStatusDataRanges     instrPtr            = {0};
    ViUInt16                functionShape_data  = 0;
    ViInt16                 cnt                 = 0;

    ViInt16     voltageUnitArr[] = {RSSIAM_OUTPUT_VOLT_UNIT_VPP,
                                    RSSIAM_OUTPUT_VOLT_UNIT_VRMS,
                                    RSSIAM_OUTPUT_VOLT_UNIT_DBM,
                                    RSSIAM_OUTPUT_VOLT_UNIT_DEF,
                                    -1};

    for (cnt = 0; voltageUnitArr[cnt] >= 0; cnt++)
        if (voltageUnit == voltageUnitArr[cnt])
            break;

    if (voltageUnitArr[cnt] < 0)
        return RSSIAM_ERROR_INVALID_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_getRegister (instrSession, "CARRIER_FUNCTION", &functionShape_data,
        RSSIAM_CURRENT_RANGE));

    /* Units dBm vs 50.0 ohms is only allowed combination */
    if ((voltageUnit == RSSIAM_OUTPUT_VOLT_UNIT_DBM) &&
        (fabs (instrPtr -> outputLoad[instrPtr -> activeChannel - 1] - 50.0) > NUMERIC_PRECISION))
        return RSSIAM_ERROR_SETTINGS_CONFLICT;

    /* Other unit than Vpp are allowed only for sinewave */
    if ((functionShape_data != RSSIAM_OUTPUT_FUNC_SIN) &&
        (voltageUnit != RSSIAM_OUTPUT_VOLT_UNIT_VPP) &&
        (voltageUnit != RSSIAM_OUTPUT_VOLT_UNIT_DEF))
        return RSSIAM_ERROR_SETTINGS_CONFLICT;
    
    instrPtr -> outputVoltageUnit = voltageUnit;

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Voltage Unit Query
 * Purpose:  Returns a numeric indicating the current output units.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_voltUnit_Q(
    ViSession   instrSession,
    ViPInt16    voltageUnit
)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges instrPtr        = {0};

    if (!voltageUnit)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    *voltageUnit = (instrPtr -> outputVoltageUnit == RSSIAM_OUTPUT_VOLT_UNIT_DEF) ?
        RSSIAM_OUTPUT_VOLT_UNIT_VPP : instrPtr -> outputVoltageUnit;

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Square Duty Cycle Setup
 * Purpose:  Sets the duty cycle in percent for variable square waves only.
 *           Duty cycle represents the amount of time per cycle that the square
 *           wave is high.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pulsDcyc(
    ViSession   instrSession,
    ViReal64    dutyCycle
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal32    dutyCycle_data  = 0.0;

    DBL2FLT (dutyCycle, dutyCycle_data);

    CHECKERR (rssiam_setRegister (instrSession, "DUTY_CYCLE", &dutyCycle_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Square Duty Cycle Query
 * Purpose:  Returns the variable square wave duty cycle in percent.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pulsDcyc_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   dutyCycle
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal32    dutyCycle_data  = 0.0;

    if (!dutyCycle)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "DUTY_CYCLE", &dutyCycle_data, range));

    *dutyCycle = dutyCycle_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Ramp Symmetry Setup
 * Purpose:  Sets the symmetry percentage for ramp waves. Symmetry represents
 *           the amount of time per cycle that the ramp wave is rising.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_rampSymm(
    ViSession   instrSession,
    ViReal64    rampSymmetry
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal32    rampSymmetry_data   = 0.0;

    DBL2FLT (rampSymmetry, rampSymmetry_data);

    CHECKERR (rssiam_setRegister (instrSession, "RAMP_SYMMETRY", &rampSymmetry_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Ramp Symmetry Query
 * Purpose:  Returns the ramp wave symmetry in percent.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_rampSymm_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   rampSymmetry
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal32    rampSymmetry_data   = 0.0;

    if (!rampSymmetry)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "RAMP_SYMMETRY", &rampSymmetry_data, range));

    *rampSymmetry = rampSymmetry_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Load Setup
 * Purpose:  Selects the output termination for output amplitude and offset
 *           voltage. The function generator has a fixed output impedance of 50
 *           ohms on the OUTPUT terminal. You can specify whether you are
 *           terminating the output into a 50-ohm load or an open circuit.
 *           Incorrect impedance matching between the function generator and
 *           your load will result in an amplitude or offset which does not
 *           match the specified signal level.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpLoad(
    ViSession   instrSession,
    ViInt16     outputLoad
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViInt16     channel             = 0;
    pTSStatusDataRanges instrPtr    = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_outpChannel_Q (instrSession, &channel));

    switch (outputLoad)
        {
        case RSSIAM_OUTPUT_LOAD_50:
            {
            //ViReal64    voltage = 0.0;

            //CHECKERR (rssiam_volt_Q (instrSession, RSSIAM_CURRENT_RANGE, &voltage));
            instrPtr -> outputLoad[channel - 1] = 50.0; /* Fixed value */
            //CHECKERR (rssiam_volt (instrSession, voltage));
            }
            break;
        case RSSIAM_OUTPUT_LOAD_USER:
            /* Do nothing */
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Load User Setup
 * Purpose:  Selects user value of the output termination for output amplitude
 *           and offset voltage.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpLoadUser (ViSession instrSession,
                                       ViReal64 outputLoad)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViInt16     channel             = 0;
    //ViReal64    voltage             = 0.0;
    pTSStatusDataRanges instrPtr    = {0};

    if (rssiam_invalidViReal64Range (outputLoad, 1.0, 1.0e6))
        return RSSIAM_ERROR_INVALID_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_outpChannel_Q (instrSession, &channel));

    /* Units dBm vs 50.0 ohms is only allowed combination */
    if ((instrPtr -> outputVoltageUnit == RSSIAM_OUTPUT_VOLT_UNIT_DBM) &&
        (fabs (outputLoad - 50.0) > NUMERIC_PRECISION))
        return RSSIAM_ERROR_SETTINGS_CONFLICT;

    //CHECKERR (rssiam_volt_Q (instrSession, RSSIAM_CURRENT_RANGE, &voltage));
    instrPtr -> outputLoad[channel - 1] = outputLoad;
    //CHECKERR (rssiam_volt (instrSession, voltage));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Load Query
 * Purpose:  Returns the output impedance.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpLoad_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   outputLoad
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViInt16     channel             = 0;
    pTSStatusDataRanges instrPtr    = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_outpChannel_Q (instrSession, &channel));

    if (!outputLoad)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    switch (range)
        {
        case RSSIAM_MIN_RANGE:
            *outputLoad = 1.0; /* Value is hardcoded here */
            break;
        case RSSIAM_MAX_RANGE:
            *outputLoad = 1.0e6; /* Value is hardcoded here */
            break;
        case RSSIAM_CURRENT_RANGE:
        default:
            *outputLoad = instrPtr -> outputLoad[channel - 1];
            break;
        }
    
    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Sync Setup
 * Purpose:  Enables or disables output from the SYNC terminal. The default is
 *           "OFF" When the sync signal is disabled, the output level on the
 *           SYNC terminal is indeterminate (it might be a TTL "high" or a TTL
 *           "low").
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpSync(
    ViSession   instrSession,
    ViInt16     outputSync
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (outputSync)
        {
        case RSSIAM_OUTPUT_SYNC_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "SYNC_OFF"));
            break;
        case RSSIAM_OUTPUT_SYNC_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "SYNC_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Sync Query
 * Purpose:  Returns whether the SYNC terminal output is enabled ("1") or
 *           disabled ("0").
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpSync_Q(
    ViSession   instrSession,
    ViPInt16    outputSync
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    outputSync_data = 0;

    if (!outputSync)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "SYNC_STATE", &outputSync_data, RSSIAM_CURRENT_RANGE));

    *outputSync = outputSync_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Setup
 * Purpose:  Enables or disables the front-panel output connector.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpSetup(
    ViSession   instrSession,
    ViInt16     outputSetup
)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr -> channelCoupling & RSSIAM_CHANNEL_COUPLING_OUTPUT)
        {
        ViInt16 activeChannelOld    = instrPtr -> activeChannel;
        ViInt16 channel             = 1;

        for (channel = 1; channel <= 2; channel++)
            {
            instrPtr -> activeChannel = channel;

            switch (outputSetup)
                {
                case RSSIAM_OUTPUT_SETUP_OFF:
                    if ((rssiam_status = rssiam_sendCmd (instrSession, "OUTPUT_OFF")) < VI_SUCCESS)
                        {
                        instrPtr -> activeChannel = activeChannelOld;
                        return rssiam_status;
                        }
                    break;
                case RSSIAM_OUTPUT_SETUP_ON:
                    if ((rssiam_status = rssiam_sendCmd (instrSession, "OUTPUT_ON")) < VI_SUCCESS)
                        {
                        instrPtr -> activeChannel = activeChannelOld;
                        return rssiam_status;
                        }

                    break;
                default:
                    return RSSIAM_ERROR_INVALID_VALUE;
                }
            instrPtr -> activeChannel = activeChannelOld;
            }
        }
    else
        {
        switch (outputSetup)
            {
            case RSSIAM_OUTPUT_SETUP_OFF:
                CHECKERR (rssiam_sendCmd (instrSession, "OUTPUT_OFF"));
                break;
            case RSSIAM_OUTPUT_SETUP_ON:
                CHECKERR (rssiam_sendCmd (instrSession, "OUTPUT_ON"));
                break;
            default:
                return RSSIAM_ERROR_INVALID_VALUE;
            }
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Query
 * Purpose:  Returns whether the front-panel output connector is enabled or
 *           disabled.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpSetup_Q(
    ViSession   instrSession,
    ViPInt16    outputSetup
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    outputSetup_data    = 0;

    if (!outputSetup)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "OUTPUT_STATE", &outputSetup_data, RSSIAM_CURRENT_RANGE));

    *outputSetup = outputSetup_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Start Phase Setup
 * Purpose:  Selects the start phase on the output of a channel.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpStartPhase(
    ViSession   instrSession,
    ViReal64    startPhase
)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    ViReal64            startPhase_data = startPhase;
    pTSStatusDataRanges instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr -> channelCoupling & RSSIAM_CHANNEL_COUPLING_PHASE)
        {
        ViInt16 activeChannelOld    = instrPtr -> activeChannel;
        ViInt16 channel             = 1;

        for (channel = 1; channel <= 2; channel++)
            {
            instrPtr -> activeChannel = channel;

            if ((rssiam_status = rssiam_setRegister (instrSession, "START_PHASE",
                &startPhase_data)) < VI_SUCCESS)
                {
                instrPtr -> activeChannel = activeChannelOld;
                return rssiam_status;
                }
            }
        instrPtr -> activeChannel = activeChannelOld;
        }
    else
        {
        CHECKERR (rssiam_setRegister (instrSession, "START_PHASE", &startPhase_data));
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Start Phase Query
 * Purpose:  Returns the start phase on the output of a channel.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpStartPhase_Q(
    ViSession   instrSession,
    ViPReal64   startPhase
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    startPhase_data = 0.0;

    if (!startPhase)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "START_PHASE", &startPhase_data, RSSIAM_CURRENT_RANGE));

    *startPhase = startPhase_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Filter Setup
 * Purpose:  Selects the filter on the output of a channel.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpFilter(
    ViSession   instrSession,
    ViInt16     outputFilter
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    CHECKERR (rssiam_setRegister (instrSession, "OUTPUT_FILTER", &outputFilter));

    if (outputFilter == RSSIAM_OUTPUT_FILTER_AUTO)
        {
        CHECKERR (rssiam_sendCmd (instrSession, "FILTER_AUTO_ON"));
        }
    else
        {
        CHECKERR (rssiam_sendCmd (instrSession, "FILTER_AUTO_OFF"));
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Filter Query
 * Purpose:  Returns the filter on the output of a channel.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpFilter_Q(
    ViSession   instrSession,
    ViPInt16    outputFilter
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    outputFilter_data   = 0;

    if (!outputFilter)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "OUTPUT_FILTER", &outputFilter_data, RSSIAM_CURRENT_RANGE));

    *outputFilter = outputFilter_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Filter Type Setup
 * Purpose:  Selects the characteristic of the low pass filter.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpFilterType(
    ViSession   instrSession,
    ViInt16     outputFilterType
)
{
    ViStatus    rssiam_status           = VI_SUCCESS;
    ViUInt16    outputFilterType_data   = outputFilterType;

    CHECKERR (rssiam_setRegister (instrSession, "FILTER_TYPE", &outputFilterType_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Filter Type Query
 * Purpose:  Returns the characteristic of the low pass filter.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpFilterType_Q(
    ViSession   instrSession,
    ViPInt16    outputFilterType
)
{
    ViStatus    rssiam_status           = VI_SUCCESS;
    ViUInt16    outputFilterType_data   = 0;

    if (!outputFilterType)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FILTER_TYPE", &outputFilterType_data, RSSIAM_CURRENT_RANGE));

    *outputFilterType = outputFilterType_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output External Filter Setup
 * Purpose:  Selects if external filter is connected.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_extFilter(
    ViSession   instrSession,
    ViInt16     externalFilter
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (externalFilter)
        {
        case RSSIAM_OUTPUT_EXT_FILTER_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "FILTER_EXT_OFF"));
            break;
        case RSSIAM_OUTPUT_EXT_FILTER_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "FILTER_EXT_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output External Filter Query
 * Purpose:  Returns if external filter is connected.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_extFilter_Q(
    ViSession   instrSession,
    ViPInt16    externalFilter
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    externalFilter_data = 0;

    if (!externalFilter)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FILTER_EXTERNAL", &externalFilter_data, RSSIAM_CURRENT_RANGE));

    *externalFilter = externalFilter_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Summary Setup
 * Purpose:  Sets whether the output signal I = (Q + I) is On or Off.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpSum(
    ViSession   instrSession,
    ViInt16     outputSummary)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (outputSummary)
        {
        case RSSIAM_OUTPUT_SUM_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "OUTPUT_SUM_OFF"));
            break;
        case RSSIAM_OUTPUT_SUM_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "OUTPUT_SUM_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Summary Query
 * Purpose:  Returns whether the  output signal I = (Q + I) is On or Off.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpSum_Q(
    ViSession   instrSession,
    ViPInt16    outputSummary
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    outputSummary_data  = 0;

    if (!outputSummary)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "OUTPUT_SUM", &outputSummary_data, RSSIAM_CURRENT_RANGE));

    *outputSummary = outputSummary_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Output Addition Setup
 * Purpose:  Sets whether the output signal Ch1 = (Ch1 + Ch2) is enabled or
 *           disabled.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpAddition (ViSession instrSession,
                                       ViInt16 outputAddition)
{
    return rssiam_outpSum (instrSession, outputAddition);
}

/*****************************************************************************
 * Function: Output Addition Query
 * Purpose:  Returns whether the output signal Ch1 = (Ch1 + Ch2) is enabled
 *           or disabled.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_outpAdditon_Q (ViSession instrSession,
                                        ViInt16 *outputSummary)
{
    return rssiam_outpSum_Q (instrSession, outputSummary);
}

/*****************************************************************************
 * Function: Pulse Period Setup
 * Purpose:  Sets period of a pulsed waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pulsePeriod(
    ViSession   instrSession,
    ViReal64    pulsePeriod
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    pulsePeriod_data    = pulsePeriod;

    CHECKERR (rssiam_setRegister (instrSession, "PULSE_PERIOD", &pulsePeriod_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Pulse Period Query
 * Purpose:  Returns the period of the pulse waveform in seconds.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pulsePeriod_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   pulsePeriod
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    pulsePeriod_data    = 0.0;

    if (!pulsePeriod)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PULSE_PERIOD", &pulsePeriod_data, range));

    *pulsePeriod = pulsePeriod_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Pulse Width Setup
 * Purpose:  Sets the width or duration of the pulse in seconds. The pulse
 *           width represents the time from the 50% threshold of the rising
 *           edge of the pulse to the 50% threshold of the next falling edge.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pulseWidth(
    ViSession   instrSession,
    ViReal64    pulseWidth
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    pulseWidth_data = pulseWidth;

    CHECKERR (rssiam_setRegister (instrSession, "PULSE_WIDTH", &pulseWidth_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Pulse Width Query
 * Purpose:  Returns the width or duration of the pulse in seconds.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pulseWidth_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   pulseWidth
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    pulseWidth_data = 0.0;

    if (!pulseWidth)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PULSE_WIDTH", &pulseWidth_data, range));

    *pulseWidth = pulseWidth_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Pulse Polarity Setup
 * Purpose:  Sets the polarity of pulses.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pulsePolarity(
    ViSession   instrSession,
    ViInt16     pulsePolarity
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    pulsePolarity_data  = pulsePolarity;

    CHECKERR (rssiam_setRegister (instrSession, "PULSE_POLARITY", &pulsePolarity_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Pulse Polarity Query
 * Purpose:  Returns the polarity of pulses.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pulsePolarity_Q(
    ViSession   instrSession,
    ViPInt16    pulsePolarity
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    pulsePolarity_data  = 0;

    if (!pulsePolarity)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PULSE_POLARITY", &pulsePolarity_data, RSSIAM_CURRENT_RANGE));

    *pulsePolarity = pulsePolarity_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sync Type Setup
 * Purpose:  Selects the type of the sync signal.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_syncType(
    ViSession   instrSession,
    ViInt16     syncType
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    syncType_data   = syncType;

    CHECKERR (rssiam_setRegister (instrSession, "SYNC_TYPE", &syncType_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sync Type Query
 * Purpose:  Returns the type of the sync signal.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_syncType_Q(
    ViSession   instrSession,
    ViPInt16    syncType
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    syncType_data   = 0;

    if (!syncType)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "SYNC_TYPE", &syncType_data, RSSIAM_CURRENT_RANGE));

    *syncType = syncType_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sync Polarity Setup
 * Purpose:  Selects the polarity of the sync signal.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_syncPolarity(
    ViSession   instrSession,
    ViInt16     syncPolarity
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    syncPolarity_data   = syncPolarity;

    CHECKERR (rssiam_setRegister (instrSession, "SYNC_POLARITY", &syncPolarity_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sync Polarity Query
 * Purpose:  Returns the polarity of the sync signal.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_syncPolarity_Q(
    ViSession   instrSession,
    ViPInt16    syncPolarity
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    syncPolarity_data   = 0;

    if (!syncPolarity)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "SYNC_POLARITY", &syncPolarity_data, RSSIAM_CURRENT_RANGE));

    *syncPolarity = syncPolarity_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Modulation Points Setup
 * Purpose:  This function sets additional parameter to AM, FM, PM (number of
 *           modulation points to calculate envelope of the modulated signal).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_mPoints(
    ViSession instrSession,
    ViInt32 modulationPoints
)
{
    ViStatus    rssiam_status           = VI_SUCCESS;
    ViUInt16    modulationPoints_data   = modulationPoints;

    CHECKERR (rssiam_setRegister (instrSession, "MODULATION_POINTS", &modulationPoints_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Modulation Points Query
 * Purpose:  This function returns additional parameter of AM, FM, PM (number
 *           of modulation points to calculate envelope of the modulated
 *           signal).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_mPoints_Q(
    ViSession instrSession,
    ViInt16 range,
    ViPInt32 modulationPoints
)
{
    ViStatus    rssiam_status           = VI_SUCCESS;
    ViUInt16    modulationPoints_data   = 0;

    if (!modulationPoints)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "MODULATION_POINTS",
        &modulationPoints_data, range));

    *modulationPoints = modulationPoints_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Amplitude Mod Depth Setup
 * Purpose:  Sets the internal modulation depth in percent.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amDept(
    ViSession   instrSession,
    ViReal64    amplitudeDepth
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal32    amplitudeDepth_data = 0.0;

    DBL2FLT (amplitudeDepth, amplitudeDepth_data);

    CHECKERR (rssiam_setRegister (instrSession, "AM_DEPTH", &amplitudeDepth_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Amplitude Mod Depth Query
 * Purpose:  Returns the internal modulation depth.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amDept_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   amplitudeDepth
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal32    amplitudeDepth_data = 0.0;

    if (!amplitudeDepth)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "AM_DEPTH", &amplitudeDepth_data, range));

    *amplitudeDepth = amplitudeDepth_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Amplitude Mod Int Func Setup
 * Purpose:  Selects the shape of the modulating waveform.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amIntFunc(
    ViSession   instrSession,
    ViInt16     amIntFunction
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    amIntFunction_data  = amIntFunction;

    CHECKERR (rssiam_setRegister (instrSession, "AM_FUNCTION", &amIntFunction_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Amplitude Mod Int Func Query
 * Purpose:  Returns a numeric value indicating the shape of the internal
 *           modulating waveform.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amIntFunc_Q(
    ViSession   instrSession,
    ViPInt16    amIntFunction
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    amIntFunction_data  = 0;

    if (!amIntFunction)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "AM_FUNCTION", &amIntFunction_data, RSSIAM_CURRENT_RANGE));

    *amIntFunction = amIntFunction_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Amplitude Mod Int Freq Setup
 * Purpose:  Sets the frequency of the modulating waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amIntFreq(
    ViSession   instrSession,
    ViReal64    amFrequency
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    amFrequency_data    = amFrequency;

    CHECKERR (rssiam_setRegister (instrSession, "AM_FREQUENCY", &amFrequency_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Amplitude Mod Int Freq Query
 * Purpose:  Returns the internal modulating frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amIntFreq_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   amFrequency
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    amFrequency_data    = 0.0;

    if (!amFrequency)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "AM_FREQUENCY", &amFrequency_data, range));

    *amFrequency = amFrequency_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Amplitude Mod Stat Setup
 * Purpose:  Enables or disables amplitude modulation. Only one modulation
 *           mode can be enabled at a time. When you enable AM, the previous
 *           modulation mode is turned off.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amState(
    ViSession   instrSession,
    ViInt16     amState
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (amState)
        {
        case RSSIAM_AMP_STAT_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "AM_OFF"));
            break;
        case RSSIAM_AMP_STAT_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "AM_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Amplitude Mod Stat Query
 * Purpose:  Returns whether AM is enabled or disabled.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amState_Q(
    ViSession   instrSession,
    ViPInt16    amState
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    amState_data    = 0;

    if (!amState)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "AM_STATE", &amState_data, RSSIAM_CURRENT_RANGE));

    *amState = amState_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Frequency Mod Dev Setup
 * Purpose:  Sets the peak frequency deviation in hertz. This value represents
 *           the variation in frequency of the modulating waveform from the
 *           carrier frequency.
 *
 *           The sum of the Carrier Frequency and FM Peak Deviation must be
 *           less than the maximum frequency for the selected function. The
 *           difference of the Carrier Frequency and FM Peak Deviation must be
 *           greater than the minimum frequency for the selected function.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmDev(
    ViSession   instrSession,
    ViReal64    fmDeviation
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    fmDeviation_data    = fmDeviation;

    CHECKERR (rssiam_setRegister (instrSession, "FM_PEAK_DEVIATION", &fmDeviation_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Frequency Mod Dev Query
 * Purpose:  Returns the peak frequency deviation in hertz. This value
 *           represents the variation in frequency of the modulating waveform
 *           from the carrier frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmDev_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   fmDeviation
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    fmDeviation_data    = 0.0;

    if (!fmDeviation)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FM_PEAK_DEVIATION", &fmDeviation_data, range));

    *fmDeviation = fmDeviation_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Frequency Mod Int Func Setup
 * Purpose:  Selects the shape of the modulating waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmIntFunc(
    ViSession   instrSession,
    ViInt16     fmIntFunction
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    fmIntFunction_data  = fmIntFunction;

    CHECKERR (rssiam_setRegister (instrSession, "FM_FUNCTION", &fmIntFunction_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Frequency Mod Int Func Query
 * Purpose:  Returns the shape of the modulating waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmIntFunc_Q(
    ViSession   instrSession,
    ViPInt16    fmIntFunction
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    fmIntFunction_data  = 0;

    if (!fmIntFunction)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FM_FUNCTION", &fmIntFunction_data, RSSIAM_CURRENT_RANGE));

    *fmIntFunction = fmIntFunction_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Frequency Mod Int Freq Setup
 * Purpose:  Sets the frequency of the modulating waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmIntFreq(
    ViSession   instrSession,
    ViReal64    fmFrequency
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    fmFrequency_data    = fmFrequency;

    CHECKERR (rssiam_setRegister (instrSession, "FM_FREQUENCY", &fmFrequency_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Frequency Mod Int Freq Query
 * Purpose:  Returns the frequency of the modulating waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmIntFreq_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   fmFrequency
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    fmFrequency_data    = 0.0;

    if (!fmFrequency)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FM_FREQUENCY", &fmFrequency_data, range));

    *fmFrequency = fmFrequency_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Frequency Mod Stat Setup
 * Purpose:  Enables or disables frequency modulation. Only one modulation
 *           mode can be enabled at a time. When you enable FM, the previous
 *           modulation mode is turned off.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmStat(
    ViSession   instrSession,
    ViInt16     fmState
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (fmState)
        {
        case RSSIAM_FREQ_STAT_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "FM_OFF"));
            break;
        case RSSIAM_FREQ_STAT_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "FM_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Frequency Mod Stat Query
 * Purpose:  Returns whether is frequency modulation enabled or disabled.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmStat_Q(
    ViSession   instrSession,
    ViPInt16    fmState
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    fmState_data    = 0;

    if (!fmState)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FM_STATE", &fmState_data, RSSIAM_CURRENT_RANGE));

    *fmState = fmState_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Phase Mod Dev Setup
 * Purpose:  Sets the modulation deviation of a PM signal. The phase of the
 *           carrier is varied by the amplitude of the modulating waveform.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmDev(
    ViSession   instrSession,
    ViReal64    pmDeviation
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    pmDeviation_data    = pmDeviation;

    CHECKERR (rssiam_setRegister (instrSession, "PM_DEVIATION", &pmDeviation_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Phase Mod Dev Query
 * Purpose:  Returns the modulation deviation of a PM signal. The phase of the
 *           carrier is varied by the amplitude of the modulating waveform.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmDev_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   pmDeviation
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    pmDeviation_data    = 0.0;

    if (!pmDeviation)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PM_DEVIATION", &pmDeviation_data, range));

    *pmDeviation = pmDeviation_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Phase Mod Int Func Setup
 * Purpose:  Selects the shape of the modulating waveform.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmIntFunc(
    ViSession   instrSession,
    ViInt16     pmIntFunction
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    pmIntFunction_data  = pmIntFunction;

    CHECKERR (rssiam_setRegister (instrSession, "PM_FUNCTION", &pmIntFunction_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Phase Mod Int Func Query
 * Purpose:  Returns the shape of the modulating waveform.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmIntFunc_Q(
    ViSession   instrSession,
    ViPInt16    pmIntFunction
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    pmIntFunction_data  = 0;

    if (!pmIntFunction)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PM_FUNCTION", &pmIntFunction_data, RSSIAM_CURRENT_RANGE));

    *pmIntFunction = pmIntFunction_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Phase Mod Int Freq Setup
 * Purpose:  Sets the frequency of the modulating waveform.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmIntFreq(
    ViSession   instrSession,
    ViReal64    pmFrequency
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    pmFrequency_data    = pmFrequency;

    CHECKERR (rssiam_setRegister (instrSession, "PM_FREQUENCY", &pmFrequency_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Phase Mod Int Freq Query
 * Purpose:  Returns the frequency of the modulating waveform.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmIntFreq_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   pmFrequency
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    pmFrequency_data    = 0.0;

    if (!pmFrequency)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PM_FREQUENCY", &pmFrequency_data, range));

    *pmFrequency = pmFrequency_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Phase Mod Stat Setup
 * Purpose:  Enables or disables phase modulation. Only one modulation mode
 *           can be enabled at a time. When you enable PM, the previous
 *           modulation mode is turned off.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmStat(
    ViSession   instrSession,
    ViInt16     pmState
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (pmState)
        {
        case RSSIAM_PHASE_STAT_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "PM_OFF"));
            break;
        case RSSIAM_PHASE_STAT_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "PM_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Phase Mod Stat Query
 * Purpose:  Returns whether is phase modulation enabled or disabled.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmStat_Q(
    ViSession   instrSession,
    ViPInt16    pmState
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    pmState_data    = 0;

    if (!pmState)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PM_STATE", &pmState_data, RSSIAM_CURRENT_RANGE));

    *pmState = pmState_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Trigger Frequency Setup
 * Purpose:  Sets the internal trigger generator frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigFrequency (ViSession instrSession,
                                        ViReal64 triggerFrequency)
{
    return rssiam_bmIntRate (instrSession, triggerFrequency);
}

/*****************************************************************************
 * Function: Trigger Frequency Query
 * Purpose:  Returns the internal trigger generator frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigFrequency_Q (ViSession instrSession,
                                          ViReal64 *triggerFrequency)
{
    return rssiam_bmIntRate_Q (instrSession, RSSIAM_CURRENT_RANGE, triggerFrequency);
}

/*****************************************************************************
 * Function: Trigger Period Setup
 * Purpose:  Sets the internal trigger generator period.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigPeriod (ViSession instrSession,
                                     ViReal64 triggerPeriod)
{
    return rssiam_bmIntRate (instrSession, 1.0 / triggerPeriod);
}

/*****************************************************************************
 * Function: Trigger Period Query
 * Purpose:  Returns the internal trigger generator period.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigPeriod_Q (ViSession instrSession,
                                       ViReal64 *triggerPeriod)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    rate = 0.0;

    CHECKERR (rssiam_bmIntRate_Q (instrSession, RSSIAM_CURRENT_RANGE, &rate));
    
    *triggerPeriod = 1.0 / rate;
    
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Burst Mod Ncycles Setup
 * Purpose:  Sets the number of cycles to be output per burst.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_bmNcyc(
    ViSession   instrSession,
    ViInt32     noofCycles
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    noofCycles_data = noofCycles;

    CHECKERR (rssiam_setRegister (instrSession, "BM_COUNT", &noofCycles_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Burst Mod Ncycles Query
 * Purpose:  Returns the number of cycles outputed per burst.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_bmNcyc_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPInt32    noofCycles
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    noofCycles_data = 0;

    if (!noofCycles)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "BM_COUNT", &noofCycles_data, range));

    *noofCycles = noofCycles_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Burst Mod Int Rate Setup
 * Purpose:  Sets the burst rate for internally triggered bursts. The burst
 *           rate frequency defines the interval between bursts.
 *
 *           The burst rate setting is used only when internal triggering is
 *           enabled. The burst rate is ignored when manual triggering or
 *           external triggering is enabled.
 *
 *           It is possible to specify a burst rate which is too fast for the
 *           function generator to output with the specified carrier frequency
 *           and burst count. If the burst rate is too high, the function
 *           generator will internally adjust it as needed to continuously
 *           re-trigger the burst. The adjustment is handled internally by the
 *           function generator.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_bmIntRate(
    ViSession   instrSession,
    ViReal64    bmIntRate
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    rate            = (bmIntRate < NUMERIC_PRECISION) ? 0.0 : 1.0 / bmIntRate;

    CHECKERR (rssiam_setRegister (instrSession, "BM_RATE", &rate));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Burst Mod Int Rate Query
 * Purpose:  Returns the burst rate frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_bmIntRate_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   bmIntRate
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    rate            = 0.0;
    ViInt16     reverseRange    = 0;

    if (!bmIntRate)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    switch (range)
        {
        case RSSIAM_MIN_RANGE:
            reverseRange = RSSIAM_MAX_RANGE;
            break;
        case RSSIAM_MAX_RANGE:
            reverseRange = RSSIAM_MIN_RANGE;
            break;
        default:
            reverseRange = range;
            break;
        }

    CHECKERR (rssiam_getRegister (instrSession, "BM_RATE", &rate, reverseRange));

    *bmIntRate = (rate < NUMERIC_PRECISION) ? 0.0 : 1.0 / rate;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Burst Mod Sour Setup
 * Purpose:  Selects the burst mode. In the triggered mode, the function
 *           generator outputs a waveform with a specified number of cycles
 *           (burst count) each time a trigger is received. In the gated mode,
 *           the output waveform is either "on" or "off" based on the level of
 *           the external signal applied to the rear panel Burst In connector.
 *           When the internal burst source is selected, the external gated
 *           mode is disabled.
 *
 *           When the gated source is selected, the burst count, burst rate
 *           and trigger source are ignored.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_bmSour(
    ViSession   instrSession,
    ViInt16     bmSource
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    bmSource_data   = bmSource;

    CHECKERR (rssiam_setRegister (instrSession, "BM_SOURCE", &bmSource_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Burst Mod Sour Query
 * Purpose:  Returns the burst modulation source.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_bmSour_Q(
    ViSession   instrSession,
    ViPInt16    bmSource
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    bmSource_data   = 0;

    if (!bmSource)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "BM_SOURCE", &bmSource_data, RSSIAM_CURRENT_RANGE));

    *bmSource = bmSource_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Burst Mod Stat Setup
 * Purpose:  Enables or disables burst modulation. Only one modulation mode
 *           can be enabled at a time. When you enable BM, the previous
 *           modulation mode is turned off.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_bmStat(
    ViSession   instrSession,
    ViInt16     bmState
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (bmState)
        {
        case RSSIAM_BM_STAT_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "BM_OFF"));
            break;
        case RSSIAM_BM_STAT_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "BM_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Burst Mod Stat Query
 * Purpose:  Returns whether burst modulation is enabled or disabled.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_bmStat_Q(
    ViSession   instrSession,
    ViPInt16    bmState
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    bmState_data    = 0;

    if (!bmState)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "BM_STATE", &bmState_data, RSSIAM_CURRENT_RANGE));

    *bmState = bmState_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: FSK Frequency Setup
 * Purpose:  Sets FSK "hop" frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fskFreq(
    ViSession   instrSession,
    ViReal64    fskFrequency
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    fskFrequency_data   = fskFrequency;

    CHECKERR (rssiam_setRegister (instrSession, "FSK_FREQUENCY", &fskFrequency_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: FSK Frequency Query
 * Purpose:  Returns the FSK "hop" frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fskFreq_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   fskFrequency
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    fskFrequency_data   = 0.0;

    if (!fskFrequency)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FSK_FREQUENCY", &fskFrequency_data, range));

    *fskFrequency = fskFrequency_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: FSK Internal Rate Setup
 * Purpose:  Sets the rate at which the output frequency "shifts" between the
 *           carrier and hop frequency when the internal FSK source is
 *           selected.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fskIntRate(
    ViSession   instrSession,
    ViReal64    fskIntRate
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    rate            = (fskIntRate < NUMERIC_PRECISION) ? 0.0 : 1 / fskIntRate;

    CHECKERR (rssiam_setRegister (instrSession, "FSK_RATE", &rate));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: FSK Internal Rate Query
 * Purpose:  Returns the FSK rate.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fskIntRate_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   fskIntRate
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    rate            = 0.0;
    ViInt16     reverseRange    = 0;

    if (!fskIntRate)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    switch (range)
        {
        case RSSIAM_MIN_RANGE:
            reverseRange = RSSIAM_MAX_RANGE;
            break;
        case RSSIAM_MAX_RANGE:
            reverseRange = RSSIAM_MIN_RANGE;
            break;
        default:
            reverseRange = range;
            break;
        }

    CHECKERR (rssiam_getRegister (instrSession, "FSK_RATE", &rate, reverseRange));

    *fskIntRate = (rate < NUMERIC_PRECISION) ? 0.0 : 1 / rate;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: FSK Source Setup
 * Purpose:  Selects the internal or external FSK source.
 *
 *           When the internal source is selected, the rate at which the
 *           output frequency "shifts" between the carrier frequency and hop
 *           frequency is determined by the FSK rate specified.
 *
 *           When the external source is selected, the signal level on the
 *           rear-panel FSK terminal determines the output frequency. When a
 *           "low" TTL level is present, the carrier frequency is output. When
 *           a "high" TTL level is present, the hop frequency is output.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fskSour(
    ViSession   instrSession,
    ViInt16     fskSource
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    fskSource_data  = fskSource;

    CHECKERR (rssiam_setRegister (instrSession, "FSK_SOURCE", &fskSource_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: FSK Source Query
 * Purpose:  Returns the internal or external FSK source.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fskSour_Q(
    ViSession   instrSession,
    ViPInt16    fskSource
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    fskSource_data  = 0;

    if (!fskSource)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FSK_SOURCE", &fskSource_data, RSSIAM_CURRENT_RANGE));

    *fskSource = fskSource_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: FSK Stat Setup
 * Purpose:  Enables or disables FSK modulation. Only one modulation mode can
 *           be enabled at a time. When you enable FSK, the previous modulation
 *           mode is turned off.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fskStat(
    ViSession   instrSession,
    ViInt16     fskState
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (fskState)
        {
        case RSSIAM_FSK_STAT_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "FSK_OFF"));
            break;
        case RSSIAM_FSK_STAT_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "FSK_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: FSK Stat Query
 * Purpose:  Returns whether FSK modulation is enabled or disabled.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fskStat_Q(
    ViSession   instrSession,
    ViPInt16    fskState
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    fskState_data   = 0;

    if (!fskState)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FSK_STATE", &fskState_data, RSSIAM_CURRENT_RANGE));

    *fskState = fskState_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: PSK Phase Setup
 * Purpose:  Sets the PSK "hop" phase.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pskPhase(
    ViSession   instrSession,
    ViReal64    pskPhase
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    pskPhase_data   = pskPhase;

    CHECKERR (rssiam_setRegister (instrSession, "PSK_PHASE", &pskPhase_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: PSK Phase Query
 * Purpose:  Returns the PSK "hop" phase.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pskPhase_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   pskPhase
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    pskPhase_data   = 0.0;

    if (!pskPhase)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PSK_PHASE", &pskPhase_data, range));

    *pskPhase = pskPhase_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: PSK Internal Rate Setup
 * Purpose:  Sets the rate at which the output phase "shifts" at the carrier
 *           frequency and when the internal FSK source is selected.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pskIntRate(
    ViSession   instrSession,
    ViReal64    pskIntRate
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    rate            = (pskIntRate < NUMERIC_PRECISION) ? 0.0 : 1 / pskIntRate;

    CHECKERR (rssiam_setRegister (instrSession, "PSK_RATE", &rate));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: PSK Internal Rate Query
 * Purpose:  Returns the rate at which the output phase "shifts" at the
 *           carrier frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pskIntRate_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   pskIntRate
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    rate            = 0.0;
    ViInt16     reverseRange    = 0;

    if (!pskIntRate)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    switch (range)
        {
        case RSSIAM_MIN_RANGE:
            reverseRange = RSSIAM_MAX_RANGE;
            break;
        case RSSIAM_MAX_RANGE:
            reverseRange = RSSIAM_MIN_RANGE;
            break;
        default:
            reverseRange = range;
            break;
        }

    CHECKERR (rssiam_getRegister (instrSession, "PSK_RATE", &rate, reverseRange));

    *pskIntRate = (rate < NUMERIC_PRECISION) ? 0.0 : 1 / rate;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: PSK Source Setup
 * Purpose:  Selects the internal or external PSK source.
 *
 *           When the internal source is selected, the rate at which the phase
 *           of output frequency "shifts" is determined by the PSK rate
 *           specified.
 *
 *           When the external source is selected, the signal level on the
 *           rear-panel PSK terminal determines phase of the output frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pskSour(
    ViSession   instrSession,
    ViInt16     pskSource
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    pskSource_data  = pskSource;

    CHECKERR (rssiam_setRegister (instrSession, "PSK_SOURCE", &pskSource_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: PSK Source Query
 * Purpose:  Returns the internal or external PSK source.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pskSour_Q(
    ViSession   instrSession,
    ViPInt16    pskSource
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    pskSource_data  = 0;

    if (!pskSource)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PSK_SOURCE", &pskSource_data, RSSIAM_CURRENT_RANGE));

    *pskSource = pskSource_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: PSK Stat Setup
 * Purpose:  Enables or disables PSK modulation. Only one modulation mode can
 *           be enabled at a time. When you enable PSK, the previous modulation
 *           mode is turned off.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pskStat(
    ViSession   instrSession,
    ViInt16     pskState
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (pskState)
        {
        case RSSIAM_PSK_STAT_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "PSK_OFF"));
            break;
        case RSSIAM_PSK_STAT_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "PSK_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: PSK Stat Query
 * Purpose:  Returns whether PSK modulation is enabled or disabled.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pskStat_Q(
    ViSession   instrSession,
    ViPInt16    pskState
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    pskState_data   = 0;

    if (!pskState)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "PSK_STATE", &pskState_data, RSSIAM_CURRENT_RANGE));

    *pskState = pskState_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: User Modulation Volatile Setup
 * Purpose:  Uploads floating-point values between -1 and +1 into volatile
 *           memory (modulation memory). Out of ramge values are coerced to
 *           the lower (upper) range limit.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_userVolatile (ViSession instrSession,
    ViInt32     noofPoints,
    ViReal64    _VI_FAR dataArray[])
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt32     idx             = 0;
    ViInt16     min              = -16384;
    ViInt16     max              = 16383;
    ViReal64    value           = 0.0;
    ViReal64    resolution      = 2.0 / (max - min); /* range is from -1.0 to 1.0 */
    ViInt16     *DacDataArray;

    if (rssiam_invalidViInt32Range (noofPoints, 262144, 262144))
        return VI_ERROR_PARAMETER2;
    if (!dataArray)
        return VI_ERROR_PARAMETER3;

    /* Scale data from range -1 to +1 to the DAC codes */
    DacDataArray = malloc (noofPoints * sizeof (ViInt16));
    DacDataArray = memset (DacDataArray, 0, noofPoints * sizeof (ViInt16));

    for (idx = 0; idx < noofPoints; idx++)
        {
        value = dataArray[idx] / resolution;
        DacDataArray[idx] = (value > max) ? max : value;
        DacDataArray[idx] = (value < min) ? min : value;
        }

    rssiam_status = rssiam_userDacVolatile (instrSession, noofPoints, DacDataArray);

    free (DacDataArray);

    return rssiam_status;
}

/*****************************************************************************
 * Function: User Modulation Dac Volatile Setup
 * Purpose:  Uploads binary integer values between -16384 and 16383 into
 *           volatile memory (modulation memory).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_userDacVolatile (ViSession instrSession,
    ViInt32     noofPoints,
    ViInt16     _VI_FAR dataArray[])
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt32     index           = 0,
                idx             = 0,
                loops           = 0,
                remainder       = 0,
                blockSize       = 2000; /* block size limit */
    ViInt16     *p2dataArray;
    

    if (rssiam_invalidViInt32Range (noofPoints, 262144, 262144))
        return VI_ERROR_PARAMETER2;
    if (!dataArray)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiam_getIndexFromName ("ARB_DATA_DAC_LOAD", &index));

    /* Due to internal device limit (4000 Bytes => 2000 points) use block transfer */

    loops       = noofPoints / blockSize;
    remainder   = noofPoints % blockSize;

    for (idx = 0; idx < loops; idx++)
        {
        p2dataArray = dataArray + idx * blockSize;
        GSRegisterSetTable[index].Size = blockSize * sizeof (ViInt16);
        CHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* mod data */, p2dataArray, GSRegisterSetTable[index].Size));
        }

    if (remainder > 0)
        {
        p2dataArray = dataArray + idx * blockSize;
        GSRegisterSetTable[index].Size = remainder * sizeof (ViInt16);
        CHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* mod data */, p2dataArray, GSRegisterSetTable[index].Size));
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: FM User Modulation Volatile Setup
 * Purpose:  Uploads floating-point values between -1 and +1 into volatile
 *           memory (modulation memory). Out of ramge values are coerced to
 *           the lower (upper) range limit.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmUserVolatile (ViSession instrSession,
                                         ViInt32 noofSamples,
                                         ViReal64 _VI_FAR dataArray[])
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViInt32     idx                 = 0;
    ViReal64    value               = 0.0,
                carrier_frequency   = 0.0,
                fm_peak_deviation   = 0.0;
    ViUInt32    *DacDataArray;

    if (rssiam_invalidViInt32Range (noofSamples, 131072, 131072))
        return VI_ERROR_PARAMETER2;
    if (!dataArray)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiam_getRegister (instrSession, "CARRIER_FREQUENCY", &carrier_frequency, RSSIAM_CURRENT_RANGE));
    CHECKERR (rssiam_getRegister (instrSession, "FM_PEAK_DEVIATION", &fm_peak_deviation, RSSIAM_CURRENT_RANGE));

    /* Scale data from range -1 to +1 to the DAC codes */
    DacDataArray = malloc (noofSamples * sizeof (ViUInt32));
    DacDataArray = memset (DacDataArray, 0, noofSamples * sizeof (ViUInt32));

    for (idx = 0; idx < noofSamples; idx++)
        {
        value = dataArray[idx];
        value = (value > 1.0) ? 1.0 : value;
        value = (value < -1.0) ? -1.0 : value;
        /* Calculate data */
        DacDataArray[idx] = (pow (2, 32) / 100.0e6 /* Fclk */) * (carrier_frequency + (fm_peak_deviation * value));
        }

    rssiam_status = rssiam_fmUserDacVolatile (instrSession, noofSamples, DacDataArray);

    free (DacDataArray);

    return rssiam_status;

}

/*****************************************************************************
 * Function: FM User Modulation Dac Volatile Setup
 * Purpose:  Uploads binary integer values between 0 and 4294967295 into
 *           volatile memory (modulation memory).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_fmUserDacVolatile (ViSession instrSession,
                                            ViInt32 noofSamples,
                                            ViUInt32 _VI_FAR dataArray[])
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt32     index           = 0,
                idx             = 0,
                loops           = 0,
                remainder       = 0,
                blockSize       = 2000, /* block size limit */
                dataSize        = 0,
                noofPoints      = 0;
    ViInt16     tmp             = 0,
                *p2data,
                *data;

    if (rssiam_invalidViInt32Range (noofSamples, 131072, 131072))
        return VI_ERROR_PARAMETER2;
    if (!dataArray)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiam_getIndexFromName ("ARB_DATA_DAC_LOAD", &index));

    /* Modulating waveform data format for FM is ViUInt32 with range <0; 4294967295>,
       where device accepts data in form

       low_word_0, high_word_0, low_word_1, high_word_1, ...

       sizeof (ViUInt32) is 2 * sizeof (ViUInt16)
    */

    dataSize = noofSamples * sizeof(ViUInt32);
    noofPoints = 2 * noofSamples;
    
    data = malloc (dataSize);
    memcpy (data, dataArray, dataSize);

    /* (Auto)Convert data into right-to-left (little-endian) format. */
    {
    char *dataPtr = (char *)data;

    rssiam_SWAP_32(dataPtr, noofPoints);
    }
    
    /* Swap the the words from original double word data */
    for (idx = 0; idx < (noofPoints - 1); idx++)
        {
        tmp = data[idx];
        data[idx] = data[idx + 1];
        data[idx + 1] = tmp;
        }

    /* Due to internal device limit (4000 Bytes => 2000 points) use block transfer */

    loops       = noofPoints / blockSize;
    remainder   = noofPoints % blockSize;

    for (idx = 0; idx < loops; idx++)
        {
        p2data = data + idx * blockSize;
        GSRegisterSetTable[index].Size = blockSize * sizeof (ViInt16);
        GOCHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* mod data */, p2data, GSRegisterSetTable[index].Size));
        }

    if (remainder > 0)
        {
        p2data = data + idx * blockSize;
        GSRegisterSetTable[index].Size = remainder * sizeof (ViInt16);
        GOCHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* mod data */, p2data, GSRegisterSetTable[index].Size));
        }

    GOCHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

ERROR:

    if (data)
        free(data);

    return rssiam_status;
}

/*****************************************************************************
 * Function: AM User Modulation Volatile Setup
 * Purpose:  Uploads floating-point values between -1 and +1 into volatile
 *           memory (modulation memory). Out of ramge values are coerced to
 *           the lower (upper) range limit.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amUserVolatile (ViSession instrSession,
                                         ViInt32 noofPoints,
                                         ViReal64 _VI_FAR dataArrayCH1[],
                                         ViReal64 _VI_FAR dataArrayCH2[])
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt32     idx             = 0;
    ViInt16     min              = -32768;
    ViInt16     max              = 32767;
    ViReal64    value           = 0.0;
    ViReal64    resolution      = 2.0 / (max - min); /* range is from -1.0 to 1.0 */
    ViInt16     *p2dataArrayCH1,
                *p2dataArrayCH2;

    if (rssiam_invalidViInt32Range (noofPoints, 262144, 262144))
        return VI_ERROR_PARAMETER2;
    if (!dataArrayCH1)
        return VI_ERROR_PARAMETER3;
    if (!dataArrayCH2)
        return VI_ERROR_PARAMETER4;

    /* Scale data from range -1 to +1 to the DAC codes */
    p2dataArrayCH1 = malloc (noofPoints * sizeof (ViInt16));
    p2dataArrayCH2 = malloc (noofPoints * sizeof (ViInt16));

    for (idx = 0; idx < noofPoints; idx++)
        {
        /* Ch1 */
        value = dataArrayCH1[idx] / resolution;
        p2dataArrayCH1[idx] = (value > max) ? max : value;
        p2dataArrayCH1[idx] = (value < min) ? min : value;
        /* Ch2 */
        value = dataArrayCH2[idx] / resolution;
        p2dataArrayCH2[idx] = (value > max) ? max : value;
        p2dataArrayCH2[idx] = (value < min) ? min : value;
        }

    GOCHECKERR (rssiam_amUserDacVolatile (instrSession, noofPoints, p2dataArrayCH1, p2dataArrayCH2));

ERROR:

    if (p2dataArrayCH1)
        free (p2dataArrayCH1);

    if (p2dataArrayCH2)
        free (p2dataArrayCH2);

    return rssiam_status;
}

/*****************************************************************************
 * Function: AM User Modulation Dac Volatile Setup
 * Purpose:  Uploads binary integer values between -32768 and 32767 into
 *           volatile memory (modulation memory).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_amUserDacVolatile (ViSession instrSession,
                                            ViInt32 noofPoints,
                                            ViInt16 _VI_FAR dataArrayCH1[],
                                            ViInt16 _VI_FAR dataArrayCH2[])
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt32     index           = 0,
                idx             = 0,
                loops           = 0,
                remainder       = 0,
                blockSize       = 2000; /* block size limit */
    ViInt16     *p2dataArrayCH1,
                *p2dataArrayCH2,
                channel         = 0,
                function        = 0;
    ViReal64    depth           = 0.0;

    if (rssiam_invalidViInt32Range (noofPoints, 262144, 262144))
        return VI_ERROR_PARAMETER2;
    if (!dataArrayCH1)
        return VI_ERROR_PARAMETER3;
    if (!dataArrayCH2)
        return VI_ERROR_PARAMETER4;

    GOCHECKERR (rssiam_outpChannel_Q (instrSession, &channel));
    GOCHECKERR (rssiam_getIndexFromName ("ARB_DATA_DAC_LOAD", &index));

    /* Due to internal device limit (4000 Bytes => 2000 points) use block transfer */

    loops       = noofPoints / blockSize;
    remainder   = noofPoints % blockSize;

    /* --- Ch1 Setup Procedure --- */

    GOCHECKERR (rssiam_outpChannel (instrSession, RSSIAM_CH1));
    GOCHECKERR (rssiam_amIntFunc_Q (instrSession, &function));
    GOCHECKERR (rssiam_amDept_Q (instrSession, RSSIAM_CURRENT_RANGE, &depth));

    for (idx = 0; idx < loops; idx++)
        {
        p2dataArrayCH1 = dataArrayCH1 + idx * blockSize;
        GSRegisterSetTable[index].Size = blockSize * sizeof (ViInt16);
        GOCHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* AM arb data */, p2dataArrayCH1, GSRegisterSetTable[index].Size));
        }

    if (remainder > 0)
        {
        p2dataArrayCH1 = dataArrayCH1 + idx * blockSize;
        GSRegisterSetTable[index].Size = remainder * sizeof (ViInt16);
        GOCHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* AM arb data */, p2dataArrayCH1, GSRegisterSetTable[index].Size));
        }

    GOCHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    GOCHECKERR (rssiam_amIntFunc (instrSession, function));
    GOCHECKERR (rssiam_amDept (instrSession, depth));

    /* Enable AM on Ch1. Calculated points are stored in modulating
       memory in positions for channel 1. Disable AM on Ch1. */
    GOCHECKERR (rssiam_amState (instrSession, RSSIAM_AMP_STAT_ON));
    GOCHECKERR (rssiam_amState (instrSession, RSSIAM_AMP_STAT_OFF));

    /* --- Ch2 Setup Procedure --- */

    GOCHECKERR (rssiam_outpChannel (instrSession, RSSIAM_CH2));
    GOCHECKERR (rssiam_amIntFunc_Q (instrSession, &function));
    GOCHECKERR (rssiam_amDept_Q (instrSession, RSSIAM_CURRENT_RANGE, &depth));

    for (idx = 0; idx < loops; idx++)
        {
        p2dataArrayCH2 = dataArrayCH2 + idx * blockSize;
        GSRegisterSetTable[index].Size = blockSize * sizeof (ViInt16);
        GOCHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* AM arb data */, p2dataArrayCH2, GSRegisterSetTable[index].Size));
        }

    if (remainder > 0)
        {
        p2dataArrayCH2 = dataArrayCH2 + idx * blockSize;
        GSRegisterSetTable[index].Size = remainder * sizeof (ViInt16);
        GOCHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* AM arb data */, p2dataArrayCH2, GSRegisterSetTable[index].Size));
        }

    GOCHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    GOCHECKERR (rssiam_amIntFunc (instrSession, function));
    GOCHECKERR (rssiam_amDept (instrSession, depth));

    /* Enable AM on Ch2. Calculated points are stored in modulating
       memory in positions for channel 2. Disable AM on Ch2. */
    GOCHECKERR (rssiam_amState (instrSession, RSSIAM_AMP_STAT_ON));
    GOCHECKERR (rssiam_amState (instrSession, RSSIAM_AMP_STAT_OFF));

ERROR:

    rssiam_outpChannel (instrSession, channel);

    return rssiam_status;
}

/*****************************************************************************
 * Function: PM User Modulation Volatile Setup
 * Purpose:  Uploads floating-point values between -1 and +1 into volatile
 *           memory (modulation memory). Out of ramge values are coerced to
 *           the lower (upper) range limit.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmUserVolatile (ViSession instrSession,
                                         ViInt32 noofPoints,
                                         ViReal64 _VI_FAR dataArrayCH1[],
                                         ViReal64 _VI_FAR dataArrayCH2[])
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViInt32     idx                 = 0;
    ViInt16     channel             = 0;
    ViReal64    value               = 0.0,
                carrier_phase_ch1   = 0.0,
                carrier_phase_ch2   = 0.0,
                pm_deviation_ch1    = 0.0,
                pm_deviation_ch2    = 0.0;
    ViUInt16    *p2dataArrayCH1,
                *p2dataArrayCH2;

    if (rssiam_invalidViInt32Range (noofPoints, 131072, 131072))
        return VI_ERROR_PARAMETER2;
    if (!dataArrayCH1)
        return VI_ERROR_PARAMETER3;
    if (!dataArrayCH2)
        return VI_ERROR_PARAMETER4;

    /* Save active channel */
    CHECKERR (rssiam_outpChannel_Q (instrSession, &channel));
    
    /* Ch1 */
    GOCHECKERR (rssiam_outpChannel (instrSession, RSSIAM_CH1));
    GOCHECKERR (rssiam_getRegister (instrSession, "START_PHASE", &carrier_phase_ch1, RSSIAM_CURRENT_RANGE));
    GOCHECKERR (rssiam_getRegister (instrSession, "PM_DEVIATION", &pm_deviation_ch1, RSSIAM_CURRENT_RANGE));

    /* Ch2 */
    GOCHECKERR (rssiam_outpChannel (instrSession, RSSIAM_CH2));
    GOCHECKERR (rssiam_getRegister (instrSession, "START_PHASE", &carrier_phase_ch2, RSSIAM_CURRENT_RANGE));
    GOCHECKERR (rssiam_getRegister (instrSession, "PM_DEVIATION", &pm_deviation_ch2, RSSIAM_CURRENT_RANGE));

    /* Restore recent channel */
    GOCHECKERR (rssiam_outpChannel (instrSession, channel));

    /* Scale data from range -1 to +1 to the DAC codes */
    p2dataArrayCH1 = malloc (noofPoints * sizeof (ViInt16));
    p2dataArrayCH2 = malloc (noofPoints * sizeof (ViInt16));

    for (idx = 0; idx < noofPoints; idx++)
        {
        /* --- Ch1 --- */
        
        value = dataArrayCH1[idx];
        value = (value > 1.0) ? 1.0 : value;
        value = (value < -1.0) ? -1.0 : value;
        
        /* Calculate value */
        
        value = carrier_phase_ch1 + (pm_deviation_ch1 * value);

        if (value < 0)
            value += 360;

        p2dataArrayCH1[idx] = (pow (2, 16) / 360) * value;
        
        /* --- Ch2 --- */

        value = dataArrayCH2[idx];
        value = (value > 1.0) ? 1.0 : value;
        value = (value < -1.0) ? -1.0 : value;
        
        /* Calculate value */
        
        value = carrier_phase_ch2 + (pm_deviation_ch2 * value);

        if (value < 0)
            value += 360;

        p2dataArrayCH2[idx] = (pow (2, 16) / 360) * value;
        }

    GOCHECKERR (rssiam_pmUserDacVolatile (instrSession, noofPoints, p2dataArrayCH1, p2dataArrayCH2));

ERROR:

    rssiam_outpChannel (instrSession, channel);

    if (p2dataArrayCH1)
        free (p2dataArrayCH1);

    if (p2dataArrayCH2)
        free (p2dataArrayCH2);

    return rssiam_status;
}

/*****************************************************************************
 * Function: PM User Modulation Dac Volatile Setup
 * Purpose:  Uploads binary integer values between 0 and 131072 into
 *           volatile memory (modulation memory).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_pmUserDacVolatile (ViSession instrSession,
                                            ViInt32 noofPoints,
                                            ViUInt16 _VI_FAR dataArrayCH1[],
                                            ViUInt16 _VI_FAR dataArrayCH2[])
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt32     index           = 0,
                idx             = 0,
                cnt             = 0,
                loops           = 0,
                remainder       = 0,
                blockSize       = 2000; /* block size limit */
    ViUInt16    *p2data,
                *data;
    

    if (rssiam_invalidViInt32Range (noofPoints, 131072, 131072))
        return VI_ERROR_PARAMETER2;
    if (!dataArrayCH1)
        return VI_ERROR_PARAMETER3;
    if (!dataArrayCH2)
        return VI_ERROR_PARAMETER4;

    CHECKERR (rssiam_getIndexFromName ("ARB_DATA_DAC_LOAD", &index));

    /* Complete the data */

    data = malloc (noofPoints * 2 * sizeof (ViUInt16));

    cnt = 0;

    for (idx = 0; idx < noofPoints; idx++)
        {
        data[cnt++] = dataArrayCH1[idx];
        data[cnt++] = dataArrayCH2[idx];
        }
    
    /* Due to internal device limit (4000 Bytes => 2000 points) use block transfer */

    loops       = (noofPoints * 2) / blockSize;
    remainder   = (noofPoints * 2) % blockSize;

    for (idx = 0; idx < loops; idx++)
        {
        p2data = data + idx * blockSize;
        GSRegisterSetTable[index].Size = blockSize * sizeof (ViInt16);
        GOCHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* PM mod data */, p2data, GSRegisterSetTable[index].Size));
        }

    if (remainder > 0)
        {
        p2data = data + idx * blockSize;
        GSRegisterSetTable[index].Size = remainder * sizeof (ViInt16);
        GOCHECKERR (SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            3 /* PM mod data */, p2data, GSRegisterSetTable[index].Size));
        }

    GOCHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

ERROR:

    if (data)
        free (data);

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Points Setup
 * Purpose:  Sets the number of points in the arbitrary waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbPoin(
    ViSession   instrSession,
    ViInt32     dataPoints
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt32    dataPoints_data = dataPoints;

    CHECKERR (rssiam_setRegister (instrSession, "ARB_DATA_POINTS", &dataPoints_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Points Query
 * Purpose:  Returns the number of points in the arbitrary waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbPoin_Q(
    ViSession   instrSession,
    ViPInt32    dataPoints
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt32    dataPoints_data = 0;

    if (!dataPoints)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "ARB_DATA_POINTS", &dataPoints_data, RSSIAM_CURRENT_RANGE));

    *dataPoints = dataPoints_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Start Setup
 * Purpose:  Sets the start point in waveform memory.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbStart(
    ViSession   instrSession,
    ViInt32     dataStart
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt32    dataStart_data  = dataStart;

    CHECKERR (rssiam_setRegister (instrSession, "ARB_DATA_START", &dataStart_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Start Query
 * Purpose:  Returns the start point in waveform memory.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbStart_Q(
    ViSession   instrSession,
    ViPInt32    dataStart
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt32    dataStart_data  = 0;

    if (!dataStart)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "ARB_DATA_START", &dataStart_data, RSSIAM_CURRENT_RANGE));

    *dataStart = dataStart_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Stop Setup
 * Purpose:  Sets the stop point in waveform memory.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbStop(
    ViSession   instrSession,
    ViInt32     dataStop
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt32    dataStop_data   = dataStop;

    CHECKERR (rssiam_setRegister (instrSession, "ARB_DATA_STOP", &dataStop_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Stop Query
 * Purpose:  Returns the stop point in waveform memory.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbStop_Q(
    ViSession   instrSession,
    ViPInt32    dataStop
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt32    dataStop_data   = 0;

    if (!dataStop)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "ARB_DATA_STOP", &dataStop_data, RSSIAM_CURRENT_RANGE));

    *dataStop = dataStop_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Rate Setup
 * Purpose:  Sets the sample rate for the arbitrary waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbRate(
    ViSession   instrSession,
    ViReal64    dataSampleRate
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    rate            = (dataSampleRate < NUMERIC_PRECISION) ? 0.0 : 1 / dataSampleRate;

    CHECKERR (rssiam_setRegister (instrSession, "ARB_DATA_SAMPLE_RATE", &rate));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Rate Query
 * Purpose:  Returns the sample rate of the arbitrary waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbRate_Q(
    ViSession   instrSession,
    ViPReal64   dataSampleRate
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    rate            = 0.0;

    if (!dataSampleRate)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "ARB_DATA_SAMPLE_RATE", &rate, RSSIAM_CURRENT_RANGE));

    *dataSampleRate = (rate < NUMERIC_PRECISION) ? 0.0 : 1 / rate;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Rate Mode Setup
 * Purpose:  Sets the mode of the sample rate for arbitrary waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbRateMode(
    ViSession   instrSession,
    ViInt16     dataSampleRateMode
)
{
    ViStatus    rssiam_status           = VI_SUCCESS;
    ViUInt16    dataSampleRateMode_data = dataSampleRateMode;

    CHECKERR (rssiam_setRegister (instrSession, "ARB_DATA_RATE_MODE", &dataSampleRateMode_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Rate Mode Query
 * Purpose:  Returns the mode of the sample rate for arbitrary waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataArbRateMode_Q(
    ViSession   instrSession,
    ViPInt16    dataSampleRateMode
)
{
    ViStatus    rssiam_status           = VI_SUCCESS;
    ViUInt16    dataSampleRateMode_data = 0;

    if (!dataSampleRateMode)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "ARB_DATA_RATE_MODE", &dataSampleRateMode_data, RSSIAM_CURRENT_RANGE));

    *dataSampleRateMode = dataSampleRateMode_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Volatile Setup
 * Purpose:  Uploads floating-point values between -1 and +1 into volatile
 *           memory. Out of ramge values are coerced to the lower (upper) range
 *           limit.
 *
 *           The values -1 and +1 correspond to the peak values of the
 *           waveform.
 *
 *           Downloading the floating-point values is slower than downloading
 *           binary values but is more convenient when using the trigonometric
 *           functions, which return values between -1 and +1.
 *
 *           This function overwrites the previous waveform in VOLATILE
 *           memory.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataVolatile(
    ViSession   instrSession,
    ViInt32     noofPoints,
    ViReal64    _VI_FAR dataArray[]
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt32     idx             = 0;
    ViInt16     min             = -16384;
    ViInt16     max             = 16383;
    ViReal64    value           = 0.0;
    ViReal64    resolution      = 2.0 / (max - min); /* range is from -1.0 to 1.0 */
    ViUInt16    *DacDataArray;

    if (rssiam_invalidViInt32Range (noofPoints, 16, 262144))
        return VI_ERROR_PARAMETER2;
    if (!dataArray)
        return VI_ERROR_PARAMETER3;

    /* Scale data from range -1 to +1 to the DAC codes */
    DacDataArray = malloc (noofPoints * sizeof (ViUInt16));
    DacDataArray = memset (DacDataArray, 0, noofPoints * sizeof (ViUInt16));

    for (idx = 0; idx < noofPoints; idx++)
        {
        value = dataArray[idx] / resolution;
        DacDataArray[idx] = (value > max) ? max : value;
        DacDataArray[idx] = (value < min) ? min : value;
        }

    rssiam_status = rssiam_dataDacVolatile (instrSession, noofPoints, DacDataArray);

    free (DacDataArray);

    return rssiam_status;
}

/*****************************************************************************
 * Function: Data Arb Dac Volatile Setup
 * Purpose:  Uploads binary integer values between -16384 and 16383 into
 *           volatile memory. The binary range of values corresponds to the
 *           values available using internal 14-bit DAC codes.
 *
 *           The values -16384 and 16383 correspond to the peak values of the
 *           waveform.
 *
 *           MSB (Most Significant Bit, at position 15) represents marker state,
 *           where On (1) and Off (0).
 *
 *           This function overwrites the previous waveform in VOLATILE
 *           memory.
 *
 *           Applicable channels: CH1 or CH2
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_dataDacVolatile(
    ViSession   instrSession,
    ViInt32     noofPoints,
    ViInt16     _VI_FAR dataArray[]
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt32     index           = 0,
                idx             = 0,
                loops           = 0,
                remainder       = 0,
                blockSize       = 2000; /* block size limit */
    ViInt16     *p2dataArray;
    

    if (rssiam_invalidViInt32Range (noofPoints, 16, 262144))
        return VI_ERROR_PARAMETER2;
    if (!dataArray)
        return VI_ERROR_PARAMETER3;

    CHECKERR (rssiam_getIndexFromName ("ARB_DATA_DAC_LOAD", &index));

    /* Due to internal device limit (4000 Bytes => 2000 points) use block transfer */

    loops       = noofPoints / blockSize;
    remainder   = noofPoints % blockSize;

    for (idx = 0; idx < loops; idx++)
        {
        p2dataArray = dataArray + idx * blockSize;
        GSRegisterSetTable[index].Size = blockSize * sizeof (ViUInt16);
        CHECKERR (rssiam_setRegister (instrSession, "ARB_DATA_DAC_LOAD", p2dataArray));
        }

    if (remainder > 0)
        {
        p2dataArray = dataArray + idx * blockSize;
        GSRegisterSetTable[index].Size = remainder * sizeof (ViUInt16);
        CHECKERR (rssiam_setRegister (instrSession, "ARB_DATA_DAC_LOAD", p2dataArray));
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Freq Start Setup
 * Purpose:  Sets the sweep start frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freqStar(
    ViSession   instrSession,
    ViReal64    frequencyStart
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    frequencyStart_data = frequencyStart;

    CHECKERR (rssiam_setRegister (instrSession, "START_FREQUENCY", &frequencyStart_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Freq Start Query
 * Purpose:  Returns the sweep start frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freqStar_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   frequencyStart
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    frequencyStart_data = 0.0;

    if (!frequencyStart)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "START_FREQUENCY", &frequencyStart_data, range));

    *frequencyStart = frequencyStart_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Freq Stop Setup
 * Purpose:  Sets the sweep stop frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freqStop(
    ViSession   instrSession,
    ViReal64    frequencyStop
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    frequencyStop_data  = frequencyStop;

    CHECKERR (rssiam_setRegister (instrSession, "STOP_FREQUENCY", &frequencyStop_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Freq Stop Query
 * Purpose:  Returns the sweep stop frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freqStop_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   frequencyStop
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    frequencyStop_data  = 0.0;

    if (!frequencyStop)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "STOP_FREQUENCY", &frequencyStop_data, range));

    *frequencyStop = frequencyStop_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Freq Center Setup
 * Purpose:  Sets the sweep center frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freqCenter (ViSession instrSession,
                                     ViReal64 frequencyCenter)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    start           = 0.0,
                stop            = 0.0,
                span            = 0.0;

    CHECKERR (rssiam_freqStar_Q (instrSession, RSSIAM_CURRENT_RANGE, &start));
    CHECKERR (rssiam_freqStop_Q (instrSession, RSSIAM_CURRENT_RANGE, &stop));

    span = stop - start;

    CHECKERR (rssiam_freqStar (instrSession, frequencyCenter - span / 2.0));
    CHECKERR (rssiam_freqStop (instrSession, frequencyCenter + span / 2.0));

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Freq Center Query
 * Purpose:  Returns the sweep center frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freqCenter_Q (ViSession instrSession, ViInt16 range,
                                       ViReal64 *frequencyCenter)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    start           = 0.0,
                stop            = 0.0;

    if (!frequencyCenter)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_freqStar_Q (instrSession, range, &start));
    CHECKERR (rssiam_freqStop_Q (instrSession, range, &stop));

    *frequencyCenter = start + (stop - start) / 2.0;
        
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Freq Span Setup
 * Purpose:  Sets the sweep span frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freqSpan (ViSession instrSession,
                                   ViReal64 frequencySpan)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    start           = 0.0,
                stop            = 0.0,
                center          = 0.0;

    CHECKERR (rssiam_freqStar_Q (instrSession, RSSIAM_CURRENT_RANGE, &start));
    CHECKERR (rssiam_freqStop_Q (instrSession, RSSIAM_CURRENT_RANGE, &stop));

    center = (start + stop) / 2.0;

    CHECKERR (rssiam_freqStar (instrSession, center - frequencySpan / 2.0));
    CHECKERR (rssiam_freqStop (instrSession, center + frequencySpan / 2.0));

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Freq Span Query
 * Purpose:  Returns the sweep span frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_freqSpan_Q (ViSession instrSession, ViInt16 range,
                                     ViReal64 *frequencySpan)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    start           = 0.0,
                stop            = 0.0;

    if (!frequencySpan)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_freqStar_Q (instrSession, range, &start));
    CHECKERR (rssiam_freqStop_Q (instrSession, range, &stop));

    *frequencySpan = stop - start;
        
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Direction Setup
 * Purpose:  This function selects the direction of the sweep.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_sweDirection(
    ViSession   instrSession,
    ViInt16     sweepDirection
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    sweepDirection_data = sweepDirection;

    CHECKERR (rssiam_setRegister (instrSession, "SWEEP_DIRECTION", &sweepDirection_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Direction Query
 * Purpose:  This function returns the direction of the sweep.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_sweDirection_Q(
    ViSession   instrSession,
    ViPInt16    sweepDirection
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    sweepDirection_data = 0;

    if (!sweepDirection)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "SWEEP_DIRECTION", &sweepDirection_data, RSSIAM_CURRENT_RANGE));

    *sweepDirection = sweepDirection_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Points Setup
 * Purpose:  Sets the number of points in a stepped sweep.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_swePoin(
    ViSession   instrSession,
    ViInt32     sweepPoints
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    dataPoints_data = sweepPoints;

    CHECKERR (rssiam_setRegister (instrSession, "SWEEP_POINTS", &dataPoints_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Points Query
 * Purpose:  Returns the number of points in the arbitrary waveform.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_swePoin_Q(
    ViSession   instrSession,
    ViPInt32    dataPoints
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    dataPoints_data = 0;

    if (!dataPoints)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "SWEEP_POINTS", &dataPoints_data, RSSIAM_CURRENT_RANGE));

    *dataPoints = dataPoints_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Spacing Setup
 * Purpose:  This function selects the linear or logarithmic spacing for the
 *           sweep.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_sweSpac(
    ViSession   instrSession,
    ViInt16     sweepSpacing
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    sweepSpacing_data   = sweepSpacing;

    CHECKERR (rssiam_setRegister (instrSession, "SWEEP_SPACING", &sweepSpacing_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Spacing Query
 * Purpose:  This function returns whether the linear or logarithmic spacing
 *           is used for the sweep.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_sweSpac_Q(
    ViSession   instrSession,
    ViPInt16    sweepSpacing
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    sweepSpacing_data   = 0;

    if (!sweepSpacing)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "SWEEP_SPACING", &sweepSpacing_data, RSSIAM_CURRENT_RANGE));

    *sweepSpacing = sweepSpacing_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Time Setup
 * Purpose:  Sets number of seconds required to sweep from the start frequency
 *           to the stop frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_sweTime(
    ViSession   instrSession,
    ViReal64    sweepTime
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal32    sweepTime_data  = 0.0;

    DBL2FLT (sweepTime, sweepTime_data);

    CHECKERR (rssiam_setRegister (instrSession, "SWEEP_TIME", &sweepTime_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Time Query
 * Purpose:  Returns number of seconds required to sweep from the start
 *           frequency to the stop frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_sweTime_Q(
    ViSession   instrSession,
    ViInt16     range,
    ViPReal64   sweepTime
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal32    sweepTime_data  = 0.0;

    if (!sweepTime)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "SWEEP_TIME", &sweepTime_data, range));

    *sweepTime = sweepTime_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Stat Setup
 * Purpose:  Enables or disables sweep mode. Only one modulation mode can be
 *           enabled at a time. When you enable sweep mode, the previous
 *           modulation mode is turned off.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_sweStat(
    ViSession   instrSession,
    ViInt16     sweepState
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (sweepState)
        {
        case RSSIAM_SWEEP_STAT_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "SWEEP_OFF"));
            break;
        case RSSIAM_SWEEP_STAT_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "SWEEP_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Sweep Stat Query
 * Purpose:  Returns whether sweep mode is enabled or disabled.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_sweStat_Q(
    ViSession   instrSession,
    ViPInt16    sweepState
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    sweepState_data = 0;

    if (!sweepState)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "FREQUENCY_MODE", &sweepState_data, RSSIAM_CURRENT_RANGE));

    *sweepState = (sweepState_data == RSSIAM_FREQUENCY_MODE_SWEEP) ? RSSIAM_SWEEP_STAT_ON : RSSIAM_SWEEP_STAT_OFF;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Marker Frequency Setup
 * Purpose:  Sets the marker frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_mkrFreq(
    ViSession   instrSession,
    ViReal64    markerFrequency
)
{
    ViStatus    rssiam_status           = VI_SUCCESS;
    ViReal64    markerFrequency_data    = markerFrequency;

    CHECKERR (rssiam_setRegister (instrSession, "MARKER_FREQUENCY", &markerFrequency_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Marker Frequency Query
 * Purpose:  Returns the marker frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_mkrFreq_Q(
    ViSession   instrSession,
    ViPReal64   markerFrequency
)
{
    ViStatus    rssiam_status           = VI_SUCCESS;
    ViReal64    markerFrequency_data    = 0.0;

    if (!markerFrequency)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "MARKER_FREQUENCY", &markerFrequency_data, RSSIAM_CURRENT_RANGE));

    *markerFrequency = markerFrequency_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Marker Stat Setup
 * Purpose:  Sets the marker state.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_mkrStat(
    ViSession   instrSession,
    ViInt16     markerState
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (markerState)
        {
        case RSSIAM_MARKER_STAT_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "MARKER_OFF"));
            break;
        case RSSIAM_MARKER_STAT_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "MARKER_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Marker Stat Query
 * Purpose:  Returns the marker state.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_mkrStat_Q(
    ViSession   instrSession,
    ViPInt16    markerState
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    markerState_data    = 0;

    if (!markerState)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "MARKER_STATE", &markerState_data, RSSIAM_CURRENT_RANGE));

    *markerState = markerState_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Trigger Source Setup
 * Purpose:  Selects the source from which the function generator will accept
 *           a trigger. The function generator will accept an immediate
 *           internal trigger, a hardware trigger from the rear-panel Ext Trig
 *           terminal, or a software (bus) trigger.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigSour(
    ViSession   instrSession,
    ViInt16     triggerSource
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    triggerSource_data  = triggerSource;

    CHECKERR (rssiam_setRegister (instrSession, "TRIGGER_SOURCE", &triggerSource_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Trigger Source Query
 * Purpose:  Returns the source from which the function generator will accept
 *           a trigger.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigSour_Q(
    ViSession   instrSession,
    ViPInt16    triggerSource
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    triggerSource_data  = 0;

    if (!triggerSource)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "TRIGGER_SOURCE", &triggerSource_data, RSSIAM_CURRENT_RANGE));

    *triggerSource = triggerSource_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Trigger Slope Setup
 * Purpose:  Sets the trigger slope (edge which the event occurs on).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigSlope(
    ViSession   instrSession,
    ViInt16     triggerSlope
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    triggerSlope_data   = triggerSlope;

    CHECKERR (rssiam_setRegister (instrSession, "TRIGGER_SLOPE", &triggerSlope_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Trigger Slope Query
 * Purpose:  Returns the trigger slope (edge which the event occurs on).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigSlope_Q(
    ViSession   instrSession,
    ViPInt16    triggerSlope
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    triggerSlope_data   = 0;

    if (!triggerSlope)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "TRIGGER_SLOPE", &triggerSlope_data, RSSIAM_CURRENT_RANGE));

    *triggerSlope = triggerSlope_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Trigger Polarity Setup
 * Purpose:  Sets the trigger polarity (edge which the event occurs on).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigPolarity (ViSession instrSession,
                                       ViInt16 triggerPolarity)
{
    return rssiam_trigSlope (instrSession, triggerPolarity);
}

/*****************************************************************************
 * Function:  Trigger Polarity Query
 * Purpose:   Returns the trigger polarity (edge which the event occurs on).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigPolarity_Q (ViSession instrSession,
                                         ViInt16 *triggerPolarity)
{
    return rssiam_trigSlope_Q (instrSession, triggerPolarity);
}

/*****************************************************************************
 * Function: Trigger Delay Setup
 * Purpose:  Sets the trigger delay (time duration between the recognition of
 *           an event(s) and the start of the action).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigDelay(
    ViSession   instrSession,
    ViReal64    triggerDelay
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    triggerDelay_data   = triggerDelay;

    CHECKERR (rssiam_setRegister (instrSession, "TRIGGER_DELAY", &triggerDelay_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Trigger Delay Query
 * Purpose:  Returns the trigger delay (time duration between the recognition
 *           of an event(s) and the start of the action).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_trigDelay_Q(
    ViSession   instrSession,
    ViPReal64   triggerDelay
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViReal64    triggerDelay_data   = 0.0;

    if (!triggerDelay)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "TRIGGER_DELAY", &triggerDelay_data, RSSIAM_CURRENT_RANGE));

    *triggerDelay = triggerDelay_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Gate Function Setup
 * Purpose:  Sets the gate function.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gateFunction(
    ViSession   instrSession,
    ViInt16     gateFunction
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    gateFunction_data   = gateFunction;

    if (gateFunction == RSSIAM_GATE_BURST)
        {
        CHECKERR (rssiam_bmSour (instrSession, RSSIAM_BM_SOUR_TRIG));
        }
    else
        {
        CHECKERR (rssiam_bmSour (instrSession, RSSIAM_BM_SOUR_INT));
        CHECKERR (rssiam_setRegister (instrSession, "GATE_FUNCTION", &gateFunction_data));
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Gate Function Query
 * Purpose:  Returns the gate function.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gateFunction_Q(
    ViSession   instrSession,
    ViPInt16    gateFunction
)
{
    ViStatus    rssiam_status       = VI_SUCCESS;
    ViUInt16    gateFunction_data   = 0;
    ViInt16     source              = 0;

    if (!gateFunction)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_bmSour_Q (instrSession, &source));

    if (source == RSSIAM_BM_SOUR_TRIG)
        {
        *gateFunction = RSSIAM_GATE_BURST;
        }
    else
        {
        CHECKERR (rssiam_getRegister (instrSession, "GATE_FUNCTION", &gateFunction_data, RSSIAM_CURRENT_RANGE));

        *gateFunction = gateFunction_data;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Gate Time Setup
 * Purpose:  Sets the internal gate time (the time for which generator outputs
 *           a continuous waveform).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gateTime(
    ViSession   instrSession,
    ViReal64    gateTime
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    gateTime_data   = gateTime;

    CHECKERR (rssiam_setRegister (instrSession, "GATE_INTERNAL_TIME", &gateTime_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Gate Time Query
 * Purpose:  Returns the internal gate time (the time for which generator
 *           outputs a continuous waveform).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gateTime_Q(
    ViSession   instrSession,
    ViPReal64   gateTime
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViReal64    gateTime_data   = 0.0;

    if (!gateTime)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "GATE_INTERNAL_TIME", &gateTime_data, RSSIAM_CURRENT_RANGE));

    *gateTime = gateTime_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Gate Length Setup
 * Purpose:  Sets the internal gate time (the time for which generator
 *           outputs a continuous waveform).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gateLength (ViSession instrSession,
                                     ViReal64 gateLength)
{
    return rssiam_gateTime (instrSession, gateLength);
}

/*****************************************************************************
 * Function: Gate Length Query
 * Purpose:  Returns the internal gate time (the time for which generator
 *           outputs a continuous waveform).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gateLength_Q (ViSession instrSession,
                                       ViReal64 *gateLength)
{
    return rssiam_gateTime_Q (instrSession, gateLength);
}

/*****************************************************************************
 * Function: Gate Source Setup
 * Purpose:  Selects the gate source.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gateSource (ViSession instrSession,
                                     ViInt16 gateSource)
{
    return rssiam_bmSour (instrSession, gateSource);
}

/*****************************************************************************
 * Function: Gate Source Query
 * Purpose:  Returns the gate source.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gateSource_Q (ViSession instrSession,
                                       ViInt16 *gateSource)
{
    return rssiam_bmSour_Q (instrSession, gateSource);
}

/*****************************************************************************
 * Function: Gate Polarity Setup
 * Purpose:  Sets the trigger polarity (edge which the event occurs on).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gatePolarity (ViSession instrSession,
                                       ViInt16 gatePolarity)
{
    return rssiam_trigSlope (instrSession, gatePolarity);
}

/*****************************************************************************
 * Function:  Gate Polarity Query
 * Purpose:   Returns the gate polarity (edge which the event occurs on).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_gatePolarity_Q (ViSession instrSession,
                                         ViInt16 *gatePolarity)
{
    return rssiam_trigSlope_Q (instrSession, gatePolarity);
}

/*****************************************************************************
 * Function: Send Trigger
 * Purpose:  This function sends a trigger.
 *
 *           Note:
 *
 *           This function is available in case of 'BUS' Trigger Source.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_sendTrigger(
    ViSession   instrSession
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;

    CHECKERR (rssiam_sendCmd (instrSession, "TRIGGER"));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Abort Trigger
 * Purpose:  This function aborts (resets) trigger system (stops sweeping).
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_abortTrigger(
    ViSession   instrSession
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    CHECKERR (rssiam_sendCmd (instrSession, "ABORT"));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Time Out Setup
 * Purpose:  Sets a minimum timeout value for driver I/O transactions in
 *           milliseconds. The timeout period may vary on computer platforms.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_timeOut(
    ViSession   instrSession,
    ViInt32     timeout
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_TMO_VALUE, timeout));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Time Out Query
 * Purpose:  Returns the timeout value for driver I/O transactions in
 *           milliseconds.
 *
 *           The timeout period may vary on computer platforms.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_timeOut_Q(
    ViSession   instrSession,
    ViPInt32    timeout
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_TMO_VALUE, timeout));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Reference Oscillator Source Setup
 * Purpose:  Selects the reference oscillator source.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_roscSour(
    ViSession   instrSession,
    ViInt16     roscSource
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    roscSource_data = roscSource;

    // Excluded value (reserved) ... RSSIAM_ROSC_OCXO
    if (roscSource == RSSIAM_ROSC_OCXO)
        return RSSIAM_ERROR_INVALID_VALUE;

    CHECKERR (rssiam_setRegister (instrSession, "ROSC_SOURCE", &roscSource_data));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Reference Oscillator Source Query
 * Purpose:  Returns the reference oscillator source.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_roscSour_Q(
    ViSession   instrSession,
    ViPInt16    roscSource
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    roscSource_data = 0;

    if (!roscSource)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "ROSC_SOURCE", &roscSource_data, RSSIAM_CURRENT_RANGE));

    *roscSource = roscSource_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Reference Oscillator Stat Setup
 * Purpose:  Sets the state of the reference oscillator output.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_roscStat(
    ViSession   instrSession,
    ViInt16     roscState
)
{
    ViStatus    rssiam_status = VI_SUCCESS;

    switch (roscState)
        {
        case RSSIAM_ROSC_STAT_OFF:
            CHECKERR (rssiam_sendCmd (instrSession, "ROSC_OFF"));
            break;
        case RSSIAM_ROSC_STAT_ON:
            CHECKERR (rssiam_sendCmd (instrSession, "ROSC_ON"));
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Reference Oscillator Stat Query
 * Purpose:  Returns the state of the reference oscillator output.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_roscStat_Q(
    ViSession   instrSession,
    ViPInt16    roscState
)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    roscState_data  = 0;

    if (!roscState)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (rssiam_getRegister (instrSession, "ROSC_STATE", &roscState_data, RSSIAM_CURRENT_RANGE));

    *roscState = roscState_data;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Reference Oscillator Frequency Setup
 * Purpose:  This function configures External Reference Oscillator frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_roscFreq(
    ViSession   instrSession,
    ViInt32     refFrequency)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViUInt16    data_0x8023     = 0x0,
                data_0x8024     = 0x0;

    switch (refFrequency)
        {
        case RSSIAM_ROSC_FREQ_2MHZ:
            data_0x8023 = 0x00FA;
            data_0x8024 = 0x0005;
            break;
        case RSSIAM_ROSC_FREQ_5MHZ:
            data_0x8023 = 0x00C8;
            data_0x8024 = 0x000A;
            break;
        case RSSIAM_ROSC_FREQ_10MHZ:
            data_0x8023 = 0x00C8;
            data_0x8024 = 0x0014;
            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    CHECKERR (rssiam_roscSour (instrSession, RSSIAM_ROSC_EXT));
    CHECKERR (SiSetRegister(instrSession, 0x8024, 0, &data_0x8024, sizeof (ViUInt16)));
    CHECKERR (SiSetRegister(instrSession, 0x8023, 0, &data_0x8023, sizeof (ViUInt16)));
    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*****************************************************************************
 * Function: Reference Oscillator Frequency Query
 * Purpose:  This function returns External Reference Oscillator frequency.
 *
 *****************************************************************************/
ViStatus _VI_FUNC rssiam_roscFreq_Q(
    ViSession   instrSession,
    ViPInt32    refFrequency)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges instrPtr        = {0};

    if (!refFrequency)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_getRegister (instrSession, "APPLY_DEVICE_CONFIGURATION", &instrPtr -> deviceCfg, RSSIAM_CURRENT_RANGE));

    if (fabs (instrPtr -> deviceCfg.rosc_ext_frequency - 2.0e6) < NUMERIC_PRECISION)
        *refFrequency = RSSIAM_ROSC_FREQ_2MHZ;
    else
        if (fabs (instrPtr -> deviceCfg.rosc_ext_frequency - 5.0e6) < NUMERIC_PRECISION)
            *refFrequency = RSSIAM_ROSC_FREQ_5MHZ;
        else
            if (fabs (instrPtr -> deviceCfg.rosc_ext_frequency - 10.0e6) < NUMERIC_PRECISION)
                *refFrequency = RSSIAM_ROSC_FREQ_10MHZ;
            else
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Flush Error Queue                                               */
/* Purpose:  This function deletes all error queue.                          */
/*===========================================================================*/
ViStatus _VI_FUNC rssiam_flushErrorQueue (ViSession instrSession)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    /* Flush error queue */
    instrPtr -> errorCount = 0;
    memset (instrPtr -> errorQueue, 0, sizeof (instrPtr -> errorQueue[MAX_ERROR_QUEUE_LENGTH]));

    /* Flush SiControl event queue */
    CHECKERR (SiFlushEventQueue (instrSession));

    return rssiam_status;
}

/*****************************************************************************/
/*-------- INSERT USER-CALLABLE INSTRUMENT-DEPENDENT ROUTINES HERE ----------*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: State Checking                                                  */
/* Purpose:  This function enables (disables) error state checking (query the*/
/*           instrument's error subsystem).                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssiam_errorCheckState (ViSession instrSession,
                                          ViBoolean stateChecking)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges instrPtr        = {0};

    if (rssiam_invalidViBooleanRange (stateChecking))
       return VI_ERROR_PARAMETER2;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_EVENT_HANDLING, stateChecking));

    instrPtr -> errorChecking = stateChecking;

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument. If the reset function      */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rssiam_reset (ViSession instrSession)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges instrPtr        = {0};
    ViReal64            fwRevision      = 0.0;
    ViChar              fwRevisionBuf[256];

    /* --- Default Instrument Setup --- (mandatory!) --- */

    CHECKERR (rssiam_defaultInstrSetup (instrSession));

    /* --- Preset registers to default state --- */

    /* Reset trigger system */

    CHECKERR (rssiam_sendCmd (instrSession, "ABORT"));

    /* Defines the control setting for the global configuration of the module */

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    /* --- */

    instrPtr -> channelCoupling = RSSIAM_CHANNEL_COUPLING_FREQ;

    //
    // TODO: Channel coupling functionality ... Level, phase, frequency ...
    //

    /* --- */

    instrPtr -> voltageHigh[0]                                  = 5.0;
    instrPtr -> voltageHigh[1]                                  = 5.0;
    instrPtr -> voltageLow[0]                                   = -5.0;
    instrPtr -> voltageLow[1]                                   = -5.0;

    instrPtr -> outputLoad[0]                                   = 50.0;
    instrPtr -> outputLoad[1]                                   = 50.0;

    instrPtr -> outputVoltageUnit                               = RSSIAM_OUTPUT_VOLT_UNIT_DEF;

    /* --- */

    instrPtr -> deviceCfg.device_cfg            = 0;            /* 0 - common frequency */
                                                                /* 1 - two independent frequencies, channels */

    instrPtr -> deviceCfg.frequency_1           = 1000.0;       /* frequency in channel I or common frequency */
    instrPtr -> deviceCfg.phase_1               = 0.0;          /* phase in channel I */
    instrPtr -> deviceCfg.volt_1_amplitude      = 1.0;          /* amplitude in channel I */
    instrPtr -> deviceCfg.volt_1_offset         = 0.0;          /* offset in channel I */
    instrPtr -> deviceCfg.func_1                = SINUSOID;     /* function in channel I */
    instrPtr -> deviceCfg.frequency_2           = 1000.0;       /* frequency in channel Q */
    instrPtr -> deviceCfg.phase_2               = 0.0;          /* phase in channel Q */
    instrPtr -> deviceCfg.volt_2_amplitude      = 1.0;          /* amplitude in channel Q */
    instrPtr -> deviceCfg.volt_2_offset         = 0.0;          /* offset in channel Q */
    instrPtr -> deviceCfg.func_2                = SINUSOID;     /* function in channel Q */

    instrPtr -> deviceCfg.symmetry_1            = 100.0;        /* symmetry in channel I */
    instrPtr -> deviceCfg.symmetry_2            = 100.0;        /* symmetry in channel Q */

    instrPtr -> deviceCfg.dcyc_1                = 50.0;         /* duty cycle in channel I */
    instrPtr -> deviceCfg.dcyc_2                = 50.0;         /* duty cycle in channel Q */

    instrPtr -> deviceCfg.pulse_period          = 0.001;        /* pulse period */
    instrPtr -> deviceCfg.pulse_width           = 0.0005;       /* pulse width */
    instrPtr -> deviceCfg.pulse_polarity_1      = NORMAL;       /* pulse polarity in channel I */
    instrPtr -> deviceCfg.pulse_polarity_2      = NORMAL;       /* pulse polarity in channel Q */

    instrPtr -> deviceCfg.volt_1_dc             = 0.0;          /* DC voltage in channel I */
    instrPtr -> deviceCfg.volt_2_dc             = 0.0;          /* DC voltage in channel Q */

    instrPtr -> deviceCfg.arb_data_points       = 16;           /* the number of generated points */
    instrPtr -> deviceCfg.arb_1_data_start      = 0;            /* arbitrary start address in channel I */
    instrPtr -> deviceCfg.arb_2_data_start      = 0;            /* arbitrary start address in channel Q */
    instrPtr -> deviceCfg.arb_1_data_stop       = 262143;       /* arbitrary stop address in channel I */
    instrPtr -> deviceCfg.arb_2_data_stop       = 262143;       /* arbitrary stop address in channel Q */
    instrPtr -> deviceCfg.arb_data_rate         = 10.0e-9;      /* arbitrary sample rate */
    instrPtr -> deviceCfg.arb_data_rate_mode    = NORM;         /* sample rate mode */

    instrPtr -> deviceCfg.filt_1_auto           = ON;           /* auto selection of the path filter type in channel I */
    instrPtr -> deviceCfg.filt_1_external       = OFF;          /* selection of the external filter in channel I */
    instrPtr -> deviceCfg.filt_1_type           = CAUER;        /* selection of the path filter type in channel I */
    instrPtr -> deviceCfg.filt_1_out            = F_AUTO;       /* state of the output filter in channel I */
    instrPtr -> deviceCfg.filt_2_auto           = ON;           /* auto selection of the path filter type in channel Q */
    instrPtr -> deviceCfg.filt_2_external       = OFF;          /* selection of the external filter in channel Q */
    instrPtr -> deviceCfg.filt_2_type           = CAUER;        /* selection of the path filter type in channel Q */
    instrPtr -> deviceCfg.filt_2_out            = F_AUTO;       /* state of the output filter in channel Q */

    instrPtr -> deviceCfg.sync_1_polarity       = NORMAL;       /* polarity of the sync signal in channel I */
    instrPtr -> deviceCfg.sync_1_type           = COMP;         /* type of the synchronization in channel I */
    instrPtr -> deviceCfg.sync_1_state          = OFF;          /* state of the SYNC I output */
    instrPtr -> deviceCfg.sync_2_polarity       = NORMAL;       /* polarity of the sync signal in channel Q */
    instrPtr -> deviceCfg.sync_2_type           = COMP;         /* type of the synchronization in channel Q */
    instrPtr -> deviceCfg.sync_2_state          = OFF;          /* state of the SYNC Q output */

    instrPtr -> deviceCfg.trig_delay            = 0.0;          /* trigger delay */
    instrPtr -> deviceCfg.trig_gate             = 100.0e-9;     /* time of gated trigger event  */
    instrPtr -> deviceCfg.trig_slope            = POSITIVE;     /* trigger slope */
    instrPtr -> deviceCfg.trig_source           = IMM;          /* source of trigger */
    instrPtr -> deviceCfg.gate_function         = SH;           /* gate function */

    instrPtr -> deviceCfg.outp_1_state          = OFF;          /* state of the signal output in channel I */
    instrPtr -> deviceCfg.outp_2_state          = OFF;          /* state of the signal output in channel Q */
    instrPtr -> deviceCfg.output_sum            = OFF;          /* selection of the I+Q mode */

    instrPtr -> deviceCfg.rosc_ext_frequency    = 10.0e6;       /* frequency of the external reference oscillator */
    instrPtr -> deviceCfg.rosc_source           = INT1;         /* source of the reference oscillator */
    instrPtr -> deviceCfg.rosc_state            = ON;           /* state of the REF OSC output */

    instrPtr -> deviceCfg.start_frequency       = 1.0;          /* start frequency */
    instrPtr -> deviceCfg.stop_frequency        = 250000.0;     /* stop frequency */
    instrPtr -> deviceCfg.sweep_time            = 0.001;        /* sweep time */
    instrPtr -> deviceCfg.sweep_direction       = UP;           /* sweep direction */
    instrPtr -> deviceCfg.sweep_spacing         = LINEAR;       /* sweep spacing */
    instrPtr -> deviceCfg.sweep_points          = 1024;         /* sweep points */
    instrPtr -> deviceCfg.sweep_state           = OFF;          /* sweep state */

    instrPtr -> deviceCfg.marker_state          = OFF;          /* marker state */
    instrPtr -> deviceCfg.marker_frequency      = 1000.0;       /* marker frequency */

    instrPtr -> deviceCfg.modulation_points     = 64;           /* modulation points */

    instrPtr -> deviceCfg.am_frequency          = 1000.0;       /* modulating frequency */
    instrPtr -> deviceCfg.am_1_func             = SINUSOID;     /* modulating function in channel I */
    instrPtr -> deviceCfg.am_1_depth            = 100.0;        /* modulation depth in channel I */
    instrPtr -> deviceCfg.am_1_state            = OFF;          /* modulation state in channel I */
    instrPtr -> deviceCfg.am_2_func             = SINUSOID;     /* modulating function in channel Q */
    instrPtr -> deviceCfg.am_2_depth            = 100.0;        /* modulation depth in channel Q */
    instrPtr -> deviceCfg.am_2_state            = OFF;          /* modulation state in channel Q */

    instrPtr -> deviceCfg.fm_frequency          = 1000.0;       /* modulating frequency */
    instrPtr -> deviceCfg.fm_func               = SINUSOID;     /* modulating function */
    instrPtr -> deviceCfg.fm_peak_deviation     = 999.9;        /* peak frequency deviation */
    instrPtr -> deviceCfg.fm_state              = OFF;          /* modulation state */

    instrPtr -> deviceCfg.pm_frequency          = 1000.0;       /* modulating frequency */
    instrPtr -> deviceCfg.pm_1_func             = SINUSOID;     /* modulating function in channel I */
    instrPtr -> deviceCfg.pm_1_deviation        = 180.0;        /* phase deviation in channel I */
    instrPtr -> deviceCfg.pm_1_state            = OFF;          /* modulation state in channel I */
    instrPtr -> deviceCfg.pm_2_func             = SINUSOID;     /* modulating function in channel Q */
    instrPtr -> deviceCfg.pm_2_deviation        = 180.0;        /* phase deviation in channel Q */
    instrPtr -> deviceCfg.pm_2_state            = OFF;          /* modulation state in channel Q */

    instrPtr -> deviceCfg.bm_rate               = 0.001;        /* burst rate */
    instrPtr -> deviceCfg.bm_count              = 1;            /* burst count */
    instrPtr -> deviceCfg.bm_source             = TRGED;        /* burst source */
    instrPtr -> deviceCfg.bm_state              = OFF;          /* burst state */

    instrPtr -> deviceCfg.fsk_frequency         = 10000.0;      /* FSK hop frequency */
    instrPtr -> deviceCfg.fsk_rate              = 0.001;        /* FSK rate */
    instrPtr -> deviceCfg.fsk_source            = INTERNAL;     /* FSK source */
    instrPtr -> deviceCfg.fsk_state             = OFF;          /* FSK state */

    instrPtr -> deviceCfg.psk_rate              = 0.001;        /* PSK rate */
    instrPtr -> deviceCfg.psk_source            = INTERNAL;     /* PSK source */
    instrPtr -> deviceCfg.psk_1_phase           = 180.0;        /* PSK hop phase in channel I */
    instrPtr -> deviceCfg.psk_1_state           = OFF;          /* PSK state in channel I */
    instrPtr -> deviceCfg.psk_2_phase           = 180.0;        /* PSK hop phase in channel Q */
    instrPtr -> deviceCfg.psk_2_state           = OFF;          /* PSK state in channel Q */

    /* For new firmware is reset of the module is done by means of additional "RESET" command. */

    CHECKERR (rssiam_revision_query (instrSession, NULL, fwRevisionBuf));
    sscanf (fwRevisionBuf, "%Le", &fwRevision);

    if (fwRevision < 3.610) /* From 3.610 is "RESET" supported */
        {
        CHECKERR (rssiam_setRegister (instrSession, "APPLY_DEVICE_CONFIGURATION",
            &instrPtr -> deviceCfg));
        }
    else
        {
        CHECKERR (rssiam_sendCmd (instrSession, "RESET"));

        /* Flush event queue to avoid errors after reset (Workaround for firmware >= 3.630) */

        CHECKERR (SiFlushEventQueue(instrSession));
        }

    /* --- Reset is finished, check event queue for possible errors --- */

    CHECKERR (rssiam_checkStatus (instrSession, VI_NULL, VI_NULL));

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssiam_self_test (ViSession instrSession,
                                    ViPInt16 testResult,
                                    ViChar _VI_FAR testMessage[])
{
    ViStatus rssiam_status = VI_WARN_NSUP_SELF_TEST;

    //
    // TODO: Resolve Self-Test ...
    //

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result. If the error query function is not supported by the */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_ERROR_QUERY.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rssiam_error_query (ViSession instrSession,
                                      ViPInt32 errorCode,
                                      ViChar _VI_FAR errorMessage[])
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges   instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr -> errorCount == 0)
        {
        *errorCode = 0x0; /* No error. */
        if (errorMessage)
            sprintf (errorMessage, "No error.");
        }
    else
        {
        /* Error queue full? */
        if (instrPtr -> errorCount >= MAX_ERROR_QUEUE_LENGTH)
            return RSSIAM_ERROR_QUEUE_OVERFLOW;

        /* Retrieve error code and description */
        *errorCode = instrPtr -> errorQueue[instrPtr -> errorCount - 1].stringVal;
        if (errorMessage)
            sprintf (errorMessage, "%s", instrPtr -> errorQueue[instrPtr -> errorCount - 1].stringName);

        /* Decrease error counter */
        instrPtr -> errorCount--;
        }

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rssiam_error_message (ViSession instrSession,
                                        ViStatus statusCode,
                                        ViChar _VI_FAR errMessage[])
{
    ViStatus rssiam_status = VI_SUCCESS;
    ViInt16 i;

    static TSStringValPair statusDescArray[] = {
        {VI_WARN_NSUP_ID_QUERY,         "WARNING: ID Query not supported"},
        {VI_WARN_NSUP_RESET,            "WARNING: Reset not supported"},
        {VI_WARN_NSUP_SELF_TEST,        "WARNING: Self-test not supported"},
        {VI_WARN_NSUP_ERROR_QUERY,      "WARNING: Error Query not supported"},
        {VI_WARN_NSUP_REV_QUERY,        "WARNING: Revision Query not supported"},
        {VI_ERROR_PARAMETER1,           "ERROR: Parameter 1 out of range"},
        {VI_ERROR_PARAMETER2,           "ERROR: Parameter 2 out of range"},
        {VI_ERROR_PARAMETER3,           "ERROR: Parameter 3 out of range"},
        {VI_ERROR_PARAMETER4,           "ERROR: Parameter 4 out of range"},
        {VI_ERROR_PARAMETER5,           "ERROR: Parameter 5 out of range"},
        {VI_ERROR_PARAMETER6,           "ERROR: Parameter 6 out of range"},
        {VI_ERROR_PARAMETER7,           "ERROR: Parameter 7 out of range"},
        {VI_ERROR_PARAMETER8,           "ERROR: Parameter 8 out of range"},
        {VI_ERROR_FAIL_ID_QUERY,        "ERROR: Identification query failed"},
        {VI_ERROR_INV_RESPONSE,         "ERROR: Interpreting instrument response"},
        {VI_ERROR_INSTR_FILE_OPEN,      "ERROR: Opening the specified file"},
        {VI_ERROR_INSTR_FILE_WRITE,     "ERROR: Writing to the specified file"},
        {VI_ERROR_INSTR_INTERPRETING_RESPONSE, "ERROR: Interpreting the instrument's response"},
        {VI_ERROR_INSTR_PARAMETER9 ,    "ERROR: Parameter 9 out of range"},
        {VI_ERROR_INSTR_PARAMETER10,    "ERROR: Parameter 10 out of range"},
        {VI_ERROR_INSTR_PARAMETER11,    "ERROR: Parameter 11 out of range"},
        {VI_ERROR_INSTR_PARAMETER12,    "ERROR: Parameter 12 out of range"},
        {VI_ERROR_INSTR_PARAMETER13,    "ERROR: Parameter 13 out of range"},
        {VI_ERROR_INSTR_PARAMETER14,    "ERROR: Parameter 14 out of range"},
        {VI_ERROR_INSTR_PARAMETER15,    "ERROR: Parameter 15 out of range"},

        /* Place user defined error codes here ... */

        {RSSIAM_ERROR_INSTRUMENT_ERROR,         "ERROR: Instrument status error."},
        {RSSIAM_ERROR_INVALID_CONFIGURATION,    "ERROR: Instrument configuration error."},
        {RSSIAM_ERROR_INSTRUMENT_OPTION,        "ERROR: Required instrument's option is not installed."},
        {RSSIAM_ERROR_INSTRUMENT_NSUP_MODEL,    "ERROR: Required instrument model is not connected."},
        {RSSIAM_ERROR_REG_NAME_NOT_FOUND,       "ERROR: Selected register name is not supported by the instrument."},
        {RSSIAM_ERROR_INVALID_VALUE,            "ERROR: Invalid value (value out of range)."},
        {RSSIAM_ERROR_RNG_TAB_NOT_AVAIL,        "ERROR: Range table for selected register name is not available."},
        {RSSIAM_ERROR_NULL_POINTER_VALUE,       "ERROR: NULL pointer passed as parameter."},
        {RSSIAM_ERROR_QUEUE_OVERFLOW,           "ERROR: The error queue is overflowed."},
        {RSSIAM_ERROR_DATA_NOT_AVAILABLE,       "ERROR: Data not available."},
        {RSSIAM_ERROR_DATA_CORRUPTED,           "ERROR: Data are corrupted."},
        {RSSIAM_ERROR_SETTINGS_CONFLICT,        "ERROR: Settings conflict. Passed parameter does not match with the current instrument's settings."},
        {RSSIAM_ERROR_RESERVED,                 "ERROR: Function or parameter is for any reason reserved."},
        {RSSIAM_ERROR_OVER_LIMIT,               "ERROR: Passed value is over predefined limit."},

        /* Place user defined warnings here ... */

        {VI_NULL, VI_NULL}
    };

    /* Query SiControl library */
    rssiam_status = SiGetErrorString(statusCode, errMessage, 256);
    /* If SiControl library failed, try user defined codes */
    if (rssiam_status == SI_WARN_UNKNOWN_STATUS)
        {
        for (i = 0; statusDescArray[i].stringName; i++)
            {
            if (statusDescArray[i].stringVal == statusCode)
                {
                sprintf (errMessage, "%s", statusDescArray[i].stringName);
                return VI_SUCCESS;
                }
            }
        }

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*           If the revision query function is not supported by the          */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_REV_QUERY.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rssiam_revision_query (ViSession instrSession,
                    ViChar _VI_FAR driverRev[], ViChar _VI_FAR instrRev[])
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViBoolean   handshake       = VI_TRUE;

    struct {
        ViUInt16 MajorVersion;
        ViUInt16 MinorVersion;
    } SFirmwareVersion = {0};

    /* This instrument does not provides handshake acknowledge in case of getting value */
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, &handshake));
    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, VI_FALSE));

    rssiam_status = SiGetRegister(instrSession, 0x1010, 0, &SFirmwareVersion, 4);

    SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, handshake);

    if (instrRev)
        sprintf (instrRev, "%u.%u", SFirmwareVersion.MajorVersion,
            SFirmwareVersion.MinorVersion);

    if (driverRev)
        sprintf (driverRev, "%s", RSSIAM_REVISION);

    /* Suppress positive (warning) code */
    rssiam_status = (rssiam_status < VI_SUCCESS) ? rssiam_status : VI_SUCCESS;

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rssiam_close (ViSession instrSession)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges   instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr != NULL)
        free (instrPtr);

    CHECKERR (SiCloseDevice (instrSession));
    CHECKERR (SiLibExit ());

    return rssiam_status;
}

/*****************************************************************************/
/*= UTILITY ROUTINES (Non-Exportable Functions) =============================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Boolean Value Out Of Range - ViBoolean                          */
/* Purpose:  This function checks a Boolean to see if it is equal to VI_TRUE */
/*           or VI_FALSE. If the value is out of range, the return value is  */
/*           VI_TRUE, otherwise the return value is VI_FALSE.                */
/*===========================================================================*/
ViBoolean rssiam_invalidViBooleanRange (ViBoolean val)
{
    return (ViBoolean)((val != VI_FALSE && val != VI_TRUE) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Long Signed Integer Value Out Of Range - ViInt32                */
/* Purpose:  This function checks a long signed integer value to see if it   */
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViBoolean rssiam_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Real (Double) Value Out Of Range - ViReal64                     */
/* Purpose:  This function checks a real (double) value to see if it lies    */
/*           between a minimum and maximum value.  If the value is out of    */
/*           range, the return value is VI_TRUE, otherwise the return value  */
/*           is VI_FALSE.                                                    */
/*===========================================================================*/
ViBoolean rssiam_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Check String                                                    */
/* Purpose:  This function checks a string value to see if it is             */
/*           of a defined length and initialized.                            */
/*===========================================================================*/
ViBoolean rssiam_invalidViString (ViString val, ViUInt32 maxLength)
{
    if (val)
        return (ViBoolean)((strlen (val) > maxLength) ? VI_TRUE : VI_FALSE);

    return VI_TRUE;
}

/*===========================================================================*/
/* Function: Initialize Clean Up                                             */
/* Purpose:  This function is used only by the rssiam_init function.  When   */
/*           an error is detected this function is called to close the       */
/*           open resource manager and instrument object sessions and to     */
/*           set the instrSession that is returned from rssiam_init to       */
/*           VI_NULL.                                                        */
/*===========================================================================*/
ViStatus rssiam_initCleanUp (ViPSession openInstrSession,
                             ViStatus currentStatus)
{
    pTSStatusDataRanges instrPtr = {0};

    if (SiGetAttribute (*openInstrSession, SI_ATTR_USER_DATA, &instrPtr) >= 0)
        if (instrPtr != NULL)
            free (instrPtr);

    SiCloseDevice (*openInstrSession);
    *openInstrSession = VI_NULL;

    return currentStatus;
}

/*===========================================================================*/
/* Function: Delay                                                           */
/* Purpose : With a call to rssiam_delay, the current program is suspended   */
/*           from execution for the number of seconds specified by the       */
/*           argument seconds. rssiam_delay is accurate to a millisecond.    */
/*           This function is platform independent.                          */
/*===========================================================================*/
void rssiam_delay (ViReal64 numberOfSeconds)
{
  clock_t StartTime = clock();

  while ((((double)(clock() - StartTime))/(double)CLOCKS_PER_SEC) < (numberOfSeconds));

  return;
}

/*****************************************************************************/
/*----------- INSERT INSTRUMENT-DEPENDENT UTILITY ROUTINES HERE -------------*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Default Instrument Setup                                        */
/* Purpose:  This function sends a default setup to the instrument. This     */
/*           function is called by the rssiam_reset operation and by the     */
/*           rssiam_init function if the reset option has not been           */
/*           selected. This function is useful for configuring any           */
/*           instrument settings that are required by the rest of the        */
/*           instrument driver functions.                                    */
/*===========================================================================*/
ViStatus rssiam_defaultInstrSetup (ViSession instrSession)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges     instrPtr        = {0};

    /* Determine if the structure has been initialized for the current       */
    /* Session and malloc if it has not.                                     */
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr == NULL)
        {
        instrPtr = malloc (sizeof (TSStatusDataRanges));
        instrPtr = memset (instrPtr, 0, sizeof (TSStatusDataRanges));
        }

    /* Set default values for members of the session based data structure */
    instrPtr -> errorChecking       = VI_TRUE;
    strcpy (instrPtr -> instrDriverRevision, RSSIAM_REVISION);
    /* - */
    instrPtr -> activeChannel       = 1;
    /* - */
    instrPtr -> voltageHigh[0]      = 5.0;
    instrPtr -> voltageHigh[1]      = 5.0;
    instrPtr -> voltageLow[0]       = -5.0;
    instrPtr -> voltageLow[1]       = -5.0;
    /* - */
    instrPtr -> outputLoad[0]       = 50.0;
    instrPtr -> outputLoad[1]       = 50.0;
    /* - */
    instrPtr -> outputVoltageUnit   = RSSIAM_OUTPUT_VOLT_UNIT_DEF;

    /* Flush event queue */
    CHECKERR (SiFlushEventQueue(instrSession));

    /* Flush error queue */
    instrPtr -> errorCount = 0;
    memset (instrPtr -> errorQueue, 0, sizeof (instrPtr -> errorQueue[MAX_ERROR_QUEUE_LENGTH]));

    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_USER_DATA, (ViUInt32)instrPtr));

    /* Retrieve current device config */
    {
    ViUInt16    deviceConfig = 0;

    CHECKERR (rssiam_getRegister (instrSession, "DEVICE_CONFIG", &deviceConfig, RSSIAM_CURRENT_RANGE));

    /*
        Device config = 0 ... with common frequency,
        Device config = 1 ... two independent frequencies
    */

    instrPtr -> channelCoupling = (deviceConfig == 1) ?
        RSSIAM_CHANNEL_COUPLING_OFF :
        RSSIAM_CHANNEL_COUPLING_FREQ;
    }

    return rssiam_status;
}

/*=========================================================================*/
/* Function: Check Status                                                  */
/* Purpose:  This function checks status subsystem. All events waiting in  */
/*           the event queue are retrieved and checked for error occurence.*/
/*           As option is possible search for the specified event.         */
/*=========================================================================*/
ViStatus rssiam_checkStatus (ViSession instrSession, ViInt16 checkEvent,
                ViPBoolean checkEnventFound)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    pTSStatusDataRanges instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    /* Proceed when Error Checking is enabled */
    if (instrPtr -> errorChecking)
        {
        ViUInt16    oldErrorCount       = instrPtr -> errorCount;
        ViBoolean   warningFlag         = VI_TRUE; /* If VI_FALSE, error is detected */
        ViInt32     idx                 = 0;
        int         EventId             = 0;
        long        lParam              = 0;
        int         wParam              = 0;

        /* --- Used for debuging purposes --- */

        ViChar      paramString[64];
        short       *p2short            = (short *)(&lParam);

        *paramString = 0;
        p2short++;

        /* --- */

        /* Set it to default (VI_FALSE = not event found) */
        if (checkEnventFound)
            *checkEnventFound = VI_FALSE;

        /* Search event queue for error events. Note that other events are discarted. */
        while ((rssiam_status = SiHandleEvent(instrSession, &EventId, &lParam, &wParam)) == VI_SUCCESS)
            {
            /* Additional error information */
            if (ADD_ERROR_INFO)
                sprintf (paramString, ", lParam[Up] = %hd, wParam = 0x%X", *p2short, wParam);
            /* Is error queue full? */
            if (instrPtr -> errorCount >= MAX_ERROR_QUEUE_LENGTH)
                break;
            /* Try to associate appropriate error descriptions */
            switch (EventId)
                {
                case RSSIAM_OSE_INTERNAL_ERROR: /* Operating system internal error. */

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                        "Operating system internal error (0x%X%s).", lParam, paramString);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;

                    break;
                case RSSIAM_DEVICE_ERROR: /* Firmware or hardware error. */

                    for (idx = 0; GSDeviceErrorsTable[idx].stringName; idx++)
                        {
                        if (GSDeviceErrorsTable[idx].stringVal == lParam)
                            {
                            break;
                            }
                        }

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    /* If error description is not available */
                    if (!GSDeviceErrorsTable[idx].stringName)
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Unknown device error (0x%X%s).", lParam, paramString);
                    else
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Device error (0x%X%s), %s.", lParam, paramString,
                            GSDeviceErrorsTable[idx].stringName);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;

                    break;
                case RSSIAM_EXECUTION_ERROR:

                    for (idx = 0; GSExecutionErrorsTable[idx].stringName; idx++)
                        {
                        if (GSExecutionErrorsTable[idx].stringVal == (short)lParam)
                            {
                            break;
                            }
                        }

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    /* If error description is not available */
                    if (!GSExecutionErrorsTable[idx].stringName)
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Unknown execution error (%ld%s).", (short)lParam, paramString);
                    else
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Execution error (%ld%s), %s.", (short)lParam, paramString,
                            GSExecutionErrorsTable[idx].stringName);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;

                    break;
                case RSSIAM_DEVICE_SPECIFIC_ERROR:

                    for (idx = 0; GSDeviceSpecificErrorsTable[idx].stringName; idx++)
                        {
                        if (GSDeviceSpecificErrorsTable[idx].stringVal == (short)lParam)
                            {
                            break;
                            }
                        }

                    /* Suppress error message */
                    if ((PLL_FAILED_ROSC_INFO == 0) && ((short)lParam == 402) && (wParam == 0x2060))
                        break;

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    /* If error description is not available */
                    if (!GSDeviceSpecificErrorsTable[idx].stringName)
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Unknown device-specific error (%ld%s).", (short)lParam, paramString);
                    else
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Device-specific error (%ld%s), %s.", (short)lParam, paramString,
                            GSDeviceSpecificErrorsTable[idx].stringName);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;

                    break;
                case RSSIAM_BAUGRUPPEN_DATA_BLOCK_ERROR: /* Baugruppen data block error. */

                    for (idx = 0; GSBaugruppenDataBlockErrorsTable[idx].stringName; idx++)
                        {
                        if (GSBaugruppenDataBlockErrorsTable[idx].stringVal == lParam)
                            {
                            break;
                            }
                        }

                    instrPtr -> errorQueue[instrPtr -> errorCount].stringVal = EventId;

                    /* If error description is not available */
                    if (!GSBaugruppenDataBlockErrorsTable[idx].stringName)
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Unknown baugruppen data block error (0x%X%s).", lParam, paramString);
                    else
                        sprintf (instrPtr -> errorQueue[instrPtr -> errorCount].stringName,
                            "Baugruppen data block error (0x%X%s), %s.", lParam, paramString,
                            GSBaugruppenDataBlockErrorsTable[idx].stringName);

                    instrPtr -> errorCount++;
                    warningFlag = VI_FALSE;

                    break;
                default:
                    /* Check for the specified event */
                    if (EventId == checkEvent)
                        if (checkEnventFound)
                            *checkEnventFound = VI_TRUE;
                }
            /* Zeroing event data */
            EventId= 0x0; lParam = 0x0; wParam = 0x0;
            }

        /* If any error has been detected, return error/warning code */
        if (instrPtr -> errorCount > oldErrorCount)
            rssiam_status = (warningFlag) ?
                VI_SUCCESS : RSSIAM_ERROR_INSTRUMENT_ERROR;
        else
            rssiam_status = VI_SUCCESS;
        }

    return rssiam_status;
}

/*=========================================================================*/
/* Function: Set Register                                                  */
/* Purpose:  This function sets value to the register defined by its name. */
/*=========================================================================*/
ViStatus rssiam_setRegister (ViSession instrSession, ViString registerSetName,
                void *value)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    ViInt32                 index           = 0;
    ViUInt16                deviceConfig    = 0;
    pTSStatusDataRanges     instrPtr        = {0};
    void                    *tempValue;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_getIndexFromName (registerSetName, &index));

    /*
        Device config = 0 ... with common frequency,
        Device config = 1 ... two independent frequencies
    */

    deviceConfig = (instrPtr -> channelCoupling == RSSIAM_CHANNEL_COUPLING_OFF) ? 1 : 0;

    /* Copy original value to the teporary variable */
    tempValue = malloc (GSRegisterSetTable[index].Size);
    tempValue = memcpy (tempValue, value, GSRegisterSetTable[index].Size);

    /* Register range checking & discreete value translation */
    if ((rssiam_status = rssiam_checkRange (index, NULL, tempValue, NULL)) < VI_SUCCESS)
        {
        free (tempValue);
        return rssiam_status;
        }

    /* Select associated channels */
    if (GSRegisterSetTable[index].Channels[deviceConfig] == 0x0)
        {
        if ((rssiam_status = SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            0, tempValue, GSRegisterSetTable[index].Size)) < VI_SUCCESS)
            {
            free (tempValue);
            return rssiam_status;
            }
        }
    else
        {
        if ((rssiam_status = SiSetRegister(instrSession, GSRegisterSetTable[index].RegId,
            instrPtr -> activeChannel, tempValue, GSRegisterSetTable[index].Size)) < VI_SUCCESS)
            {
            free (tempValue);
            return rssiam_status;
            }
        }

    free (tempValue);

    return rssiam_status;
}

/*=========================================================================*/
/* Function: Get Register                                                  */
/* Purpose:  This function gets value of the register defined by its name. */
/*=========================================================================*/
ViStatus rssiam_getRegister (ViSession instrSession, ViString registerSetName,
                void *value, ViInt16 range)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    ViInt32                 index           = 0;
    ViUInt16                deviceConfig    = 0;
    ViBoolean               handshake       = VI_TRUE;
    pTSStatusDataRanges     instrPtr        = {0};

    if (!value)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));
    CHECKERR (rssiam_getIndexFromName (registerSetName, &index));

    /* Current, minimum or maximum setting is to be queried? */
    switch (range)
        {
        case RSSIAM_MIN_RANGE:
            CHECKERR (rssiam_checkRange (index, value, VI_NULL, VI_NULL));
            return rssiam_status;
        case RSSIAM_MAX_RANGE:
            CHECKERR (rssiam_checkRange (index, VI_NULL, VI_NULL, value));
            return rssiam_status;
        case RSSIAM_CURRENT_RANGE:

            /* Do nothing */

            break;
        default:
            return RSSIAM_ERROR_INVALID_VALUE;
        }

    /*
        Device config = 0 ... with common frequency,
        Device config = 1 ... two independent frequencies
    */

    deviceConfig = (instrPtr -> channelCoupling == RSSIAM_CHANNEL_COUPLING_OFF) ? 1 : 0;

    /* This instrument does not provides handshake acknowledge in case of getting value */
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, &handshake));
    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, VI_FALSE));

    /* Select associated channel */
    if (GSRegisterSetTable[index].Channels[deviceConfig] == 0x0)
        {
        rssiam_status = SiGetRegister(instrSession, GSRegisterSetTable[index].RegId,
            0, value, GSRegisterSetTable[index].Size);
        }
    else
        {
        rssiam_status = SiGetRegister(instrSession, GSRegisterSetTable[index].RegId,
            instrPtr -> activeChannel, value, GSRegisterSetTable[index].Size);
        }

    SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, handshake);

    CHECKERR (rssiam_status);

    /* --- Reverse discreete value translation --- */

    if (GSRegisterSetTable[index].RangeTable -> discreteValues)
        {
        ViInt32 count = 0;

        for (count = 0; GSRegisterSetTable[index].RangeTable -> discreteValues[count].opt; count++)
            {
            switch (GSRegisterSetTable[index].Structure)
                {
                case DBL:
                    {
                    ViReal64 new_value = *(ViPReal64)value;

                    if (fabs (new_value - GSRegisterSetTable[index].RangeTable -> discreteValues[count].value.dbl) < NUMERIC_PRECISION)
                        {
                        *(ViReal64*)value = GSRegisterSetTable[index].RangeTable -> discreteValues[count].parameter;

                        return VI_SUCCESS;
                        }
                    }
                    break;
                case FLT:
                    {
                    ViReal32 new_value = *(ViPReal32)value;

                    if (fabs (new_value - GSRegisterSetTable[index].RangeTable -> discreteValues[count].value.dbl) < NUMERIC_PRECISION)
                        {
                        DBL2FLT(GSRegisterSetTable[index].RangeTable -> discreteValues[count].parameter, *(ViReal32*)value);

                        return VI_SUCCESS;
                        }
                    }
                    break;
                case I32:
                    {
                    ViInt32 new_value = *(ViPInt32)value;

                    if (new_value == GSRegisterSetTable[index].RangeTable -> discreteValues[count].value.dbl)
                        {
                        *(ViInt32*)value = (ViInt32)GSRegisterSetTable[index].RangeTable -> discreteValues[count].parameter;

                        return VI_SUCCESS;
                        }
                    }
                    break;
                case U32:
                    {
                    ViUInt32 new_value = *(ViPUInt32)value;

                    if (new_value == GSRegisterSetTable[index].RangeTable -> discreteValues[count].value.dbl)
                        {
                        *(ViUInt32*)value = (ViUInt32)GSRegisterSetTable[index].RangeTable -> discreteValues[count].parameter;

                        return VI_SUCCESS;
                        }
                    }
                    break;
                case I16:
                    {
                    ViInt16 new_value = *(ViPInt16)value;

                    if (new_value == GSRegisterSetTable[index].RangeTable -> discreteValues[count].value.dbl)
                        {
                        *(ViInt16*)value = (ViInt16)GSRegisterSetTable[index].RangeTable -> discreteValues[count].parameter;

                        return VI_SUCCESS;
                        }
                    }
                    break;
                case U16:
                    {
                    ViUInt16 new_value = *(ViPUInt16)value;

                    if (new_value == GSRegisterSetTable[index].RangeTable -> discreteValues[count].value.dbl)
                        {
                        *(ViUInt16*)value = (ViUInt16)GSRegisterSetTable[index].RangeTable -> discreteValues[count].parameter;

                        return VI_SUCCESS;
                        }
                    }
                    break;
                default:

                    //
                    // TODO: Resolve other data types ...
                    //

                    return VI_SUCCESS;
                }
            }

        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

        }

    /* Suppress positive (warning) code */
    rssiam_status = (rssiam_status < VI_SUCCESS) ? rssiam_status : VI_SUCCESS;

    return rssiam_status;
}

/*=========================================================================*/
/* Function: Get Device Capabilities                                       */
/* Purpose:  This function gets value of the capability register defined   */
/*           by its name.                                                  */
/*=========================================================================*/
ViStatus rssiam_getDeviceCaps (ViSession instrSession, ViConstString capsName,
                void *value)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    ViBoolean           handshake       = VI_TRUE;
    ViInt32             idx             = 0;

    /* In this special case when NULL pointer passed, return VI_SUCCESS */
    if (!capsName)
        return VI_SUCCESS;

    for (idx = 0; GSDeviceCapsTable[idx].Name; idx++)
    {
    if (strcmp (GSDeviceCapsTable[idx].Name, capsName) == 0)
        {
        break;
        }
    }

    if (!GSDeviceCapsTable[idx].Name)
        rssiam_status = RSSIAM_ERROR_REG_NAME_NOT_FOUND;

    /* This instrument does not provides handshake acknowledge in case of getting value */
    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, &handshake));
    CHECKERR (SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, VI_FALSE));

    rssiam_status = SiGetDeviceCaps (instrSession, GSDeviceCapsTable[idx].CapsId,
        0, value, GSDeviceCapsTable[idx].Size);

    SiSetAttribute (instrSession, SI_ATTR_HANDSHAKE_ACKNOWLEDGE, handshake);

    return rssiam_status;
}

/*=========================================================================*/
/* Function: Send Command                                                  */
/* Purpose:  This function sends command defined by its name.              */
/*=========================================================================*/
ViStatus rssiam_sendCmd (ViSession instrSession, ViString cmdSetName)
{
    ViStatus                rssiam_status   = VI_SUCCESS;
    ViInt32                 idx             = 0;
    ViUInt16                deviceConfig    = 0;
    pTSStatusDataRanges     instrPtr        = {0};

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_USER_DATA, &instrPtr));

    if (!cmdSetName)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    for (idx = 0; GSCommandSetTable[idx].Name; idx++)
        {
        if (strcmp (GSCommandSetTable[idx].Name, cmdSetName) == 0)
            {
            break;
            }
        }

    if (!GSCommandSetTable[idx].Name)
        rssiam_status = RSSIAM_ERROR_REG_NAME_NOT_FOUND;

    /*
        Device config = 0 ... with common frequency,
        Device config = 1 ... two independent frequencies
    */

    deviceConfig = (instrPtr -> channelCoupling == RSSIAM_CHANNEL_COUPLING_OFF) ? 1 : 0;

    /* Choose if operation is channel based or not */
    if (GSCommandSetTable[idx].Channels[deviceConfig] == 0x0)
        {
        CHECKERR (SiSendCommand (instrSession, GSCommandSetTable[idx].CmdId));
        }
    else
        {
        CHECKERR (SiSetRegister(instrSession, GSCommandSetTable[idx].CmdId,
            instrPtr -> activeChannel, 0, 0));
        }

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Wait for Device State                                           */
/* Purpose:  This function waits until the defined device state or timeout   */
/*           associated with the session is reached.                         */
/*===========================================================================*/
ViStatus rssiam_waitForDeviceState (ViSession instrSession, ViInt32 deviceState)
{
    ViStatus rssiam_status  = VI_SUCCESS;
    ViInt32  status         = 0;
    ViUInt32 timeout        = 0;
    ViUInt32 consumed       = 0;

    CHECKERR (SiGetAttribute (instrSession, SI_ATTR_TMO_VALUE, &timeout));

    while ((status = SiGetStatus(instrSession)) != deviceState)
        {
        /* Wait for at least 5 milisecond */
        rssiam_delay (0.005);
        /* Increase consumed time counter */
        consumed += 5;
        /* Exit when timeout elapsed */
        if (consumed >= timeout)
            return SI_ERROR_TMO;
        }

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Get Index from Name                                             */
/* Purpose:  This function returns index position in static global table for */
/*           specified register name.                                        */
/*===========================================================================*/
ViStatus rssiam_getIndexFromName (ViString Name, ViPInt32 index)
{
    ViStatus    rssiam_status   = VI_SUCCESS;
    ViInt32     idx             = 0;

    if (index) *index = -1;

    if (!Name)
        return RSSIAM_ERROR_NULL_POINTER_VALUE;

    for (idx = 0; GSRegisterSetTable[idx].Name; idx++)
        {
        if (strcmp (GSRegisterSetTable[idx].Name, Name) == 0)
            {
            if (index) *index = idx;
            break;
            }
        }

    if (!GSRegisterSetTable[idx].Name)
        rssiam_status = RSSIAM_ERROR_REG_NAME_NOT_FOUND;

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Check Range                                                     */
/* Purpose:  This function returns whether or not is value associated with   */
/*           register name in the valid range.                               */
/*===========================================================================*/
ViStatus rssiam_checkRange (ViInt32 index, void* min, void* value, void* max)
{
    ViStatus            rssiam_status   = VI_SUCCESS;
    ViInt32             maxIndex        = 0;
    ViInt32             count           = 0;
    TSRegisterSetEntry  *table          = GSRegisterSetTable;

    for (maxIndex = 0; table[maxIndex].Name; maxIndex++);

    if ((!table[index].RangeTable) || (index > maxIndex))
        return RSSIAM_ERROR_RNG_TAB_NOT_AVAIL;

    if ((min != NULL) || (value != NULL) || (max != NULL))
        {
        do
            {
            switch (table[index].Structure)
                {
                case I16:

                    if (min)
                        {
                        *(ViInt16*)min = (ViInt16)table[index].RangeTable -> min.dbl;
                        }

                    if (max)
                        {
                        *(ViInt16*)max = (ViInt16)table[index].RangeTable -> max.dbl;
                        }

                    if (value)
                        {
                        ViInt16 new_value = *(ViPInt16)value;

                        if (table[index].RangeTable -> discreteValues)
                            {
                            if (new_value == table[index].RangeTable -> discreteValues[count].parameter)
                                {
                                *(ViInt16*)value = (ViInt16)table[index].RangeTable -> discreteValues[count].value.dbl;

                                return VI_SUCCESS;
                                }
                            }
                        else
                            {
                            if (( table[index].RangeTable -> min.dbl > new_value ) ||
                                ( table[index].RangeTable -> max.dbl < new_value ))
                                {
                                return RSSIAM_ERROR_INVALID_VALUE;
                                }
                            }
                        }
                    break;
                case U16:

                    if (min)
                        {
                        *(ViUInt16*)min = (ViUInt16)table[index].RangeTable -> min.dbl;
                        }

                    if (max)
                        {
                        *(ViUInt16*)max = (ViUInt16)table[index].RangeTable -> max.dbl;
                        }

                    if (value)
                        {
                        ViUInt16 new_value = *(ViPUInt16)value;

                        if (table[index].RangeTable -> discreteValues)
                            {
                            if (new_value == table[index].RangeTable -> discreteValues[count].parameter)
                                {
                                *(ViUInt16*)value = (ViUInt16)table[index].RangeTable -> discreteValues[count].value.dbl;

                                return VI_SUCCESS;
                                }
                            }
                        else
                            {
                            if (( table[index].RangeTable -> min.dbl > new_value ) ||
                                ( table[index].RangeTable -> max.dbl < new_value ))
                                {
                                return RSSIAM_ERROR_INVALID_VALUE;
                                }
                            }
                        }
                    break;
                case I32:

                    if (min)
                        {
                        *(ViInt32*)min = (ViInt32)table[index].RangeTable -> min.dbl;
                        }

                    if (max)
                        {
                        *(ViInt32*)max = (ViInt32)table[index].RangeTable -> max.dbl;
                        }

                    if (value)
                        {
                        ViInt32 new_value = *(ViPInt32)value;

                        if (table[index].RangeTable -> discreteValues)
                            {
                            if (new_value == table[index].RangeTable -> discreteValues[count].parameter)
                                {
                                *(ViInt32*)value = (ViInt32)table[index].RangeTable -> discreteValues[count].value.dbl;

                                return VI_SUCCESS;
                                }
                            }
                        else
                            {
                            if (( table[index].RangeTable -> min.dbl > new_value ) ||
                                ( table[index].RangeTable -> max.dbl < new_value ))
                                {
                                return RSSIAM_ERROR_INVALID_VALUE;
                                }
                            }
                        }
                    break;
                case U32:

                    if (min)
                        {
                        *(ViUInt32*)min = (ViUInt32)table[index].RangeTable -> min.dbl;
                        }

                    if (max)
                        {
                        *(ViUInt32*)max = (ViUInt32)table[index].RangeTable -> max.dbl;
                        }

                    if (value)
                        {
                        ViUInt32 new_value = *(ViPUInt32)value;

                        if (table[index].RangeTable -> discreteValues)
                            {
                            if (new_value == table[index].RangeTable -> discreteValues[count].parameter)
                                {
                                *(ViUInt32*)value = (ViUInt32)table[index].RangeTable -> discreteValues[count].value.dbl;

                                return VI_SUCCESS;
                                }
                            }
                        else
                            {
                            if (( table[index].RangeTable -> min.dbl > new_value ) ||
                                ( table[index].RangeTable -> max.dbl < new_value ))
                                {
                                return RSSIAM_ERROR_INVALID_VALUE;
                                }
                            }
                        }
                    break;
                case FLT:

                    if (min)
                        {
                        DBL2FLT(table[index].RangeTable -> min.dbl, *(ViReal32*)min);
                        }

                    if (max)
                        {
                        DBL2FLT(table[index].RangeTable -> max.dbl, *(ViReal32*)max);
                        }

                    if (value)
                        {
                        ViReal32 new_value = *(ViPReal32)value;

                        if (table[index].RangeTable -> discreteValues)
                            {
                            if (fabs (new_value - table[index].RangeTable -> discreteValues[count].parameter) < NUMERIC_PRECISION)
                                {
                                DBL2FLT(table[index].RangeTable -> discreteValues[count].value.dbl, *(ViReal32*)value);

                                return VI_SUCCESS;
                                }
                            }
                        else
                            {
                            if (( table[index].RangeTable -> min.dbl > new_value ) ||
                                ( table[index].RangeTable -> max.dbl < new_value ))
                                {
                                return RSSIAM_ERROR_INVALID_VALUE;
                                }
                            }
                        }
                    break;
                case DBL:

                    if (min)
                        {
                        *(ViReal64*)min = table[index].RangeTable -> min.dbl;
                        }

                    if (max)
                        {
                        *(ViReal64*)max = table[index].RangeTable -> max.dbl;
                        }

                    if (value)
                        {
                        ViReal64 new_value = *(ViPReal64)value;

                        if (table[index].RangeTable -> discreteValues)
                            {
                            if (fabs (new_value - table[index].RangeTable -> discreteValues[count].parameter) < NUMERIC_PRECISION)
                                {
                                *(ViReal64*)value = table[index].RangeTable -> discreteValues[count].value.dbl;

                                return VI_SUCCESS;
                                }
                            }
                        else
                            {
                            if (( table[index].RangeTable -> min.dbl > new_value ) ||
                                ( table[index].RangeTable -> max.dbl < new_value ))
                                {
                                return RSSIAM_ERROR_INVALID_VALUE;
                                }
                            }
                        }
                    break;
                case STRING:
                    {

                    // TODO: Pointer to string handling ...

                    }
                    break;
                case STRUCT: /* Structures must be handled each case one by one */

                    // TODO: Structures handling ...

                break;
                case DBL_ARRAY:

                    // TODO: Array handling ...

                break;
                case U16_ARRAY:

                    // TODO: Array handling ...

                break;
                default:
                    rssiam_status = VI_SUCCESS;
                    break;
                }

            if (!table[index].RangeTable -> discreteValues)
                break; /* Exit from Do Loop */

            count++;

            } while (table[index].RangeTable -> discreteValues[count].opt);
        }

    return rssiam_status;
}

/*===========================================================================*/
/* Function: Swap 32bit Integer                                              */
/* Purpose:  For the Intel architecture and Pentium processors we have to use*/
/*           right-to-left (little-endian) ordering. This function will do   */
/*           the conversion when neccessary.                                 */
/*===========================================================================*/
void rssiam_SWAP_32(unsigned char *data, long points)
{
    /* MOTOROLA (byte order 0123) or INTEL (byte order 3210). */
    unsigned int    word = 0x1122;
    unsigned char   *p2word = (unsigned char*)&word;

    if (*p2word == 0x11) /* MOTOROLA format */
    {
       unsigned char    src[4];
       long             *p2data = (long*)data;
       int              idx;

       for (idx = 0; idx < points; idx++, p2data++)
          {
              *((long *)src) = *(p2data);
              ((unsigned char *)(p2data))[0] =  ((unsigned char*)(src))[3];
              ((unsigned char *)(p2data))[1] =  ((unsigned char*)(src))[2];
              ((unsigned char *)(p2data))[2] =  ((unsigned char*)(src))[1];
              ((unsigned char *)(p2data))[3] =  ((unsigned char*)(src))[0];
          }
    }
    
   return;
}

/*===========================================================================*/
/* Function: Unit Conversion
/* Purpose:  Converts values in Volts (Vpp) to values in selected unit.
/*===========================================================================*/
ViReal64 rssiam_vpp2unit (ViReal64 value, ViInt32 unit)
{
    switch (unit)
        {
        case RSSIAM_OUTPUT_VOLT_UNIT_DEF:
        case RSSIAM_OUTPUT_VOLT_UNIT_VPP:
            return value;
        case RSSIAM_OUTPUT_VOLT_UNIT_VRMS:
            return value / (2.0 * sqrt(2.0));
        case RSSIAM_OUTPUT_VOLT_UNIT_DBM:
            return 10.0 * log10 ((value * value / 8.0) / (50.0 * 0.001));
        }

    return value;
}

/*===========================================================================*/
/* Function: Unit Conversion
/* Purpose:  Converts value in selected unit to Vpp.
/*===========================================================================*/
ViReal64 rssiam_unit2vpp (ViReal64 value, ViInt32 unit)
{
    switch (unit)
        {
        case RSSIAM_OUTPUT_VOLT_UNIT_DEF:
        case RSSIAM_OUTPUT_VOLT_UNIT_VPP:
            return value;
        case RSSIAM_OUTPUT_VOLT_UNIT_VRMS:
            return value * (2.0 * sqrt(2.0));
        case RSSIAM_OUTPUT_VOLT_UNIT_DBM:
            return sqrt (8.0 * 50.0 * 0.001 * pow (10.0, value / 10.0));
        }

    return value;
}

/*===========================================================================*/
/* Function: U Load, U Source
/* Purpose:  Calculates based on output load (rLoad) voltage level to be seen
/*           at the output. Passed level value is value to be set to the device
/*           register. All levels are in Vpp.
/*===========================================================================*/
ViReal64 rssiam_uLoad (ViReal64 uSource, ViReal64 rLoad)
{
    return 2.0 * (uSource * rLoad / (rLoad + 50.0)); /* U Load */
}

ViReal64 rssiam_uSource (ViReal64 uLoad, ViReal64 rLoad)
{
    return uLoad * (rLoad + 50.0) / (2.0 * rLoad); /* U Source */
}

/*****************************************************************************/
/*=== END INSTRUMENT DRIVER SOURCE CODE =====================================*/
/*****************************************************************************/
